@@ -86,7 +86,7 @@ QString Awards::getQSOofAward (const int _enti, const int _bandid)
     bool sqlOK = false;
     QString answer = QString();
 
-    stringQuery = QString("SELECT call, qso_date, time_on from log where id=(SELECT qsoid from awarddxcc where dxcc='%1' and band='%2')").arg(_enti).arg(_bandid);
+    stringQuery = QString("SELECT call, qso_date, from log where id=(SELECT qsoid from awarddxcc where dxcc='%1' and band='%2')").arg(_enti).arg(_bandid);
 
     sqlOK = query.exec(stringQuery);
        //qDebug() << "Awards::getQSOofAward: stringQuery: " << stringQuery << endl;
@@ -95,7 +95,7 @@ QString Awards::getQSOofAward (const int _enti, const int _bandid)
         query.next();
         if (query.isValid())
         {
-            answer = query.value(0).toString() + " / " + query.value(1).toString() + " / " + query.value(2).toString();
+            answer = query.value(0).toString() + " / " + query.value(1).toString() ;
 
             query.finish();
                //qDebug() << "Awards::getQSOofAward: answer: " << answer << endl;
@@ -217,11 +217,11 @@ int Awards::getDXCCConfirmed(const int _logNumber)
     bool sqlOK;
     if (dataProxy->doesThisLogExist(_logNumber))
     {
-        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log where qsl_rcvd='Y' AND dxcc!='' AND dxcc >'0' AND lognumber='%1'").arg(_logNumber);
+        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log where (qsl_rcvd='Y' OR lotw_qsl_rcvd='Y') AND dxcc!='' AND dxcc >'0' AND lognumber='%1'").arg(_logNumber);
     }
     else
     {
-        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log where qsl_rcvd='Y' AND dxcc!='' AND dxcc >'0'");
+        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log where (qsl_rcvd='Y' OR lotw_qsl_rcvd='Y') AND dxcc!='' AND dxcc >'0'");
     }
 
     sqlOK = query.exec(stringQuery);
@@ -303,11 +303,11 @@ int Awards::getWAZConfirmed(const int _logNumber)
     //Usar la siguiente para el confirmed
     if (dataProxy->doesThisLogExist(_logNumber))
     {
-        stringQuery = QString("SELECT COUNT (cqz) FROM (SELECT DISTINCT cqz FROM log WHERE cqz!='' AND cqz>'0' AND cqz<'41' AND qsl_rcvd='Y' AND lognumber='%1')").arg(_logNumber);
+        stringQuery = QString("SELECT COUNT (cqz) FROM (SELECT DISTINCT cqz FROM log WHERE cqz!='' AND cqz>'0' AND cqz<'41' AND (qsl_rcvd='Y' OR lotw_qsl_rcvd='Y') AND lognumber='%1')").arg(_logNumber);
     }
     else
     {
-        stringQuery = QString("SELECT COUNT (cqz) FROM (SELECT DISTINCT cqz FROM log WHERE cqz!='' AND cqz>'0' AND cqz<'41' AND qsl_rcvd='Y')");
+        stringQuery = QString("SELECT COUNT (cqz) FROM (SELECT DISTINCT cqz FROM log WHERE cqz!='' AND cqz>'0' AND cqz<'41' AND (qsl_rcvd='Y' OR lotw_qsl_rcvd='Y'))");
     }
 
 
@@ -702,7 +702,7 @@ QColor Awards::getQRZDXStatusColor(const QStringList &_qs)
     //From Search QSO to QSL: q << _call << bandid << _mode << QString::number(currentLog);
 
 
-      //qDebug() << "Awards::getQRZDXStatusColor: " << _qs.at(0) << "/" << _qs.at(1) << "/" << _qs.at(2) << _qs.at(3) << endl;
+    //qDebug() << "Awards::getQRZDXStatusColor: " << _qs.at(0) << "/" << _qs.at(1) << "/" << _qs.at(2) << _qs.at(3) << endl;
     // Receives:  QStringList _qs;
     //_qs << Entity << BandID << ModeId << lognumber;
 
@@ -717,8 +717,8 @@ QColor Awards::getQRZDXStatusColor(const QStringList &_qs)
 
     int status = getDXStatus(_qs);
 
-       //qDebug() << "Awards::getQRZDXStatusColor: status: " << QString::number(status) << "/" << getDXStatusString(status) << endl;
-       //qDebug() << "Awards::getQRZDXStatusColor: status: " << QString::number(status) << endl;
+    //qDebug() << "Awards::getQRZDXStatusColor: status: " << QString::number(status) << "/" << getDXStatusString(status) << endl;
+    //qDebug() << "Awards::getQRZDXStatusColor: status: " << QString::number(status) << endl;
 
     switch (status) {
         case 0:
