@@ -22,11 +22,13 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
 #include <QObject>
+//#include<QtCore/QtCore>
+//#include<QtCore/QObject>
 #include <QSqlDatabase>
 #include <QMessageBox>
 #include <QSqlQuery>
@@ -40,7 +42,7 @@
 class QSqlRelationalTableModel;
 // Previous db update 0.011
 
-const float DBVersionf = 0.016; // This is the latest version of the DB.
+const float DBVersionf = 0.019f; // This is the latest version of the DB.
 
 
 struct AwarddxccEntry
@@ -62,14 +64,17 @@ struct AwarddxccEntryCheck
     QString logNumber;
 };
 
-class DataBase
+class DataBase //: public QObject
 {
+   // Q_OBJECT
 
 public:
     DataBase(const QString &_parentClass, const QString &_DBName);
     //DataBase(const QString _softVersion, bool  inmemoryonly = false);
     DataBase(const QString &_parentClass, const QString &_softVersion, const QString &_DBName);
+    //virtual ~DataBase();
     ~DataBase();
+
     QString getSoftVersion();
     QString getDBVersion();
     QString getDBName();
@@ -113,8 +118,11 @@ public:
 
     bool unMarkAllQSO();
     bool updateIfNeeded();
+    void backupB4Update();
+    void logBackup();
     void compress();
 
+
     bool updateTheEntityTableISONames();
     bool updateTableLogs();
 
@@ -128,6 +136,8 @@ public:
     bool updateAwardWAZTable();
     int getNumberOfQsos(const int _logNumber);
 
+//private slots:
+//    void slotPrintErrors(QString _func, QString _msg, int _level);
 
 private:
     //bool beginTransaction();
@@ -138,6 +148,7 @@ private:
     bool isTheDBCreated();
     bool isTheTableExisting(const QString &_tableName);
     bool hasTheTableData(const QString &_tableName);
+    bool requiresManualUpgrade();
     bool updateToLatest();
     bool updateTo003(); // Updates the DB to 0.0.3
     bool updateTo004();
@@ -151,8 +162,12 @@ private:
     bool updateTo012(); // Updates the flags and so on.
     bool updateTo013(); // Update the qsl_via_enumeration bug caused for calling the table just qsl_via
     bool updateTo014(); // Update the Satellite DB
-    bool updateTo015();  //Adds the FT4 mode
+    bool updateTo015(); // Adds the FT4 mode
     bool updateTo016(); // Recreates the satellite table to add the QO-100
+    bool updateTo017(); // Merges the qso_date & time_on fields
+    bool updateTo018(); // Creates Subdivision
+    bool updateTo019(); // Adds FTS4 and FST4W modes and RS-44 satellite
+
     bool updateTableLog(const int _v);
     bool updateDBVersion(QString _softV, QString _dbV);
 
@@ -183,6 +198,8 @@ private:
     bool recreateTableWAZ();
     bool createTableAwardWAZ();
 
+    bool createTableSubdivision(const bool NoTmp);
+    
     bool recreateSatelliteData();
     bool createTableSatellites(const bool NoTmp);
     bool populateTableSatellites(const bool NoTmp);
@@ -205,8 +222,6 @@ private:
     bool howManyQSOsInLog(const int i);
     //void showError();
 
-
-
     //bool moveFromModeIdToSubmodeId();
     bool updateModeIdFromSubModeId();
     bool updateBandIdTableLogToNewOnes();
@@ -216,6 +231,7 @@ private:
     void queryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
 
 
+
     bool created;
     float dbVersion;    // The current version of the DB. May differ from latestReaded if we are updating the DB!
     QString dbConnectionName;
@@ -244,8 +260,9 @@ private:
 
     int constrid; // Just an id for the constructor to check who is being executed at one specific time
 
-signals:
-    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+//signals:
+    //void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+    //void debugLog(QString functionFailed, QString errorCode, int level); // emitted when a function retuns false due to an error
 
 
 };
