@@ -1,5 +1,6 @@
 #ifndef DATAPROXY_SQLITE_H
 #define DATAPROXY_SQLITE_H
+
 /***************************************************************************
                           dataproxy_sqlite.h  -  description
                              -------------------
@@ -22,16 +23,24 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 #include <QString>
 #include <QStringList>
 #include <QObject>
-//#include <QtGlobal>
-
 #include "database.h"
+#include "qso.h"
+//#include "regionalaward.h"
 
+//Class QSO;
+
+enum
+{
+    CQZones = 40,
+    ITUZones = 90,
+    DXCCEntities = 521 // http://www.adif.org/adif302.htm#Country%20Codes
+};
 
 class DataProxy_SQLite : public QObject
 {
@@ -39,9 +48,10 @@ class DataProxy_SQLite : public QObject
 
 public:
 
-    DataProxy_SQLite(const QString &_softVersion, const QString &_parentFunction);
+    DataProxy_SQLite(const QString &_parentFunction, const QString &_softVersion = "0");
     ~DataProxy_SQLite();
 
+
     QString getSoftVersion();
     QString getDBVersion();
     bool reconnectDB();
@@ -81,35 +91,42 @@ public:
     QString getBandNameFromFreq(const double _n);
 
     double getLowLimitBandFromBandName(const QString &_sm);
-    double getLowLimitBandFromBandId(const QString &_sm);
+    double getLowLimitBandFromBandId(const int _sm);
     bool isThisFreqInBand(const QString &_band, const QString &_fr);
 
     int getLastQSOid();
     QDate getFirstQSODateFromCall (const QString &_call);  // If the callsign provided is not valid it provides the date of the first QSO
     QDate getLastQSODateFromCall (const QString &_call);   // If the callsign provided is not valid it provides the date of the last QSO
 
-    bool addQSOFromWSJTX(const QString &_dxcall, const double _freq, const QString &_mode,
-                                 const QString &_dx_grid, const QString &_time_off, const QString &_report_sent, const QString &_report_rec,
-                                 const QString &_tx_power, const QString &_comments, const QString &_name, const QString &_time_on,
-                                 const int _dxcc, const QString &_opQrz, const QString &_stQrz, const QString &_myLoc, const int _logN);
+    bool addQSOFromWSJTX (const QString &_dxcall, const QString &_mode, const QString &_band, const double _freq,
+                          const QString &_mygrid, const QString &_dxgrid,
+                          const QString &_rstTX, const QString &_rstRX, const QString &_sRX, const QString &_sTX,
+                          const QString &_comment,
+                          const QString &_stationcallsign, const QString &_name, const QString &_operator,
+                          const QDateTime &_datetime, const QDateTime &_datetime_off, const double txpower,
+                          const int _dxcc, const int _logNumber);
+
+    int addQSOFromLoTW(const QString &_call, const QDateTime _datetime, const QString &_mode, const QString &_band, const double _freq, const QDate _qslrdate, const QString &_stationcallsign, const int _logn);
+    int addQSO(QSO &_qso);
 
     bool deleteQSO(const int _qsoId);
     int isWorkedB4(const QString &_qrz, const int _currentLog);
-    bool isThisQSODuplicated(const QString &_qrz, const QString &_date, const QString &_time, const int _band, const int _mode);
-    int getDuplicatedQSOId(const QString &_qrz, const QString &_date, const QString &_time, const int _band, const int _mode);
+    QList<int> isThisQSODuplicated(const QString &_qrz, const QDateTime &_dateTime, const int _band, const int _mode);
+    int getDuplicatedQSOId(const QString &_qrz, const QDateTime &_datetime, const int _band, const int _mode);
     bool isDXCCConfirmed(const int _dxcc, const int _currentLog);
     bool isQSLReceived(const int _qsoId);
     bool isQSLSent(const int _qsoId);
 
-    bool qslSentViaDirect(const int _qsoId, const QString &_updateDate);
-    bool qslSentViaBureau(const int _qsoId, const QString &_updateDate);
-    bool qslRecViaBureau(const int _qsoId, const QString &_updateDate);
-    bool qslRecViaBureau(const int _qsoId, const QString &_updateDate, const bool _queueSentQSL);
-    bool qslRecViaDirect(const int _qsoId, const QString &_updateDate);
-    bool qslRecViaDirect(const int _qsoId, const QString &_updateDate, const bool _queueSentQSL);
-    bool qslSentAsRequested(const int _qsoId, const QString &_updateDate);
-    bool qslRecAsRequested(const int _qsoId, const QString &_updateDate);
-    bool setClubLogSent(const int _qsoId, const QString &_st, const QString &_updateDate);
+    bool qslSentViaDirect(const int _qsoId, const QDate &_updateDate);
+    bool qslSentViaBureau(const int _qsoId, const QDate &_updateDate);
+    bool qslRecViaBureau(const int _qsoId, const QDate &_updateDate);
+    bool qslRecViaBureau(const int _qsoId, const QDate &_updateDate, const bool _queueSentQSL);
+    bool qslRecViaDirect(const int _qsoId, const QDate &_updateDate);
+    bool qslRecViaDirect(const int _qsoId, const QDate &_updateDate, const bool _queueSentQSL);
+    bool qslSentAsRequested(const int _qsoId, const QDate &_updateDate);
+    bool qslRecAsRequested(const int _qsoId, const QDate &_updateDate);
+    bool setClubLogSent(const int _qsoId, const QString &_st, const QDate &_updateDate);
+    bool setLoTWQSLRec (const int _qsoId, const QString &_st, const QDate &_updateDate);
 
     bool isHF(const int _band);
     bool isWARC(const int _band);
@@ -132,16 +149,36 @@ public:
 
     bool updateAwardDXCC();
     bool updateAwardWAZ();
+    // QRZ.com
+    bool QRZCOMModifyFullLog(const int _currentLog); // Mark all the log as modified to be sent to QRZ.com
+     bool QRZCOMSentQSOs(const QList<int> &_qsos); // Mark as uploaded
+    // QRZ.com
+    //EQSL
+    bool eQSLModifyFullLog(const int _currentLog); // Mark all the log as modified to be sent to eQSL
+    bool eQSLSentQSOs(const QList<int> &_qsos); // Mark as uploaded
 
+    //EQSL
+
+    //CLUBLOG
+    bool clublogSentQSOs(const QList<int> &_qsos); // Mark as uploaded
+    bool clublogModifyFullLog(const int _currentLog); // Mark all the log as modified to be sent to CLubLog
+    // CLUBLOG
 
     //LOTW
-    bool lotwSentQueue(const QString &_updateDate, const int _currentLog);          // Mark LOTW QSL SENT as Q (Queued)
-    bool lotwSentYes(const QString &_updateDate, const int _currentLog, const QString &_station);         // Update LOTW QSL SENT marked as Q as Y (Queued)
+    bool lotwSentQueue(const QDate &_updateDate, const int _currentLog);          // Mark LOTW QSL SENT as Q (Queued)
+    bool lotwSentYes(const QDate &_updateDate, const int _currentLog, const QString &_station);         // Update LOTW QSL SENT marked as Q as Y (Queued)
     bool lotwSentQSOs(const QList<int> &_qsos);
-    int lotwUpdateQSLReception (const QString &_call, const QString &_qso_date, const QString &_time_on, const QString &_band, const QString &_mode, const QString &_qslrdate);
+    int lotwUpdateQSLReception (const QString &_call, const QDateTime &_dateTime, const QString &_band, const QString &_mode, const QDate &_qslrdate);
     QList<int> getQSOsListLoTWNotSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justQueued=true);
+    QStringList getQSOsListLoTWNotSent2(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justQueued=true);
     QStringList getQSODetailsForLoTWDownload(const int _id);
 
+    QList<int> getQSOsListeQSLNotSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justQueued=true);
+
+    QList<int> getQSOsListClubLogToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true);
+    QList<int> getQSOsListEQSLToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true);
+    QList<int> getQSOsListQRZCOMToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true);
+
     int getContinentIdFromContinentShortName(const QString &_n);
     QString getContinentShortNameFromEntity(const int _n);
     int getContinentIdFromEntity(const int _n);
@@ -227,6 +264,8 @@ public:
     QStringList getQSLSentList();
     QStringList getClubLogStatusList();
     QStringList getQSLViaList();
+    int getHowManyQSOPerPropMode(const QString &_p, const int _logn);
+
 
     //QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
 
@@ -249,9 +288,12 @@ public:
     bool setDXCCAwardStatus(const int _qsoId);
     bool setWAZAwardStatus(const int _qsoId);
 
-
+    //bool addRegionalAward(RegionalAward _regionalAward);
+    bool addDXCCEntitySubdivision(const QString &_name, const QString &_short, const QString &_pref, const QString &_group, const int _regId, const int _dxcc, const int _cq, const int _itu, const QDate &_startDate, const QDate &_endDate, const bool _deleted);
 
     void getFoundInLog(const QString &_txt, const int _log=-1);
+    QString getADIFQSO(const int _qsoId);
+    bool showInvalidCallMessage(const QString &_call);
 
     //bool queryPrepare(const QString &_query);
     //bool queryBind(const QString &_field, const QString &value);
@@ -266,16 +308,20 @@ private:
 
     int getPrefixId(const QString &_qrz);
     QString changeSlashAndFindPrefix(const QString &_qrz);
-
+    QSO *qso;
     bool searching;
     int executionN;
     Utilities *util;
     //QSqlQuery preparedQuery;
     //QSqlRelationalTableModel *logModel;
+private slots:
+    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, const int _level=7);
 
 signals:
     void qsoFound(const QStringList _qs); // Each: QString with format: Fieldname:value
     void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+    void debugLog(QString functionFailed, QString errorCode, int level); // emitted as the KLog application log
 
 };
-#endif // DATAPROXY_SQLITE_H
+
+#endif //DATAPROXY_SQLITE_H
