@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 #include <QObject>
@@ -74,9 +74,10 @@ private slots:
 
 signals:
     void actionReturnDownload(const int _i);
-    void done();
+    void done(bool _success);
     void actionShowProgres(qint64 received, qint64 total);
     void actionError(const int _i);
+    void downloadStopped();
 
 
 };
