@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 #include <QWidget>
@@ -31,7 +31,7 @@
 //#include <QTableView>
 #include "awards.h"
 #include "world.h"
-#include "dataproxy.h"
+#include "dataproxy_sqlite.h"
 #include "locator.h"
 
 
@@ -41,38 +41,45 @@ class DXCCStatusWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit DXCCStatusWidget(DataProxy *dp, const QString _parentFunction, QWidget *parent = nullptr);
+    explicit DXCCStatusWidget(DataProxy_SQLite *dp, const QString &_parentFunction, QWidget *parent = nullptr);
     ~DXCCStatusWidget();
     
     void update();    
     //void awardsUpdated();
-    void setBands(const QStringList _ent, const bool _creating = false); // Receives the list of bandIDs
+    void setBands(const QStringList &_ent, const bool _creating = false); // Receives the list of bandIDs
     void setCurrentLog(const int _logN);
-    void setMyLocator(const QString _loc);
+    void setMyLocator(const QString &_loc);
 
     void refresh();
 
 signals:
-    void showQso(const int _qsoid); // identified QSO double clicking on DXCC
+    //void showQso(const int _qsoid); // identified QSO double clicking on DXCC
     void showQsos(QList<int> _qsos);
     //void updateAwards();
 
 public slots:
     //void slotSearchLineEditTextChanged();
     void slotRefreshButtonClicked();
+
+private slots:
+    //void slotRightButton(const QPoint& pos);
+    //void slotWikipedia();
     void slotItemEntered(QTableWidgetItem  * item );
     void slotItemDoubleClicked(QTableWidgetItem  * item );
 
+
 private:
     void createUI();
     void setDefaultBands();
-    void addEntity(QStringList const _ent); // DXCC id, bandid, bandid, ...
-    //QStringList sortBandNamesBottonUp(const QStringList _qs);
+    void addEntity(const QStringList &_ent); // DXCC id, bandid, bandid, ...
+//    void showMenuRightButtonFromLogCreateActions();
+//    void righButtonFromLogMenu(const int trow);
+
 
     QTableWidget *dxccView;
     Awards *awards;
     World *world;
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
     Locator *locator;
 
     QHeaderView *hv, *hh;
@@ -86,6 +93,8 @@ private:
     int logNumber, tempLog; // log in use in the log / log to be used in the widget
     QString loc; // The locator of the user.
 
+    QAction *showDXCCWikipediaAct;
+
 };
 
 #endif // DXCCSTATUSWIDGET_H
