@@ -704,7 +704,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
         (fields.at(0)).toFloat(&FirstFrecOK); // Just to see if the first string is a frecuency
 
         if ( (fields.at(0) == "DX" ) && (fields.at(1) == "de" ) )
-        { // DX de EA4K: 21200.1 EA0JC The comment 1550
+        { // DX de EA0XXX: 21200.1 EA0K The comment 1550
 
             if ( world->getQRZARRLId(fields.at(4))> 0 )
             {
@@ -738,7 +738,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
         }
         //else if (( isAFrecuency(fields.at(0) ) ) && ( isACall(fields.at(1)) ) )
         else if ( (((fields.at(0)).toDouble()) > 0.0 )&& ( world->getQRZARRLId(fields.at(1))> 0 ) )
-        { // 14205.0 EA0JC    5-Mar-2012 1500Z    <EA4K>
+        { // 14205.0 EA0K   5-Mar-2012 1500Z    <EA0XXX>
 
             dxCallsign = (fields.at(1)).toUpper();
             dxFreq = fields.at(0);
@@ -815,8 +815,8 @@ void DXClusterWidget::saveSpot(const QString &_spot)
         {
               //qDebug() << "DXClusterWidget::saveSpot: File Open" << endl;
             QTextStream out(saveSpotsFile);
-            //out << _spot << endl;
-            out << (QDateTime::currentDateTime()).toString("yyyy/MM/dd-hh:mm:ss") << " - " << _spot  << endl;
+
+            out << util->getDateTimeSQLiteStringFromDateTime(QDateTime::currentDateTime()) << " - " << _spot  << endl;
             saveSpotsFile->close();
         }
         else {
