@@ -45,16 +45,17 @@
 #include "dataproxy_sqlite.h"
 #include "dataproxy_sqlite.h"
 #include "utilities.h"
+#include "qso.h"
 
 
-
+/*
 enum
 {
     CQZones = 40,
     ITUZones = 90,
     DXCCEntities = 521 // http://www.adif.org/adif302.htm#Country%20Codes
 };
-
+*/
 //enum ExportMode {ModeLotW, ModeADIF};
 
 class FileManager : public QWidget
@@ -68,15 +69,17 @@ public:
     ~FileManager();
     //bool readAdif(const QString& tfileName, const int logN);
     bool adifReadLog(const QString& tfileName, const int logN);
-    QList<int> adifLoTWReadLog(const QString& tfileName);
-    QList<int> adifLoTWLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN);
-    //QList<int> adifLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN, const bool LoTWOnly);
-    QList<int> adifLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN, const ExportMode _em);
+    QList<int> adifLoTWReadLog2(const QString& fileName, const int logN);
+    QList<int> adifLoTWReadLog(const QString& tfileName, const int logN);
+    //QList<int> adifLoTWLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN);
+    //QList<int> (const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN, const bool LoTWOnly);
+
+    bool adifQSOsExport(const QString& _fileName, QList<int> _qsos);
+    QList<int> adifLogExportReturnList(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN, const ExportMode _em);
     bool adifLogExport(const QString& _fileName, const int _logN);
-   // QList<int> adifLogExportDates(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN);
     bool adifLogExportMarked(const QString& _fileName);
     bool adifReqQSLExport(const QString& _fileName);
-    bool cabrilloLogExport(const QString& _fileName, const QString &_contestType, const int logNconst);
+    //bool cabrilloLogExport(const QString& _fileName, const QString &_contestType, const int logNconst);
     bool modifySetupFile(const QString& _filename, const QString &_field, const QString &_value);
     void setVersion(const QString &_version);
     QDateTime getDateTimeOfLastBackup();
@@ -84,18 +87,21 @@ public:
 
 
 private:    
+
     bool adifLogExportToFile(const QString& _fileName, const int _logN, bool justMarked, bool _qslRequested, bool _lotw);
-    bool cabrilloLogExportToFile(const QString& _fileName, const int logNconst);
-    bool cabrilloLogExportCQWWToFile(const QString& _fileName, const int logNconst);
+    //bool cabrilloLogExportToFile(const QString& _fileName, const int logNconst);
+    //bool cabrilloLogExportCQWWToFile(const QString& _fileName, const int logNconst);
     //bool adifCheckMoreThanOneLog(QFile &_f);
     int howManyLogsInFile(QFile & _f);
     bool fillHashLog(QFile & _f);
     QStringList getListOfLogsInFile(QFile & _f);
     bool writeBackupDate();
     bool getStationCallsignFromUser(const QString &_qrzDX, const QDate &_dt);
-
+    bool showInvalidCallMessage(const QString &_call);
     void showError (const QString &_txt);
 
+    bool askUserToUseAlwaysSameAnswer();
+    bool askUserToAddThisQSOToLog(const QString &_call, const QDateTime _datetime, const QString &_mode, const QString &_band, const double _freq, const QDate _qslrdate);
 
     //QString checkAndFixASCIIinADIF(_data);
 
@@ -108,14 +114,18 @@ private:
     // void writeAdifField(const QString &_field, const QString &_data); // It should possibly receive also the QTextStream
     QString prepareStringLog();
 
+    void writeQuery(QSqlQuery query, QTextStream &out, const ExportMode _em, const bool _justMarked, const bool _onlyRequested, const int _logN);
+    void writeADIFHeader(QTextStream &out, const ExportMode _em, const int _numberOfQsos);
 
     bool dbCreated;
     DataBase *db;
+
     //float softwareVersion;
     //DataProxy_SQLite *dataProxy;
     DataProxy_SQLite *dataProxy;//, *dataProxyPrepared;
 
-    Utilities *util;    
+    Utilities *util;
+    //QSO *qso;
 
     bool rstTXDefault, rstRXDefault; // If true and a log is not including RST, 59 is automatically added
 
