@@ -24,7 +24,7 @@ public:
     QString getNameFromModelId(const int _id);
     void setModelId(const int _id);
     void setPort(const QString &_port);
-    void setPool(const int _milsecs);
+    void setPoll(const int _milsecs);
 
     void setData(const QString &_data);
     void setStop(const QString &_stop);
@@ -44,7 +44,7 @@ public:
 
     void init(bool _active);
     void stop();
-    void readRadio();
+    void readRadio(bool _forceRead);
     bool isRunning();
     void clean();
     void checkErrorCountAndStop();
@@ -61,6 +61,7 @@ public slots:
     void slotTimer();
 
 private:
+    void readRadioInternal(bool _forceRead);
     static int addRigToList(const struct rig_caps* caps, void* data);
     QString hamlibMode2Mode(rmode_t _rmode);
     rmode_t mode2HamlibMode(const QString &_m);
@@ -95,7 +96,7 @@ private:
     QString flowControl;            // default QSerialPort::NoFLowControl
     QString parity;                 // default QSerialPort::NoParity
     QString serialPort;
-    int pollInterval;           // Pool interval in mSecs
+    int pollInterval;           // Poll interval in mSecs
     int errorCount;            // Number of times that the rig has returned an error since last time OK.
     bool rigLaunched;
     bool readOnlyMode;          // If true, KLog will not modify any parameter (freq/mode...) in the radio. KLog just will follow the radio.
