@@ -20,7 +20,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
  *                                                                           *
  *****************************************************************************/
 
@@ -28,6 +28,7 @@
 #define LOCATOR_H
 #include <math.h>
 #include <QString>
+#include <QRegularExpression>
 
 
 
@@ -35,7 +36,7 @@ const double PI = 3.141592654; //http://en.wikipedia.org/wiki/Pi
 const bool LATITUDE = false;
 const bool LONGITUDE = true;
 const double EARTH_RADIUS = 6371; //http://en.wikipedia.org/wiki/Earth_radius
-const bool RADIAN = 180.0/PI;
+const double RADIAN = 180.0/PI;
 const double DEG_TO_RAD = PI/180.0;
 const double KM_IN_A_MILE = 1.609344;
 
@@ -57,20 +58,20 @@ public:
   int getDistance(const double lon1, const double lat1, const double lon2, const double lat2, const bool _imperialSystem);
   int getDistanceBetweenLocators (const QString& tlocator1, const QString& tlocator2, const bool _imperialSystem);
   //int getDistanceMilles(const double lon1, const double lat1, const double lon2, const double lat2);
-  void degTodms(const double deg);
-  double dmsTodeg (int deg, int min, int sec);
+  //void degTodms(const double deg);
+  //double dmsTodeg (int deg, int min, int sec);
   
   bool checkCoords(const double lon1, const double lat1);
 
 
 private:
   //bool valid;
-  QString myLocator;
-  QString testLocator;
-  QString otherLocator;
-  QChar theChar;
+  //QString myLocator;
+  //QString testLocator;
+  //QString otherLocator;
+  //QChar theChar;
   //double my_lon, my_lat, other_lon, other_lat, beam, testNumb;
-  int ideg, imin, isec;
+  //int ideg, imin, isec;
 
 
 };
