@@ -90,14 +90,12 @@ This should be coherent with the logview
      q.next();
      rec = q.record(); // Number of columns
 
-        //qDebug() << "LogModel::createlogModel - columns: " << QString::number(rec.count()) << endl;
-
-
+    //qDebug() << "LogModel::createlogModel - columns: " << QString::number(rec.count()) << endl;
 
      nameCol = rec.indexOf("bandid");
      setRelation(nameCol, QSqlRelation("band", "id", "name"));
 
-     nameCol = rec.indexOf("modeid");     
+     nameCol = rec.indexOf("modeid");
      setRelation(nameCol, QSqlRelation("mode", "id", "submode"));
 
      nameCol = rec.indexOf("id");
@@ -106,11 +104,8 @@ This should be coherent with the logview
      nameCol = rec.indexOf("qso_date");
      setHeaderData(nameCol, Qt::Horizontal, tr("Date"));
 
-     nameCol = rec.indexOf("time_on");
-     setHeaderData(nameCol, Qt::Horizontal, tr("Time"));
-
      nameCol = rec.indexOf("call");
-     setHeaderData(nameCol, Qt::Horizontal,tr("QRZ"));
+     setHeaderData(nameCol, Qt::Horizontal,tr("Callsign"));
 
      nameCol = rec.indexOf("bandid");
      setHeaderData(nameCol, Qt::Horizontal, tr("Band"));
