@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 #include <QDebug>
@@ -30,20 +30,20 @@
 #include <QSqlQuery>
 #include <QSqlRecord>
 #include <QSqlError>
-#include "dataproxy.h"
+#include "dataproxy_sqlite.h"
 
 
 class LogModel : public QSqlRelationalTableModel
 {
     Q_OBJECT
 public:
-    LogModel(DataProxy *dp, QObject *parent);
+    LogModel(DataProxy_SQLite *dp, QObject *parent);
     void createlogModel(const int _i);
 
 private:
     void setColumnsToDX();
     //QSqlRelationalTableModel *logModel;
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
 
 signals:
     void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
