@@ -33,11 +33,12 @@ LogWindow::LogWindow(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
     dataProxy = dp;
     //sortingThroughProxyModel = false;
     logModel = new LogModel(dataProxy, this);
+    util = new Utilities;
     connect(logModel, SIGNAL(queryError(QString, QString, int, QString)), this, SLOT(slotQueryErrorManagement(QString, QString, int, QString)) );
     logView = new QTableView;
-    //dxccStatusWidget = new DXCCStatusWidget(dataProxy);
-    elogClublog = new eLogClubLog();
 
+    //dxccStatusWidget = new DXCCStatusWidget(dataProxy);
+    //elogClublog = new eLogClubLog();
     currentLog = -1;
     //proxyModel = new LogViewSortFilterProxyModel(this);
 
@@ -55,22 +56,7 @@ LogWindow::~LogWindow()
 {
 //    emit clearError();
 }
-/*
-void LogWindow::setProxyModel (const bool _p)
-{
-    sortingThroughProxyModel = _p;
-    if (sortingThroughProxyModel)
-    {
-        logView->setModel(proxyModel);
-        logView->setCurrentIndex(proxyModel->index(0, 0));
-    }
-    else
-    {
-        logView->setModel(logModel);
-        logView->setCurrentIndex(logModel->index(0, 0));
-    }
-}
-*/
+
 
 void LogWindow::sortColumn(const int _c)
 {
@@ -111,46 +97,24 @@ void LogWindow::createlogPanel(const int _currentLog)
     logView->setModel(logModel);
     logView->setCurrentIndex(logModel->index(0, 0));
 
+
     //setProxyModel(false);
 
     //QString contestMode = dataProxy->getLogTypeOfUserLog(currentLog);
     setColumnsToDX();
     sortColumn(1);  //Initial sort by column 1 (date & time)
 
-/*
-    if (contestMode == "DX")
-    {
-           //qDebug() << "LogWindow::createlogPanel: DX"  << endl;
-        setColumnsToDX();
-    }
-    else if (contestMode == "CQ-WW-SSB")
-    {
-           //qDebug() << "LogWindow::createlogPanel: CQ-WW-SSB"  << endl;
-    }
 
-    else
-    {
-        // THIS POINT SHOULD NOT BE REACHED. It means that there is a kind of contest not supported.
-        // Maybe the way should be to move ALL the actions from DX here.
-           //qDebug() << "LogWindow::createlogPanel: No log type found!"  << endl;
-    }
-*/
-    logView->setItemDelegate(new QSqlRelationalDelegate(this));
-    logView->setSelectionMode(QAbstractItemView::SingleSelection);
+    //qDebug() << "LogWindow::createlogPanel " << logModel->record(0).field(1).value().toString() << endl;
+    //logView->setItemDelegateForColumn(1, new ItemDelegate);
+    //logView->setItemDelegate(new QSqlRelationalDelegate(this));
+
+    logView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     logView->setSelectionBehavior(QAbstractItemView::SelectRows);
     logView->resizeColumnsToContents();
     logView->horizontalHeader()->setStretchLastSection(true);
     logView->sortByColumn(1);
-    /*
-    if (sortingThroughProxyModel)
-    {
-        proxyModel->sort(1);
-    }
-    else
-    {
-        logView->sortByColumn(1);
-    }
-    */
+
 
 }
 
@@ -177,8 +141,6 @@ void LogWindow::setColumnsToDX()
 
     columns = rec.indexOf("qso_date");
     logView->setColumnHidden(columns, false);
-    columns = rec.indexOf("time_on");
-    logView->setColumnHidden(columns, false);
     columns = rec.indexOf("call");
     logView->setColumnHidden(columns, false);
     columns = rec.indexOf("rst_sent");
@@ -203,6 +165,7 @@ void LogWindow::refresh()
 void LogWindow::createActions()
 {
     createActionsCommon();
+    showMenuRightButtonFromLogCreateActions();
 }
 
 void LogWindow::createActionsCommon()
@@ -217,21 +180,67 @@ void LogWindow::slotRighButtonFromLog(const QPoint& pos)
 {
        //qDebug() << "LogWindow::slotshowRighButtonFromLog"  << endl;
     int row = (logView->indexAt(pos)).row();
-    showMenuRightButtonFromLogCreateActions();
-    righButtonFromLogMenu(row);
+    QItemSelectionModel *select = logView->selectionModel();
+    QModelIndexList list = select->selectedRows();
+
+    if (select->hasSelection() && (list.length()>1) )
+    {       
+        rightButtonMultipleFromLogMenu();
+    }
+    else
+    {
+        rightButtonFromLogMenu(row);
+    }
+
+
+
     //TODO: To be added to the logWindow and create an action that emist the QSO id
 }
-
-void LogWindow::righButtonFromLogMenu(const int trow)
+void LogWindow::rightButtonMultipleFromLogMenu()
 {
-       //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  " << QString::number(trow) << endl;
+    //qDebug() << "LogWindow::slotshowRighButtonMultipleFromLogMenu:  "  << endl;
+
+    QMenu menu(this);
+    menu.addAction(multipleDelQSOsFromLogAct);
+    //menu.addSeparator();
+    menu.addAction(multipleExportToADIFFromLogAct);
+    /*
+    menu.addSeparator();
+
+    QMenu *menuEQsl = menu.addMenu(tr("eQSL"));
+    menuEQsl->addAction(multipleQueueForLoTWFromLogAct);
+    menuEQsl->addAction(multipleQueueForClubLogFromLogAct);
+    menuEQsl->addAction(multipleQueueForEQSLFromLogAct);
+    menu.addMenu(menuEQsl);
+
+    QMenu *menuQslS = menu.addMenu(tr("QSL"));
+
+    QMenu *menuSentQsl = menuQslS->addMenu(tr("QSLs Send"));
+    menuSentQsl->addAction(multipleQslSentViaBureauFromLogAct);
+    menuSentQsl->addAction(multipleQslSentViaDirectFromLogAct);
+
+    QMenu *menuRcvdQsl = menuQslS->addMenu(tr("QSLs Rcvd"));
+    menuRcvdQsl->addAction(multipleQslRecViaBureauFromLogAct);
+    menuRcvdQsl->addAction(multipleQslRecViaDirectFromLogAct);
+    */
+
+    menu.addSeparator();
+    menu.addAction(multipleSelectAll);
+    menu.addAction(multipleDeselectAll);
+    menu.exec(QCursor::pos());
+}
+
+void LogWindow::rightButtonFromLogMenu(const int trow)
+{
+    //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  " << QString::number(trow) << endl;
 
     int _qsoID = ((logModel->index(trow, 0)).data(0)).toInt();
-       //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  QSOid: " << QString::number(_qsoID) << endl;
+    //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  QSOid: " << QString::number(_qsoID) << endl;
     bool qslReceived = isQSLReceived(_qsoID);
     bool qslSent = isQSLSent(_qsoID);
     QMenu menu(this);
-
+    //menu.addAction(multipleQueueForQRZCOMFromLogAct);
+    menu.addAction(multipleExportToADIFFromLogAct);
     menu.addAction(delQSOFromLogAct);
     delQSOFromLogAct->setData(trow);
     menu.addAction(qsoToEditFromLogAct);
@@ -241,7 +250,6 @@ void LogWindow::righButtonFromLogMenu(const int trow)
     menu.addAction(checkDXHeatFromLogAct);
     checkDXHeatFromLogAct->setData(trow);
 
-
         menu.addSeparator();
         if (qslSent)
         {
@@ -266,6 +274,9 @@ void LogWindow::righButtonFromLogMenu(const int trow)
             qslRecViaBureauFromLogAct->setData(trow);
             qslRecViaDirectFromLogAct->setData(trow);
         }
+        menu.addSeparator();
+        menu.addAction(multipleSelectAll);
+        menu.addAction(multipleDeselectAll);
     menu.exec(QCursor::pos());
 }
 
@@ -345,24 +356,80 @@ void LogWindow::showMenuRightButtonFromLogCreateActions()
     checkDXHeatFromLogAct->setStatusTip(tr("Check this callsign in DXHeat.com"));
     connect(checkDXHeatFromLogAct, SIGNAL(triggered()), this, SLOT( slotCheckDXHeatCom() ));
 
+    multipleDelQSOsFromLogAct = new QAction(tr("Delete selected QSOs"), this);
+    //multipleDelQSOsFromLogAct->setShortcut(Qt::CTRL + Qt::Key_D);
+    multipleDelQSOsFromLogAct->setStatusTip(tr("Delete the selected QSOs"));
+    connect(multipleDelQSOsFromLogAct, SIGNAL(triggered()), this, SLOT(slotQSOsDeleteFromLog()));
 
+    multipleExportToADIFFromLogAct = new QAction(tr("Export to ADIF"), this);
+    multipleExportToADIFFromLogAct->setStatusTip(tr("Export the selected QSOs to an ADIF file."));
+    connect(multipleExportToADIFFromLogAct, SIGNAL(triggered()), this, SLOT(slotQSOsExportFromLog()));
+
+    //multipleQueueForQRZCOMFromLogAct = new QAction(tr("Upload to QRZ.com"), this);
+    //multipleQueueForQRZCOMFromLogAct->setStatusTip(tr("Send the selected QSOs to QRZ.com."));
+    //connect(multipleQueueForQRZCOMFromLogAct, SIGNAL(triggered()), this, SLOT(slotQSOsQRZUploadFromLog()));
+
+
+    multipleQueueForLoTWFromLogAct = new QAction(tr("Upload to LoTW"), this);
+    multipleQueueForLoTWFromLogAct->setStatusTip(tr("Upload the selected QSOs to LoTW"));
+    connect(multipleQueueForLoTWFromLogAct, SIGNAL(triggered()), this, SLOT(slotQSOsUploadToLoTWFromLog()));
+
+    multipleQueueForClubLogFromLogAct = new QAction(tr("Upload to ClubLog"), this);
+    multipleQueueForClubLogFromLogAct->setStatusTip(tr("Upload the selected QSOs to ClubLog"));
+    connect(multipleQueueForClubLogFromLogAct, SIGNAL(triggered()), this, SLOT(slotQSOsUploadToClubLogFromLog()));
+
+    multipleQueueForEQSLFromLogAct = new QAction(tr("Upload to eQSL.cc"), this);
+    multipleQueueForEQSLFromLogAct->setStatusTip(tr("Upload the selected QSOs to eQSL.cc"));
+    connect(multipleQueueForEQSLFromLogAct, SIGNAL(triggered()), this, SLOT(slotQSOsUploadToEQSLFromLog()));
+
+   multipleQslSentViaBureauFromLogAct = new QAction(tr("Via bureau"), this);
+   multipleQslSentViaBureauFromLogAct->setStatusTip(tr("Send these QSLs via bureau"));
+   connect(multipleQslSentViaBureauFromLogAct, SIGNAL(triggered()), this, SLOT( slotMultipleQSLSentViaBureauFromLog() ));
+
+   multipleQslSentViaDirectFromLogAct = new QAction(tr("Direct"), this);
+   multipleQslSentViaDirectFromLogAct->setStatusTip(tr("Send these QSLs via direct"));
+   connect(multipleQslSentViaDirectFromLogAct, SIGNAL(triggered()), this, SLOT( slotMultipleQSLSentViaDirectFromLog()   ));
+
+   multipleQslRecViaBureauFromLogAct = new QAction(tr("Via bureau"), this);
+   multipleQslRecViaBureauFromLogAct->setStatusTip(tr("QSLs received via bureau"));
+   connect(multipleQslRecViaBureauFromLogAct, SIGNAL(triggered()), this, SLOT( slotMultipleQSLRecViaBureauFromLog() ));
+
+   multipleQslRecViaDirectFromLogAct = new QAction(tr("Direct"), this);
+   multipleQslRecViaDirectFromLogAct->setStatusTip(tr("QSLs received via direc&t"));
+   connect(multipleQslRecViaDirectFromLogAct, SIGNAL(triggered()), this, SLOT( slotMultipleQSLRecViaDirectFromLog() ));
+
+   multipleDeselectAll = new QAction(tr("Select none"), this);
+   multipleDeselectAll->setStatusTip(tr("Remove all selections"));
+   connect(multipleDeselectAll, SIGNAL(triggered()), this, SLOT( slotQSOsDeselectAll() ));
+
+   multipleSelectAll = new QAction(tr("Select all"), this);
+   multipleSelectAll->setStatusTip(tr("Select all the QSOs"));
+   connect(multipleSelectAll, SIGNAL(triggered()), this, SLOT( slotQSOsSelectAll() ));
 }
 
+void LogWindow::slotQSOsSelectAll()
+{
+    logView->selectAll();
+}
 
+void LogWindow::slotQSOsDeselectAll()
+{
+    logView->selectionModel()->clearSelection();
+}
 
 void LogWindow::slotQSLSentViaBureauFromLog()
 {
       //qDebug() << "LogWindow::slotQSLSentViaBureauFromLog: " << (qslSentViaBureauFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
     int _qsoId = ((logModel->index( ( (qslSentViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     qslSentViaBureau(_qsoId);
-
 }
 
 void LogWindow::slotQSLSentViaDirectFromLog()
 {
        //qDebug() << "LogWindow::slotQSLSentViaDirectFromLog: " << (qslSentViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
-    int _qsoId = ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
-    dataProxy->qslSentViaDirect(_qsoId, (QDateTime::currentDateTime()).toString("yyyy/MM/dd"));
+     int _qsoId = ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
+    //dataProxy->qslSentViaDirect(_qsoId, (QDateTime::currentDateTime()).toString("yyyy-MM-dd"));
+    dataProxy->qslSentViaDirect(_qsoId, QDate::currentDate());
 
 }
 
@@ -405,12 +472,22 @@ void LogWindow::slotQSOToEditFromLog()
     //TODO: To be added to the logWindow and create an action that emit the QSO id
 }
 
+void LogWindow::deleteQSO(const int _qsoId)
+{
+   //qDebug() << "LogWindow::deleteQSO " << QString::number(_qsoId) << endl;
+    emit actionDeleteQSO(_qsoId);
+}
 
-
+/*
 void LogWindow::deleteQSO(const int _qsoID)
 {
        //qDebug() << "LogWindow::deleteQSO: " << QString::number(_qsoID) << endl;
-    elogClublog->deleteQSO(dataProxy->getClubLogRealTimeFromId(_qsoID));
+
+
+
+
+    emit actionDeleteQSO(_qsoID);
+    //elogClublog->deleteQSO(dataProxy->getClubLogRealTimeFromId(_qsoID));
     dataProxy->deleteQSO(_qsoID);
 
     //logModel->removeRow((delQSOFromLogAct->data()).toInt()); //TODO: This has been replaced by the previous line
@@ -421,12 +498,12 @@ void LogWindow::deleteQSO(const int _qsoID)
     emit updateSearchText();
 
 }
-
+*/
 void LogWindow::slotQsoDeleteFromLog()
 {
       //qDebug() << "LogWindow::slotQsoDeleteFromLog: " << (delQSOFromLogAct->data()).toString() << endl;
     //TODO: To be added to the logWindow and create an action that emist the QSO id
-
+/*
     QMessageBox msgBox;
     msgBox.setIcon(QMessageBox::Information);
     msgBox.setText(tr("You have requested to delete this QSO."));
@@ -434,11 +511,11 @@ void LogWindow::slotQsoDeleteFromLog()
     msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
     msgBox.setDefaultButton(QMessageBox::No);
     int ret = msgBox.exec();
-
+*/
     int QSOid = ((logModel->index((delQSOFromLogAct->data()).toInt(), 0)).data(0)).toInt();
-
+    deleteQSO(QSOid);
       //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): " << QString::number(QSOid) << endl;
-
+    /*
     switch (ret) {
       case QMessageBox::Yes:
           //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): -1" << endl;
@@ -452,19 +529,123 @@ void LogWindow::slotQsoDeleteFromLog()
           // should never be reached
           break;
     }
+    */
 }
 
+void LogWindow::slotQSOsDeleteFromLog()
+{
+    //qDebug() << "LogWindow::slotQSOsDeleteFromLog" << endl;
+    QItemSelectionModel *select = logView->selectionModel();
+    QList<int> qsos;
+    qsos.clear();
+    if (select->hasSelection())
+    {
+        QModelIndexList list = select->selectedRows();
+        foreach (QModelIndex index, list)
+        {
+            qsos.append(index.data(0).toInt());
+            //qDebug() << "LogWindow::slotshowRighButtonFromLog: " << QString::number(index.row())  << endl;
+            //qDebug() << "LogWindow::slotshowRighButtonFromLog: " << QString::number(index.data(0).toInt())  << endl;
+        }
+    }
+    if (qsos.length()>0)
+    {
+        emit deleteTheseQSOs(qsos);
+    }
+}
+
+void LogWindow::slotQSOsExportFromLog()
+{
+   //qDebug() << "LogWindow::slotQSOsExportFromLog" << endl;
+    QItemSelectionModel *select = logView->selectionModel();
+    QList<int> qsos;
+    qsos.clear();
+    if (select->hasSelection())
+    {
+        QModelIndexList list = select->selectedRows();
+        foreach (QModelIndex index, list)
+        {
+            qsos.append(index.data(0).toInt());
+           //qDebug() << "LogWindow::slotQSOsExportFromLog: " << QString::number(index.row())  << endl;
+           //qDebug() << "LogWindow::slotQSOsExportFromLog: " << QString::number(index.data(0).toInt())  << endl;
+        }
+    }
+    if (qsos.length()>0)
+    {
+        emit exportToADIFTheseQSOs(qsos);
+    }
+   //qDebug() << "LogWindow::slotQSOsExportFromLog - END - " << QString::number(qsos.length()) << endl;
+}
+
+
+void LogWindow::slotQSOsUploadToLoTWFromLog()
+{
+    //qDebug() << "LogWindow::slotQSOsUploadToLoTWFromLog - TO BE IMPLEMENTED" << endl;
+}
+
+void LogWindow::slotQSOsUploadToClubLogFromLog()
+{
+    //qDebug() << "LogWindow::slotQSOsUploadToClubLogFromLog - TO BE IMPLEMENTED" << endl;
+}
+
+void LogWindow::slotQSOsQRZUploadFromLog()
+{
+   //qDebug() << "LogWindow::slotQSOsQRZUploadFromLog - TO BE IMPLEMENTED" << endl;
+    QItemSelectionModel *select = logView->selectionModel();
+    QList<int> qsos;
+    qsos.clear();
+    if (select->hasSelection())
+    {
+        QModelIndexList list = select->selectedRows();
+        foreach (QModelIndex index, list)
+        {
+            qsos.append(index.data(0).toInt());
+            //qDebug() << "LogWindow::slotQSOsQRZUploadFromLog: " << QString::number(index.row())  << endl;
+            //qDebug() << "LogWindow::slotQSOsQRZUploadFromLog: " << QString::number(index.data(0).toInt())  << endl;
+        }
+    }
+    if (qsos.length()>0)
+    {
+        emit uploadToQRZcomTheseQSOs(qsos);
+    }
+}
+
+void LogWindow::slotQSOsUploadToEQSLFromLog()
+{
+    //qDebug() << "LogWindow::slotQSOsUploadToEQSLFromLog - TO BE IMPLEMENTED" << endl;
+}
+
+void LogWindow::slotMultipleQSLSentViaBureauFromLog()
+{
+    //qDebug() << "LogWindow::slotMultipleQSLSentViaBureauFromLog - TO BE IMPLEMENTED" << endl;
+}
+
+void LogWindow::slotMultipleQSLSentViaDirectFromLog()
+{
+    //qDebug() << "LogWindow::slotMultipleQSLSentViaDirectFromLog - TO BE IMPLEMENTED" << endl;
+}
+
+void LogWindow::slotMultipleQSLRecViaBureauFromLog()
+{
+    //qDebug() << "LogWindow::slotMultipleQSLRecViaBureauFromLog - TO BE IMPLEMENTED" << endl;
+}
+
+void LogWindow::slotMultipleQSLRecViaDirectFromLog()
+{
+    //qDebug() << "LogWindow::slotMultipleQSLRecViaDirectFromLog - TO BE IMPLEMENTED" << endl;
+}
+
+
 void LogWindow::qslSentViaBureau(const int _qsoId)
 {
-       //qDebug() << "LogWindow::qslSentViaBureau: " << QString::number(_qsoId) << endl;
-
-    dataProxy->qslSentViaBureau(_qsoId, (QDateTime::currentDateTime()).toString("yyyy/MM/dd"));
+       //qDebug() << "LogWindow::qslSentViaBureau: " << QString::number(_qsoId)yyyy-MM-dd
+    dataProxy->qslSentViaBureau(_qsoId, QDate::currentDate());
 }
 
 void LogWindow::qslRecViaBureau(const int _qsoId)
 {
-   //    //qDebug() << "LogWindow::qslRecViaBureau: " << QString::number(_qsoId) << "/" << (dateTime->currentDateTime()).toString("yyyy/MM/dd") << endl;
-    dataProxy->qslRecViaBureau(_qsoId, (QDateTime::currentDateTime()).toString("yyyy/MM/dd"), false);
+   //    //qDebug() << "LogWyyyy-MM-ddRecViaBureau: " << QString::number(_qsoIyyyy-MM-dd<< (dateTime->currentDateTime()).toString("yyyy/MM/dd") << endl;
+    dataProxy->qslRecViaBureau(_qsoId, QDate::currentDate(), false);
     awards->setAwards(_qsoId);   //Update the Award status
 
     refresh();
@@ -474,9 +655,8 @@ void LogWindow::qslRecViaBureau(const int _qsoId)
 
 void LogWindow::qslRecViaDirect(const int _qsoId)
 {
-       //qDebug() << "LogWindow::qslRecViaDirect: " << QString::number(_qsoId) << endl;
-
-    dataProxy->qslRecViaDirect(_qsoId, (QDateTime::currentDateTime()).toString("yyyy/MM/dd"), false);
+       //qDebug() << "LogWindow::qslRecViaDirect: " << QString::number(_qsoId)yyyy-MM-dd
+    dataProxy->qslRecViaDirect(_qsoId, QDate::currentDate(), false);
     awards->setAwards(_qsoId);
 
     refresh();
@@ -491,8 +671,9 @@ void LogWindow::slotQueryErrorManagement(QString functionFailed, QString errorCo
 
 void LogWindow::slotCheckQRZCom()
 {
-    int _qsoId = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
-    QString _qrz = dataProxy->getCallFromId(_qsoId);
+    QString _qrz = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 2)).data(Qt::DisplayRole).toString());
+    //int _qsoId = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
+    //QString _qrz = dataProxy->getCallFromId(_qsoId);
       //qDebug() << "LogWindow::sloTCheckQRZCom: " << _qrz << endl;
     QString url = "https://www.qrz.com/db/" + _qrz;
 
@@ -502,9 +683,11 @@ void LogWindow::slotCheckQRZCom()
 
 void LogWindow::slotCheckDXHeatCom()
 {
-    int _qsoId = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
-    QString _qrz = dataProxy->getCallFromId(_qsoId);
+    QString _qrz = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 2)).data(Qt::DisplayRole).toString());
+    //int _qsoId = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
+    //QString _qrz = dataProxy->getCallFromId(_qsoId);
       //qDebug() << "LogWindow::slotCheckDXHeatCom(): " << _qrz << endl;
     QString url = "https://www.dxheat.com/db/" + _qrz;
     QDesktopServices::openUrl(QUrl(url));
 }
+
