@@ -40,10 +40,12 @@
 #include "logmodel.h"
 #include "awards.h"
 //#include "dxccstatuswidget.h"
-#include "elogclublog.h"
+//#include "elogclublog.h"
+#include "utilities.h"
 //#include "logviewsortfilterproxymodel.h"
 
 //class  LogViewSortFilterProxyModel;
+//class ItemDelegate;
 
 class LogWindow : public  QWidget
 {
@@ -68,11 +70,15 @@ public:
 
 signals:
     void actionQSODoubleClicked(const int _qsoid);
+    void actionDeleteQSO(const int _qsoid);
     void updateAwards();
     void updateSearchText();   
     //void qsoFound(const QStringList _qs); // Each: QString with format: Fieldname:value
     void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
     //void clearError();
+    void deleteTheseQSOs(QList<int> _qsos);
+    void exportToADIFTheseQSOs(QList<int> _qsos);
+    void uploadToQRZcomTheseQSOs(QList<int> _qsos);
 
 private slots:
 
@@ -89,6 +95,18 @@ private slots:
     void slotCheckQRZCom();
     void slotCheckDXHeatCom();
 
+    void slotQSOsDeselectAll();
+    void slotQSOsSelectAll();
+    void slotQSOsDeleteFromLog();
+    void slotQSOsExportFromLog();
+    void slotQSOsUploadToLoTWFromLog();
+    void slotQSOsUploadToClubLogFromLog();
+    void slotQSOsUploadToEQSLFromLog();
+    void slotMultipleQSLSentViaBureauFromLog();
+    void slotMultipleQSLSentViaDirectFromLog();
+    void slotMultipleQSLRecViaBureauFromLog();
+    void slotMultipleQSLRecViaDirectFromLog();
+    void slotQSOsQRZUploadFromLog();
 
 private:    
     void createUI();
@@ -96,7 +114,8 @@ private:
     void createActions();
 
     void deleteQSO(const int _qsoID);
-    void righButtonFromLogMenu(const int trow);
+    void rightButtonFromLogMenu(const int trow);
+    void rightButtonMultipleFromLogMenu();
     void showMenuRightButtonFromLogCreateActions();
 
 
@@ -106,9 +125,10 @@ private:
 
     DataProxy_SQLite *dataProxy;
     LogModel *logModel;
+    //QItemSelectionModel *selectionModel;
     Awards *awards;
     //DXCCStatusWidget *dxccStatusWidget;
-    eLogClubLog *elogClublog;
+    //eLogClubLog *elogClublog;
 
     QTableView *logView;
     QLabel *logLabel;
@@ -122,12 +142,39 @@ private:
     QAction *checkQRZCOMFromLogAct;
     QAction *checkDXHeatFromLogAct;
 
+    //Multiple selection actions
+    QAction *multipleDeselectAll;
+    QAction *multipleSelectAll;
+    QAction *multipleDelQSOsFromLogAct;
+    QAction *multipleExportToADIFFromLogAct;
+    QAction *multipleQueueForLoTWFromLogAct;
+    QAction *multipleQueueForClubLogFromLogAct;
+    QAction *multipleQueueForQRZCOMFromLogAct;
+    QAction *multipleQueueForEQSLFromLogAct;
+    QAction *multipleQslSentViaBureauFromLogAct;
+    QAction *multipleQslSentViaDirectFromLogAct;
+    QAction *multipleQslRecViaBureauFromLogAct;
+    QAction *multipleQslRecViaDirectFromLogAct;
+    //QAction *moveToAnotherLog; // MOves the selected QSOs to another log.
+
     int currentLog;
 
+    Utilities *util;
+
    //LogViewSortFilterProxyModel *proxyModel;
    //bool sortingThroughProxyModel;
 };
+/*
+class ItemDelegate: public QStyledItemDelegate
+{
+    Q_OBJECT
 
+public:
+    ItemDelegate(QWidget *parent=nullptr){}
 
+    QString displayText(const QVariant &value, const QLocale &locale) const;
 
+    //QString displayText (const QVariant &value);
+};
+*/
 #endif // LOGWINDOW_H
