@@ -7,8 +7,9 @@
 
 LoTWUtilities::LoTWUtilities(const QString &_klogDir, const QString &_klogVersion, const QString &_parentFunction, DataProxy_SQLite *dp)
 {
-     //qDebug() << "LoTWUtilities::LoTWUtilities(): " << _klogDir << endl;
+   //qDebug() << "LoTWUtilities::LoTWUtilities(): " << _klogDir << endl;
     dataProxy = dp;
+    calendar = new QCalendarWidget;
     util = new Utilities;    
     manager = new QNetworkAccessManager(this);
 
@@ -27,7 +28,12 @@ LoTWUtilities::LoTWUtilities(const QString &_klogDir, const QString &_klogVersio
 
     pDialog = new QProgressDialog(nullptr);
     pDialog->cancel();
-     //qDebug() << "LoTWUtilities::LoTWUtilities(): - END"  << endl;
+    firstDate = QDate::currentDate();
+    calendar->setToolTip(tr("Double click on the date that you want to use as the start date for downloading QSOs."));
+
+    connect(calendar, SIGNAL(activated(QDate)), this, SLOT(slotCalendarDateSelected(QDate)));
+
+   //qDebug() << "LoTWUtilities::LoTWUtilities(): - END"  << endl;
 }
 
 LoTWUtilities::~LoTWUtilities()
@@ -35,6 +41,14 @@ LoTWUtilities::~LoTWUtilities()
       //qDebug() << "LoTWUtilities::~LoTWUtilities"  << endl;
 }
 
+void LoTWUtilities::slotCalendarDateSelected(const QDate _d)
+{
+   //qDebug() << "LoTWUtilities::slotCalendarDateSelected: " << _d.toString("yyyyMMdd")  << endl;
+    firstDate = _d;
+    startThefullDownload();
+
+}
+
 void LoTWUtilities::setFileName(const QString &_fn)
 {
     //qDebug() << "LoTWUtilities::setFileName: " << _fn  << endl;
@@ -68,7 +82,20 @@ bool LoTWUtilities::selectQuery(const int _queryId)
             return false;
         }
     }
-    lotwQuery = QString("https://lotw.arrl.org/lotwuser/lotwreport.adi?login=%1&password=%2&qso_query=1&qso_qsl=no&qso_owncall=%3&qso_startdate=%4").arg(lotwUser).arg(lotwPassword).arg(stationCallsign).arg(startDate);
+    switch (_queryId)
+    {
+    case 1: // Normal query
+        lotwQuery = QString("https://lotw.arrl.org/lotwuser/lotwreport.adi?login=%1&password=%2&qso_query=1&qso_qsl=no&qso_owncall=%3&qso_startdate=%4").arg(lotwUser).arg(lotwPassword).arg(stationCallsign).arg(startDate);
+        break;
+    case 2:
+        lotwQuery = QString("https://lotw.arrl.org/lotwuser/lotwreport.adi?login=%1&password=%2&qso_query=1&qso_qsl=no&qso_owncall=%3&qso_startdate=%4").arg(lotwUser).arg(lotwPassword).arg(stationCallsign).arg(firstDate.toString("yyyyMMdd"));
+        break;
+    default:
+    {
+        lotwQuery = QString("https://lotw.arrl.org/lotwuser/lotwreport.adi?login=%1&password=%2&qso_query=1&qso_qsl=no&qso_owncall=%3&qso_startdate=%4").arg(lotwUser).arg(lotwPassword).arg(stationCallsign).arg(startDate);
+    }
+    }
+
     if (!savePassword)
     {// We delete the password as soon as possible if the user is not willing to save it
         lotwPassword = QString();
@@ -80,38 +107,65 @@ bool LoTWUtilities::selectQuery(const int _queryId)
     return true;
 }
 
-bool LoTWUtilities::setStationCallSign (const QString &_call)
+bool LoTWUtilities::setStationCallSign(const QString &_call)
 {
-     //qDebug() << "LoTWUtilities::setStationCallSign: " << _call << endl;
+    //qDebug() << "LoTWUtilities::setStationCallSign: " << _call << endl;
     if (!util->isValidCall(_call))
     {
-         //qDebug() << "LoTWUtilities::setStationCallSign: FALSE "  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: FALSE "  << endl;
         return false;
     }
     if (((dataProxy->getStationCallSignsFromLog(-1)).contains(_call)))
     {
-         //qDebug() << "LoTWUtilities::setStationCallSign: TRUE"  << endl;
+       //qDebug() << "LoTWUtilities::setStationCallSign: TRUE"  << endl;
         stationCallsign = _call;
         QDate date = dataProxy->getFirstQSODateFromCall(stationCallsign);
-         //qDebug() << "LoTWUtilities::setStationCallSign: Date: " << startDate  << endl;        
-        //date = QDate::fromString(startDate, "yyyy/MM/dd");
+       //qDebug() << "LoTWUtilities::setStationCallSign: Date: " << startDate  << endl;
         if (date.isValid())
         {
             startDate = date.toString("yyyyMMdd");
-             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate" << startDate  << endl;
+            //qDebug() << "LoTWUtilities::setStationCallSign: StartDate" << startDate  << endl;
         }
         else
         {
             startDate.clear();
-             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate not valid Date" << endl;
+            //qDebug() << "LoTWUtilities::setStationCallSign: StartDate not valid Date" << endl;
             return false;
         }
 
-         //qDebug() << "LoTWUtilities::setStationCallSign: startDate: " << startDate  << endl;
+       //qDebug() << "LoTWUtilities::setStationCallSign: startDate: " << startDate  << endl;
         return true;
     }
-      //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 2"  << endl;
-    return false;
+    else if (dataProxy->getHowManyQSOInLog(-1) <1)
+    {
+       //qDebug() << "LoTWUtilities::setStationCallSign:TRUE Empty log"  << endl;
+        stationCallsign = _call;
+        return true;
+    }
+    else
+    {
+       //qDebug() << "LoTWUtilities::setStationCallSign: Not a single QSO in the log with that StationCallsign: " << stationCallsign  << endl;
+        QMessageBox msgBox;
+        msgBox.setIcon(QMessageBox::Question);
+        msgBox.setWindowTitle(tr("KLog - LoTW Station callsign"));
+        QString aux = QString(tr("There is not a single QSO in the log with that station callsign.") );
+        msgBox.setText(tr("Are you sure that you want to use that station callsign (%1)?").arg(_call));
+        msgBox.setDetailedText(aux);
+        msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
+        msgBox.setDefaultButton(QMessageBox::Yes);
+        int ret = msgBox.exec();
+        //qDebug() << "LoTWUtilities::download: - 13" << endl;
+        if (ret == QMessageBox::Yes)
+        {
+            stationCallsign = _call;
+            return true;
+        }
+        else
+        {
+           //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 2"  << endl;
+            return false;
+        }
+    }
 }
 
 void LoTWUtilities::startRequest(QUrl url)
@@ -125,18 +179,17 @@ void LoTWUtilities::startRequest(QUrl url)
     //reply = manager->get(QNetworkRequest(url));
     reply = manager->get(request);
     //qDebug() << "LoTWUtilities::startRequest - 10"  << endl;
-      // Whenever more data is received from the network,
-      // this readyRead() signal is emitted
-      connect(reply, SIGNAL(readyRead()), this, SLOT(slotReadyRead()));
+    // Whenever more data is received from the network,
+    // this readyRead() signal is emitted
+    connect(reply, SIGNAL(readyRead()), this, SLOT(slotReadyRead()));
 
-      // Also, downloadProgress() signal is emitted when data is received
-      connect(reply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(slotDownloadProgress(qint64)));
-
-      // This signal is emitted when the reply has finished processing.
-      // After this signal is emitted,
-      // there will be no more updates to the reply's data or metadata.
-      connect(reply, SIGNAL(finished()), this, SLOT(slotFinished()));
-       //qDebug() << "LoTWUtilities::startRequest: - END" << endl;
+    // Also, downloadProgress() signal is emitted when data is received
+    connect(reply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(slotDownloadProgress(qint64)));
+    // This signal is emitted when the reply has finished processing.
+    // After this signal is emitted,
+    // there will be no more updates to the reply's data or metadata.
+    connect(reply, SIGNAL(finished()), this, SLOT(slotFinished()));
+    //qDebug() << "LoTWUtilities::startRequest: - END" << endl;
 }
 
 int LoTWUtilities::download()
@@ -156,7 +209,7 @@ int LoTWUtilities::download()
         //qDebug() << "LoTWUtilities::download: - 12" << endl;
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
-        msgBox.setWindowTitle(tr("KLog - File exist"));
+        msgBox.setWindowTitle(tr("KLog - LoTW File already exists"));
         QString aux = QString(tr("There is a file already existing with the name that will be used.") );
         msgBox.setText(tr("The file %1 already exist. Do you want to overwrite?").arg(fileName));
         msgBox.setDetailedText(aux);
@@ -169,11 +222,6 @@ int LoTWUtilities::download()
              //qDebug() << "LoTWUtilities::download - END- 2" << endl;
             return -2;
         }
-        //qDebug() << "LoTWUtilities::download: - 14" << endl;
-        //file->close();
-        //file->remove(fileName);
-        //QFile::remove(fileName);
-        //qDebug() << "LoTWUtilities::download: - 15" << endl;
       }
         //qDebug() << "LoTWUtilities::download: - 20 Filename: -" << fileName << "-" << endl;
         if (!file->isOpen())
@@ -188,9 +236,9 @@ int LoTWUtilities::download()
       {
           QMessageBox msgBox;
           msgBox.setIcon(QMessageBox::Warning);
-          msgBox.setWindowTitle(tr("KLog - Can't write the file"));
+          msgBox.setWindowTitle(tr("KLog - LoTW Can't write the file"));
           QString aux = QString(tr("KLog was not able to save the file %1.\nError returned: %2") ).arg(fileName).arg(file->errorString());
-          msgBox.setText(tr("The file already %1 exist.").arg(fileName));
+          msgBox.setText(tr("The file %1 already exists.").arg(fileName));
           msgBox.setDetailedText(aux);
           msgBox.setStandardButtons(QMessageBox::Ok);
           msgBox.setDefaultButton(QMessageBox::Ok);
@@ -232,8 +280,137 @@ int LoTWUtilities::download()
 
 }
 
+int LoTWUtilities::fullDownload()
+{
+   //qDebug() << "LoTWUtilities::fullDownload" << endl;
+    QDate date = dataProxy->getFirstQSODateFromCall(stationCallsign);
+   //qDebug() << "LoTWUtilities::fullDownload: Date: " << startDate  << endl;
+    if (date.isValid())
+    {
+        startDate = date.toString("yyyyMMdd");
+        //qDebug() << "LoTWUtilities::fullDownload: StartDate" << startDate  << endl;
+    }
+    QMessageBox msgBox;
+    msgBox.setIcon(QMessageBox::Question);
+    msgBox.setWindowTitle(tr("KLog - LoTW Start date selection"));
+    QString aux = QString(tr("This is the first date of a QSO with the call %1 in this log If you think that in LoTW you may have previous QSOs, answer No.").arg(stationCallsign) );
+    msgBox.setText(tr("Do you want to used this date (%1) as start date?").arg(startDate));
+    msgBox.setDetailedText(aux);
+    msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
+    msgBox.setDefaultButton(QMessageBox::Yes);
+    int ret = msgBox.exec();
+    if (ret == QMessageBox::Yes)
+    {
+         //qDebug() << "LoTWUtilities::fulldownload - Yes" << endl;
+          firstDate = date;
+          startThefullDownload();
+          return 1;
+    }
+
+    calendar->setSelectedDate(firstDate);
+    calendar->setGridVisible(true);
+    calendar->setMaximumDate(QDate::currentDate());
+    calendar->show();
+   //qDebug() << "LoTWUtilities::fullDownload - END" << endl;
+    return 2;
+}
+
+int LoTWUtilities::startThefullDownload()
+{
+
+   //qDebug() << "LoTWUtilities::startThefulldownload - Start" << endl;
+    if (calendar->isVisible())
+    {
+        calendar->close();
+    }
+
+    if (!selectQuery(2))
+    {
+       //qDebug() << "LoTWUtilities::startThefulldownload - END-1" << endl;
+        return -1;
+    }
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 10" << endl;
+    QFileInfo fileInfo(url.path());
+
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 11" << endl;
+   if (QFile::exists(fileName))
+   {
+       //qDebug() << "LoTWUtilities::startThefulldownload: - 12" << endl;
+       QMessageBox msgBox;
+       msgBox.setIcon(QMessageBox::Question);
+       msgBox.setWindowTitle(tr("KLog - LoTW File already exists"));
+       QString aux = QString(tr("There is a file already existing with the name that will be used.") );
+       msgBox.setText(tr("The file %1 already exist. Do you want to overwrite?").arg(fileName));
+       msgBox.setDetailedText(aux);
+       msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
+       msgBox.setDefaultButton(QMessageBox::Yes);
+       int ret = msgBox.exec();
+       //qDebug() << "LoTWUtilities::startThefulldownload: - 13" << endl;
+       if (ret == QMessageBox::No)
+       {
+            //qDebug() << "LoTWUtilities::startThefulldownload - END- 2" << endl;
+           return -2;
+       }
+     }
+       //qDebug() << "LoTWUtilities::startThefulldownload: - 20 Filename: -" << fileName << "-" << endl;
+       if (!file->isOpen())
+       {
+           //qDebug() << "LoTWUtilities::startThefulldownload: - 21 Filename: -" << endl;
+           file->setFileName(fileName);
+           //qDebug() << "LoTWUtilities::startThefulldownload: - 22 Filename: -" << endl;
+       }
+       //qDebug() << "LoTWUtilities::startThefulldownload: - 23 Filename: -" << endl;
+
+     if (!file->open(QIODevice::WriteOnly))
+     {
+         QMessageBox msgBox;
+         msgBox.setIcon(QMessageBox::Warning);
+         msgBox.setWindowTitle(tr("KLog - LoTW Can't write the file"));
+         QString aux = QString(tr("KLog was not able to save the file %1.\nError returned: %2") ).arg(fileName).arg(file->errorString());
+         msgBox.setText(tr("The file %1 already exists.").arg(fileName));
+         msgBox.setDetailedText(aux);
+         msgBox.setStandardButtons(QMessageBox::Ok);
+         msgBox.setDefaultButton(QMessageBox::Ok);
+         msgBox.exec();
+         //file->close();
+         //delete file;
+         //file = nullptr;
+          //qDebug() << "LoTWUtilities::startThefulldownload - END - 3" << endl;
+         return -3;
+     }
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 30" << endl;
+     // used for progressDialog
+     // This will be set true when canceled from progress dialog
+   downloadAborted = false;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 31" << endl;
+   //progressDialog = new QProgressDialog(nullptr);
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 40" << endl;
+   pDialog->setLabelText(tr("Downloading data to file: %1.").arg(fileName));
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 41" << endl;
+   pDialog->setWindowTitle(tr("KLog - LoTW download"));
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 42" << endl;
+   pDialog->setWindowModality(Qt::WindowModal);
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 43" << endl;
+   pDialog->reset();
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 44" << endl;
+   pDialog->setRange(0, 0);
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 45" << endl;
+   pDialog->setMinimumDuration(0);
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 46" << endl;
+   pDialog->show();
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 47" << endl;
+
+   connect(pDialog, SIGNAL(canceled()), this, SLOT(slotCancelDownload()));
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 50" << endl;
+
+   startRequest(url);
+    //qDebug() << "LoTWUtilities::startThefulldownload - END" << endl;
+
+    return 1;
+}
+
 void LoTWUtilities::slotDownloadProgress(qint64 bytesRead) {
-    //qDebug() << "LoTWUtilities::slotDownloadProgress: " << QString::number(bytesRead) << "/" << QString::number(totalBytes) << endl;
+    //qDebug() << "LoTWUtilities::slotDownloadProgress: " << QString::number(bytesRead) << endl;
     if (downloadAborted)
     {
          //qDebug() << "LoTWUtilities::slotDownloadProgress: CANCELLED" << endl;
@@ -256,7 +433,7 @@ void LoTWUtilities::slotReadyRead()
 
 void LoTWUtilities::slotFinished()
 {
-     //qDebug() << "LoTWUtilities::slotFinished - Started" << endl;
+    //qDebug() << "LoTWUtilities::slotFinished - Started" << endl;
     // when canceled
      if (downloadAborted)
      {
@@ -273,33 +450,39 @@ void LoTWUtilities::slotFinished()
          //qDebug() << "LoTWUtilities::slotFinished - END Canceled" << endl;
          return;
      }
-
+    //qDebug() << "LoTWUtilities::slotFinished - 10" << endl;
      // download finished normally
     pDialog->cancel();
+    //qDebug() << "LoTWUtilities::slotFinished - 11" << endl;
     file->flush();
+    //qDebug() << "LoTWUtilities::slotFinished - 12" << endl;
     file->close();
+    //qDebug() << "LoTWUtilities::slotFinished - 13" << endl;
 
      // get redirection url
      QVariant redirectionTarget = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
+     //qDebug() << "LoTWUtilities::slotFinished - 14" << endl;
      if (reply->error())
      {
-        file->remove();
-        QMessageBox msgBox;
-        msgBox.setIcon(QMessageBox::Warning);
-        msgBox.setWindowTitle(tr("KLog - Download error"));
-        QString aux = QString(tr("The downloading error is: %1") ).arg(reply->errorString());
-        msgBox.setText(tr("There was an error while downloading the file from LoTW."));
-        msgBox.setDetailedText(aux);
-        msgBox.setStandardButtons(QMessageBox::Ok);
-        msgBox.setDefaultButton(QMessageBox::Ok);
-        msgBox.exec();
+         file->remove();
+         QMessageBox msgBox;
+         msgBox.setIcon(QMessageBox::Warning);
+         msgBox.setWindowTitle(tr("KLog - LoTW Download error"));
+         QString aux;
+         msgBox.setText(tr("There was an error (%1) while downloading the file from LoTW.").arg(QString::number(reply->error())));
+         aux = QString(tr("The downloading error details are: %1") ).arg(reply->errorString());
+         msgBox.setDetailedText(aux);
+         msgBox.setStandardButtons(QMessageBox::Ok);
+         msgBox.setDefaultButton(QMessageBox::Ok);
+         msgBox.exec();
     }
     else if (!redirectionTarget.isNull())
     {
+         //qDebug() << "LoTWUtilities::slotFinished - Redirection" << endl;
         QUrl newUrl = url.resolved(redirectionTarget.toUrl());
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
-        msgBox.setWindowTitle(tr("KLog - Redirection found"));
+        msgBox.setWindowTitle(tr("KLog - LoTW Redirection found"));
         QString aux = QString(tr("The remote server redirected our connection to %1") ).arg(newUrl.toString());
         msgBox.setText(tr("Do you want to follow the redirection?"));
         msgBox.setDetailedText(aux);
@@ -319,21 +502,11 @@ void LoTWUtilities::slotFinished()
      }
     else
     {
-        //QString fileName = QFileInfo(QUrl(ui->urlEdit->text()).path()).fileName();
-         //ui->statusLabel->setText(tr("Downloaded %1 to %2.").arg(fileName).arg(QDir::currentPath()));
-         //ui->downloadButton->setEnabled(true);
-         //qDebug() << "LoTWUtilities::slotFinished:  "  << endl;
-     }
-
-    //reply->deleteLater();
-
-
+        //qDebug() << "LoTWUtilities::slotFinished:  "  << endl;
+    }
+    //qDebug() << "LoTWUtilities::slotReadyRead - Going to parse ..." << endl;
     parseDownloadedFile(file->fileName());
-    //delete file;
-    //file = nullptr;
-
-
-      //qDebug() << "LoTWUtilities::slotReadyRead - END" << endl;
+    //qDebug() << "LoTWUtilities::slotReadyRead - END" << endl;
 }
 
 void LoTWUtilities::slotCancelDownload()
@@ -376,7 +549,7 @@ bool LoTWUtilities::getIsReady()
 
 void LoTWUtilities::parseDownloadedFile(const QString &_fn)
 {
-     //qDebug() << "LoTWUtilities::parseDownloadedFile: " << _fn << endl;
+    //qDebug() << "LoTWUtilities::parseDownloadedFile: " << _fn << endl;
     QString _fileName = _fn;
     QMessageBox msgBox;
     QString aux;
@@ -384,9 +557,9 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
     QFile file( _fileName );
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     {
-         //qDebug() << "LoTWUtilities::parseDownloadedFile File not found" << _fileName << endl;
+        //qDebug() << "LoTWUtilities::parseDownloadedFile File not found" << _fileName << endl;
         msgBox.setIcon(QMessageBox::Warning);
-        msgBox.setWindowTitle(tr("KLog - File not found"));
+        msgBox.setWindowTitle(tr("KLog - LoTW File not found"));
         msgBox.setText(tr("KLog can't find the downloaded file."));
         aux = QString(tr("It was not possible for find the file %1 that has been just downloaded.") ).arg(_fn);
 
@@ -497,10 +670,11 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
    //Procesar los QSOs y meterlos en una tabla? o en un QStringList o alguna otra estructura
 
 
-     //qDebug() << "LoTWUtilities::parseDownloadedFile - END"  << endl;
+    //qDebug() << "LoTWUtilities::parseDownloadedFile - END"  << endl;
 }
 
-void LoTWUtilities::showMessage(const int _messageIcon, const QString &_msg, const QString &_msgExt)
+/*void LoTWUtilities::showMessage(const int _messageIcon, const QString &_msg, const QString &_msgExt)
 {
 
 }
+*/
