@@ -10,19 +10,18 @@ MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) :
     modeComboBox = new QComboBox;
     dateEdit = new QDateEdit;
     timeEdit = new QTimeEdit;
-    realTime =true;
     realtimeCheckBox = new QCheckBox;
     enabledCR = realtimeCheckBox->backgroundRole();
     OKButton = new QPushButton(tr("&Add"), this);
     clearButton = new QPushButton(tr("&Clear"), this);
     timer = new QTimer(this);
     util = new Utilities;
-
+    realTime = true;
 
     logSeverity = 7;  //7 Debug /0=emergency or no debug
 
     createUI();
-    setInitialData();    
+    setInitialData();
       //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget: - END" << endl;
 }
 
@@ -30,7 +29,7 @@ void MainQSOEntryWidget::createUI()
 {
       //qDebug()<< "MainQSOEntryWidget::createUI" << endl;
     emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
-    qrzLineEdit->setToolTip(tr("QRZ of the QSO."));
+    qrzLineEdit->setToolTip(tr("Callsign of the QSO."));
     bandComboBox->setToolTip(tr("Band of the QSO."));
     modeComboBox->setToolTip(tr("Mode of the QSO."));
     dateEdit->setToolTip(tr("Date of the QSO."));
@@ -52,7 +51,7 @@ void MainQSOEntryWidget::createUI()
     QrzBandModeLayout->addWidget(qrzLineEdit);
     QrzBandModeLayout->addLayout(BandModeLayout);
 
-    qrzgroupBox = new QGroupBox(tr("QRZ"));
+    qrzgroupBox = new QGroupBox(tr("Callsign"));
     qrzgroupBox->setFlat(true);
     QVBoxLayout *qrzvbox = new QVBoxLayout;
     qrzvbox->addLayout(QrzBandModeLayout);
@@ -62,7 +61,7 @@ void MainQSOEntryWidget::createUI()
     buttonsLayout->addWidget(OKButton);
     buttonsLayout->addWidget(clearButton);
 
-    dateEdit->setDisplayFormat("yyyy/MM/dd");
+    dateEdit->setDisplayFormat("yyyy-MM-dd");
     timeEdit->setDisplayFormat("HH:mm:ss");
 
     QGridLayout *widgetLayout = new QGridLayout;
@@ -78,7 +77,7 @@ void MainQSOEntryWidget::createUI()
     connect(qrzLineEdit, SIGNAL(returnPressed()), this, SLOT(slotOKButtonClicked() ) );
     connect(qrzLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotQRZTextChanged() ) );
     connect(bandComboBox, SIGNAL(currentIndexChanged (int)), this, SLOT(slotBandComboBoxChanged() ) ) ;
-    connect(modeComboBox, SIGNAL(currentIndexChanged (int)), this, SLOT(slotModeComboBoxChanged() ) ) ;    
+    connect(modeComboBox, SIGNAL(currentIndexChanged (int)), this, SLOT(slotModeComboBoxChanged() ) ) ;
 
     connect(OKButton, SIGNAL(clicked()), this, SLOT(slotOKButtonClicked() ) );
     connect(clearButton, SIGNAL(clicked()), this, SLOT(slotClearButtonClicked() ) );
@@ -112,7 +111,7 @@ void MainQSOEntryWidget::setCleaning (const bool _c)
 
 void MainQSOEntryWidget::slotQRZTextChanged()
 {
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######" << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######" << endl;
     emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
     if ((qrzLineEdit->text()).length()<1)
     {
@@ -122,18 +121,18 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     return;
     }
     int cursorP = qrzLineEdit->cursorPosition();
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position: " << QString::number(cursorP) << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position: " << QString::number(cursorP) << endl;
     qrzLineEdit->setText((qrzLineEdit->text()).toUpper());
     if (cleaning)
     {
-          //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Cleaning - END" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Cleaning - END" << endl;
         emit debugLog(Q_FUNC_INFO, "END-2", logSeverity);
         return;
     }
 
     if (qrzAutoChanging)
     {
-          //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: qrzAutoChanging - END" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: qrzAutoChanging - END" << endl;
         qrzAutoChanging = false;
         emit debugLog(Q_FUNC_INFO, "END-3", logSeverity);
         return;
@@ -147,22 +146,22 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     {/*Remove the space and moves the focus to SRX to write the RX exchange*/
         previousQRZ = (qrzLineEdit->text()).simplified();
         qrzLineEdit->setText(previousQRZ);
-          //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Space detected" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Space detected" << endl;
     }
 
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Simplifiying & Capitalizing" << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Simplifiying & Capitalizing" << endl;
     qrzLineEdit->setText(((qrzLineEdit->text())).simplified());
     qrzLineEdit->setText((qrzLineEdit->text()).remove(" "));
-    //qrzLineEdit->setText((qrzLineEdit->text()).toUpper());
 
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars" << endl;
+
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars" << endl;
     //TODO: This validCharactersInCall may be removed?
     InValidCharsInPrevCall = validCharactersInCall(qrzLineEdit->text());
 
     if (!util->isValidCall(qrzLineEdit->text()))
     {
         qrzLineEdit->setPalette(palRed);
-        //emit showInfoLabel(tr("QRZ not valid"));
+        //emit showInfoLabel(tr("Callsign not valid"));
         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ not valid - END" << endl;
         emit debugLog(Q_FUNC_INFO, "END-4", logSeverity);
         //return;
@@ -182,7 +181,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     }
     */
 
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for modify or length<1" << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for modify or length<1" << endl;
     if (qrzSmallModDontCalculate)
     //if ((modify) || ((qrzLineEdit->text()).length() < 1) || (qrzSmallModDontCalculate))
     {
@@ -192,7 +191,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
         return;
     }
 
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: running..." << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: running..." << endl;
     qrzSmallModDontCalculate = true; // A kind of flag to prevent multiple calls to this method.
     currentQrz = qrzLineEdit->text();
 
@@ -203,7 +202,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     }
 
     currentQrz = qrzLineEdit->text();
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.3: " << QString::number(cursorP) << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.3: " << QString::number(cursorP) << endl;
     if (cursorP>currentQrz.length())
     {// A Space that has been removed without updating the cursor
           //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursorP > currentQRZ.length" << endl;
@@ -230,7 +229,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     emit currentQRZSignal(currentQrz);
 
     qrzSmallModDontCalculate = false; // If the text has not been modified in this method
-      //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP) << endl;
+    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP) << endl;
     qrzLineEdit->setCursorPosition(cursorP);
 
     qrzAutoChanging = false;
@@ -389,7 +388,7 @@ bool MainQSOEntryWidget::setBand(const QString &_band)
 bool MainQSOEntryWidget::setMode(const QString &_mode)
 {
     emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
-      //qDebug() << "MainQSOEntryWidget::setMode: " << _mode << endl;
+    //qDebug() << "MainQSOEntryWidget::setMode: " << _mode << endl;
     if (modeComboBox->findText(_mode, Qt::MatchCaseSensitive) < 0)
     {
         emit debugLog(Q_FUNC_INFO, "END-1", logSeverity);
@@ -406,23 +405,27 @@ bool MainQSOEntryWidget::setMode(const QString &_mode)
 bool MainQSOEntryWidget::setQRZ(const QString &_qrz)
 {
     emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
+    //qDebug() << "MainQSOEntryWidget::setQRZ: " << _qrz << endl;
     //TODO: Add validations to prevent that non valid qrz are sent from the outside of this function or at least manage this appropriately.
     qrzLineEdit->setText(_qrz.toUpper());
     emit debugLog(Q_FUNC_INFO, "END", logSeverity);
     return false;
 }
 
-bool MainQSOEntryWidget::setDate(const QDate _date)
+bool MainQSOEntryWidget::setDate(const QDateTime _date)
 {
     emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
     if (_date.isValid())
     {
-        dateEdit->setDate(_date);
+        dateEdit->setDate(_date.date());
+        timeEdit->setTime(_date.time());
+
         emit debugLog(Q_FUNC_INFO, "END", logSeverity);
         return true;
     }
     else
     {
+        //qDebug() << "MainQSOEntryWidget::setDate - NO VALID DATE" << endl;
         emit debugLog(Q_FUNC_INFO, "END", logSeverity);
         return false;
     }
@@ -446,7 +449,7 @@ bool MainQSOEntryWidget::setTime(const QTime _time)
 
 QString MainQSOEntryWidget::getQrz()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", logSeverity);    
+    emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
     emit debugLog(Q_FUNC_INFO, "END", logSeverity);
     return (qrzLineEdit->text()).toUpper();
 }
@@ -457,6 +460,7 @@ QString MainQSOEntryWidget::getBand(const int _b)
     if (_b<0)
     {
         emit debugLog(Q_FUNC_INFO, "END", logSeverity);
+        //qDebug() << "MainQSOEntryWidget::getBand(1): " << bandComboBox->currentText()<< endl;
         return bandComboBox->currentText();
     }
     else
@@ -464,11 +468,13 @@ QString MainQSOEntryWidget::getBand(const int _b)
         if (bandComboBox->count()>=_b)
         {
             emit debugLog(Q_FUNC_INFO, "END-1", logSeverity);
+            //qDebug() << "MainQSOEntryWidget::getBand(2): " << bandComboBox->currentText()<< endl;
             return bandComboBox->itemText(_b);
         }
         else
         {
             emit debugLog(Q_FUNC_INFO, "END-2", logSeverity);
+            //qDebug() << "MainQSOEntryWidget::getBand(3): " << bandComboBox->currentText()<< endl;
             return bandComboBox->currentText();
         }
     }
@@ -504,6 +510,18 @@ QDate MainQSOEntryWidget::getDate()
     return dateEdit->date();
 }
 
+
+QDateTime MainQSOEntryWidget::getDateTime()
+{
+    emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
+    //emit debugLog(Q_FUNC_INFO, "END", logSeverity);
+    QDateTime dateTime;
+    dateTime.setDate(dateEdit->date());
+    dateTime.setTime(timeEdit->time());
+    return dateTime;
+
+}
+
 QTime MainQSOEntryWidget::getTime()
 {
     emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
@@ -515,7 +533,7 @@ void MainQSOEntryWidget::setRealTime(const bool _realTime)
 {
     emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
     realtimeCheckBox->setChecked(_realTime);
-    realTime = _realTime;
+    //realTime = _realTime;
     emit debugLog(Q_FUNC_INFO, "END", logSeverity);
 }
 
@@ -533,14 +551,11 @@ void MainQSOEntryWidget::setModify(const bool _modify)
     modify = _modify;
     if (modify)
     {
-        realTime = realtimeCheckBox->isChecked();
         OKButton->setText(tr("&Modify"));
-        realtimeCheckBox->setChecked(false);
     }
     else
     {
         OKButton->setText(tr("&Add"));
-        realtimeCheckBox->setChecked(realTime);
     }
     emit debugLog(Q_FUNC_INFO, "END", logSeverity);
 }
@@ -548,23 +563,27 @@ void MainQSOEntryWidget::setModify(const bool _modify)
 void MainQSOEntryWidget::slotUpdateTime()
 {
     //qDebug()<< "MainQSOEntryWidget::slotUpdateTime" << endl;
-    emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
-    if ( (!modify) && (realTime)  )
+    //emit debugLog(Q_FUNC_INFO, "Start", logSeverity);
+
+    if ( (!modify) && (realtimeCheckBox->isChecked())  )
     {
         //qDebug()<< "MainQSOEntryWidget::slotUpdateTime - Real Time & update" << endl;
 
         if (UTCTime)
         {
+
             dateEdit->setDate(QDateTime::currentDateTime().toUTC().date());
             timeEdit->setTime(QDateTime::currentDateTime().toUTC().time());
         }
         else
         {
+
             dateEdit->setDate(QDateTime::currentDateTime().date());
             timeEdit->setTime(QDateTime::currentDateTime().time());
         }
     }
-    emit debugLog(Q_FUNC_INFO, "END", logSeverity);
+
+    //emit debugLog(Q_FUNC_INFO, "END", logSeverity);
 }
 
 bool MainQSOEntryWidget::validCharactersInCall(const QString &_qrz)
