@@ -34,7 +34,7 @@
 #include <QNetworkReply>
 #include <QtAlgorithms>
 
-#include "database.h"
+//#include "database.h"
 #include "setupdialog.h"
 //#include "helpaboutdialog.h"
 #include "aboutdialog.h"
@@ -42,6 +42,7 @@
 #include "tipsdialog.h"
 #include "world.h"
 #include "filemanager.h"
+#include "fileawardmanager.h"
 //#include "contest.h"
 //#include "contest_cqwwdxssb.h"
 #include "dataproxy_sqlite.h"
@@ -71,9 +72,10 @@
 #include "statisticswidget.h"
 #include "updatesatsdata.h"
 #include "hamlibclass.h"
-#include "pstrotatorsupport.h"
+#include "elogqrzlog.h"
+//#include "pstrotatorsupport.h"
 #include "lotwutilities.h"
-#include "widgets/rotator.h"
+#include "eqslutilities.h"
 #include "widgets/adiflotwexportwidget.h"
 #include "widgets/showadifimportwidget.h"
 //#include "worldmapwidget.h"
@@ -146,6 +148,8 @@ public:
 
 private slots:
     //void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
+    //void slotTest();        // Slot for testing purposes only
+    void slotAWAImport();
     void slotClearNoMorErrorShown();
     void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString queryFailed);
     void slotQRZReturnPressed();
@@ -158,6 +162,7 @@ private slots:
     //void slotMyLocatorTextChanged();
     void slotFreqTXChanged();
     void slotFreqRXChanged();
+    void slotSplitCLicked();
 
     void slotSearchBoxTextChanged();
     //void slotCloseStats(bool _vis);
@@ -170,7 +175,11 @@ private slots:
     void slotToolLoTWMarkAllYesThisLog();
     void slotToolLoTWMarkAllYes();
     void slotLoTWDownloadedFileProcess(const QString &_fn);
+    //void slotLoTWTest();
 
+    void slotClubLogLogUpload();
+    void sloteQSLLogUpload();
+    void slotElogEQSLModifyCurrentLog();
     //void slotModeComboBoxChanged();
     //void slotBandComboBoxChanged();
     //void slotIOTAComboBoxChanged();
@@ -186,10 +195,15 @@ private slots:
     void slotLogRefresh();
     //void slotScoreWinShow();
     void slotQSODelete(const int _id);
+    void slotQSOsDelete(QList<int> _id);
+    void slotQSOsExportToADIF(QList<int> _id);
+    void slotQRZcomUpload(QList<int> _id);
+    void slotQRZCOMLogUpload();
+
 
     void slotShowAwards();
     void slotUpdateStatusBar(const QString &statusm);
-
+    void setMainWindowTitle(const QString _s);
     void slotSetup(const int _page=0);
 
     //void slotrstTXTextChanged();
@@ -200,6 +214,7 @@ private slots:
 
     void slotLoTWExport();
     void slotLoTWDownload();
+    void slotLoTWFullDownload();
     void slotADIFExportSelection(const QString &_st, const QDate &_startDate, const QDate &_endDate, const ExportMode _eM);
     //void slotADIFExportPeriod(const QString &_st, const QDate &_startDate, const QDate &_endDate, const ExportMode _eM);
 
@@ -220,6 +235,7 @@ private slots:
     void slotWorldReload(const bool _b);
 
     void slotExitFromSlotDialog(const int exitID);
+    void slotSetupDialogFinished (const int _s);
     void exitQuestion();
 
     //void slotDownloadFinished(QNetworkReply *reply);
@@ -269,10 +285,24 @@ private slots:
     void slotElogClubLogShowMessage(const QString &_s);
     void slotElogClubLogProcessAnswer(const int _i, const int _qID);
     void slotElogClubLogDisable(const bool _b);
+    void slotElogClubLogFileUploaded (QNetworkReply::NetworkError _error, QList<int> _qsos);
+    void slotElogClubLogModifyCurrentLog();
+
     //CLUBLOG
-
+    // EQSL
+    void slotElogEQSLFileUploaded (QNetworkReply::NetworkError _error, QList<int> _qsos);
+    // EQSL
     void slotShowSoftUpdateResults(const bool _b);   // Software Update: Receives the signal to see if it is needed or not to update
-
+    // EQSL
+    // QRZCOM
+    void slotElogQRZCOMShowMessage(const QString &_s);
+    void slotElogQRZCOMFoundData(const QString &_t, const QString & _d);
+    void slotElogQRZCOMCheckThisCall();
+    void slotElogQRZCOMAutoCheck();
+    void slotElogQRZCOMAutoCheckFromSetup(const bool _s);
+    void slotElogQRZCOMModifyCurrentLog();
+    void slotElogQRZCOMLogUploaded (QNetworkReply::NetworkError _error, QList<int> _qsos);
+    // QRZCOM
     //SATELLITE
     //void slotSatBandTXComboBoxChanged(const QString _q);
     void slotDefineNewBands (const QStringList _bands);
@@ -287,7 +317,7 @@ private slots:
     //void slotHamlibModeNotADIF();
 
     // PST Rotator
-    void slotRotatorShow();
+    //void slotRotatorShow();
     // WORLD MAP
     //void slotWorldMapShow();
 
@@ -300,11 +330,16 @@ private slots:
                                  const QString &_report, const QString &_de_call, const QString &_de_grid,
                                  const QString &_dx_grid, const QString &_sub_mode);
 
+    void slotWSJTXloggedQSO (const QString &_dxcall, const QString &_mode, const QString &_band, const double _freq,
+                     const QString &_mygrid, const QString &_dxgrid, const QString &_rstTX, const QString &_rstRX,
+                     const QString &_comment, const QString &_stationcallsign, const QString &_name,
+                     const QString &_opCall, const QDateTime &_datetime, const QDateTime &_datetime_off,
+                     const QString &_exchangeTX, const QString &_exchangeRX, const QString &_mypwr);
 
+    //void slotWSJTXloggedQSO (const QString &_dxcall, const QString &_mode, const QString &band, const double _freq,
+    //                 const QString &mygrid, const QString &dxgrid, const QString &rstTX, const QString &rstRX, const QString &comment, const QString &stationcallsign,
+    //                 const QDateTime &datetime, const QDateTime &datetime_off);
 
-    void slotWSJTXloggedQSO(const int _type, const QString &_dxcall, const double _freq, const QString &_mode,
-                             const QString &_dx_grid, const QString &_time_off, const QString &_report_sent, const QString &_report_rec,
-                             const QString &_tx_power, const QString &_comments, const QString &_name, const QString &_time_on, const QString &_de_call, const QString &_de_grid);
 
 
     //void slotTipsFindQSL2QSO();
@@ -314,6 +349,10 @@ private slots:
     void slotCaptureDebugLogs(const QString &_func, const QString &_msg, const int _level=7);
 private:
     //void setWidgetsOrder();
+    void showMessageToEnableTheOnlineService(const OnLineProvider _service);
+    void cleanQRZCOMreceivedDataFromUI();
+    void saveWindowsSize();
+    void setWindowsSize(const int _width, const int _height);
     bool maybeSave();
     void setCleaning(const bool _c);
 
@@ -321,6 +360,8 @@ private:
     void setSeverity(const int _sev);
     void updateBandComboBox(const QString &_band);
     void fileExportLoTW(const QString &_st, const QDate &_startDate, const QDate &_endDate);
+    void fileExportClubLog(const QString &_st, const QDate &_startDate, const QDate &_endDate);
+    void fileExportEQSL(const QString &_st, const QDate &_startDate, const QDate &_endDate);
     void fileExportADIF(const QString &_st, const QDate &_startDate, const QDate &_endDate);
     bool callTQSL(const QString &_filename, const QString &_call);
     void showNumberOfSavedQSO(const QString &_fn, const int _n);
@@ -334,9 +375,9 @@ private:
     bool hamlibModeNotADIFSupported;
 
     // PST Rotator
-    PSTRotatorSupport *pstRotator;
-    bool usePSTRotator;
-    RotatorWidget *rotatorWidget;
+    //PSTRotatorSupport *pstRotator;
+    //bool usePSTRotator;
+    //RotatorWidget *rotatorWidget;
     //</UPDATE CTY.DAT>
     //WorldMapWidget *worldMapWidget;
     void createStatusBar();
@@ -417,6 +458,7 @@ private:
     //QWidget *dxClusterTabWidget;//, *searchTabWidget;
     World *world;
     FileManager *filemanager;
+    FileAwardManager *fileAwardManager;
     Locator *locator;
     Awards *awards;
     Utilities *util;
@@ -467,12 +509,17 @@ private:
     QMenu *toolMenu;
     QMenu *qslToolMenu;
     QMenu *lotwToolMenu;
+    QMenu *clublogToolMenu;
+    QMenu *eQSLToolMenu;
+    QMenu *QRZCOMToolMenu;
     //QMenu *lotwMarkAllAsQueuedMenu;
     //QMenu *lotwMarkAllInThisLogAsQueuedMenu;
     QMenu *viewMenu;
     QMenu *setupMenu;
     QMenu *helpMenu;
 
+    //QAction *TestAct;       // Action for testing purposes only
+    QAction *awardAddAct;
     QAction *klogFolderAct;
     //QAction *openAct;
     //QAction *saveAct;
@@ -510,11 +557,22 @@ private:
     QAction *lotwMarkSentYesAct;
     QAction *lotwCallTQSL;
     QAction *lotwUpdateFromLoTWAct;
+    QAction *lotwFullDownloadFromLoTWAct;
+
+    QAction *clublogLogUploadAct;
+    QAction *clublogLogModifyCurrentLogAct;
+    QAction *eqslUploadAct;
+    QAction *eqslLogModifyCurrentLogAct;
+
+    QAction *QRZCOMCheckThisCallAct;
+    QAction *QRZCOMAutoCheckAct;
+    QAction *QRZCOMLogUploadAct;
+    QAction *QRZCOMLogModifyCurrentLogAct;
 
     QAction *downloadCTYAct;
     QAction *downloadSATSAct;
     QAction *showStatsAct;
-    QAction *showRotatorAct;
+    //QAction *showRotatorAct;
     //QAction *showDXCCSummaryAct;
 
     QAction *loggWinAct;
@@ -568,6 +626,7 @@ private:
     QLineEdit *operatorLineEdit, *stationCallSignLineEdit;//, *commentLineEdit, *iotaNumberLineEdit;
     QTextEdit *notesTextEdit;
     QDoubleSpinBox *rxPowerSpinBox,  *txFreqSpinBox, *rxFreqSpinBox; //*myPowerSpinBox,
+    QCheckBox *splitCheckBox;
     QLCDNumber *freqQLCDNumber;
 
     QString lotwTQSLpath;
@@ -644,7 +703,7 @@ private:
     QString stx;
     QString srx;
     QPalette palRed, palBlack; // To paint Text in red or black(normal)
-    bool  alwaysADIF, needToSave, useDefaultLogFileName, upAndRunning, qrzSmallModDontCalculate, imperialSystem, sendQSLWhenRec, manageDxMarathon, keepMyData, completeWithPrevious, completedWithPreviousQTH, completedWithPreviousLocator, completedWithPreviousName, completedWithPreviousIOTA, completedWithPreviousQSLVia;
+    bool  alwaysADIF, needToSave, useDefaultLogFileName, upAndRunning, qrzSmallModDontCalculate, imperialSystem, sendQSLWhenRec, manageDxMarathon, completeWithPrevious, completedWithPreviousQTH, completedWithPreviousLocator, completedWithPreviousName, completedWithPreviousIOTA, completedWithPreviousQSLVia;
     // bool realTime, UTCTime;
     bool cleaning;
     bool manageMode; // If true, the DXCC and awards will take the mode into consideration to decide if needed or worked. False implies only band is taken into account
@@ -674,14 +733,19 @@ private:
     QColor newOneColor;
 
     //<CLUBLOG>
-    bool clublogActive, clublogRealTime;
-    QString clublogUser, clublogPass, clublogEmail;
+    bool clublogActive, clublogRealTime, eQSLActive, eQSLRealTime, eQSLUseQSOStationCallSign; //clublogUseStationCallSign,
+    QString clublogPass, clublogEmail; //clublogUser,   
 
     eLogClubLog *elogClublog;
     int clublogAnswer;
     QStringList clublogPrevQSO;
 
     //</CLUBLOG>
+    // QRZ.com
+    bool qrzcomActive;
+    eLogQrzLog *elogQRZcom;
+    QString qrzcomUser, qrzcomPass;
+    // QRz.com - END
 
     // Contest
     //int points, qsoPoints, multipliers, qsoMultiplier;
@@ -690,7 +754,7 @@ private:
     // Contest
     DataProxy_SQLite *dataProxy;
 
-    DataBase *db;
+    //DataBase *db;
 
 
     SoftwareUpdate *softUpdate;
@@ -699,6 +763,11 @@ private:
     bool UDPServerStart;
     // LOTWUTILITIES
     LoTWUtilities *lotwUtilities;
+    bool lotwActive;
+
+    //eQSLUtilities
+    eQSLUtilities *eqslUtilities;
+
     //LOGVIEW
     //QString bandOld, modeOld;
     //LOGVIEW
@@ -708,8 +777,8 @@ signals:
 
 
 protected:
-    void keyPressEvent(QKeyEvent *event);
-    void closeEvent(QCloseEvent *event);
+    void keyPressEvent(QKeyEvent *event) override;
+    void closeEvent(QCloseEvent *event) override;
 
 };
 
