@@ -31,10 +31,10 @@
 This class calls all the othet "Setup..." to manage the configuration
 
 */
-
-SetupDialog::SetupDialog(DataProxy_SQLite *dp, const bool _firstTime)
+/*
+SetupDialog::SetupDialog(DataProxy_SQLite *dp, const bool _firstTime, QWidget *parent)
 {
-      //qDebug() << "SetupDialog::SetupDialog 1" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 1" << endl;
     logSeverity = 7;  //7 Debug /0=emergency or no debug
     util = new Utilities;
     constrid = 1;
@@ -79,17 +79,21 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const bool _firstTime)
       //qDebug() << "SetupDialog::SetupDialog 3.10" << endl;
     logsPage = new SetupPageLogs(dataProxy, this);
       //qDebug() << "SetupDialog::SetupDialog 3.11" << endl;
-    clubLogPage = new SetupPageClubLog(this);
-    lotwPage = new SetupPageLoTW(this);
+    eLogPage = new SetupPageELog(this);
+    //clubLogPage = new SetupPageClubLog(this);
+    //lotwPage = new SetupPageLoTW(this);
+    //eQSLPage = new SetupPageEQSL(this);
        //qDebug() << "SetupDialog::SetupDialog 3.12" << endl;
     UDPPage = new SetupPageUDP(this);    
       //qDebug() << "SetupDialog::SetupDialog 3.13" << endl;
     satsPage = new SetupPageSats(dataProxy, this);
+    subdivisionsPage = new SetupPageSubdivisions(dataProxy, this);
+    //regionalAwardsPage = new SetupPageRegionalAwards(dataProxy, this);
     //hamlibPage = new SetupPageHamLib(dataProxy, this);
-    interfacesWindowsPage = new SetupPageInterfacesWindows(this);
+    //interfacesWindowsPage = new SetupPageInterfacesWindows(this);
 
       //qDebug() << "SetupDialog::SetupDialog 4" << endl;
-
+    //tabWidget->addTab(subdivisionsPage, tr("Subdivisions"));
     tabWidget->addTab(userDataPage, tr("My Data"));    
     tabWidget->addTab(bandModePage, tr("Bands/Modes"));
     tabWidget->addTab(dxClusterPage, tr("DX-Cluster"));
@@ -97,8 +101,10 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const bool _firstTime)
     tabWidget->addTab(miscPage, tr("Misc"));
     tabWidget->addTab(worldEditorPage, tr("World Editor"));
     logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
-    tabWidget->addTab(clubLogPage, "ClubLog");
-    tabWidget->addTab(lotwPage, "LoTW");
+    tabWidget->addTab(eLogPage, "eLog");
+    //tabWidget->addTab(clubLogPage, "ClubLog");
+    //tabWidget->addTab(lotwPage, "LoTW");
+    //tabWidget->addTab(eQSLPage, "eQSL");
     tabWidget->addTab(UDPPage, "WSJT-X");
     tabWidget->addTab(satsPage , tr("Satellites"));
     tabWidget->addTab(hamlibPage, tr ("HamLib"));
@@ -131,6 +137,7 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const bool _firstTime)
     setLayout(mainLayout);
 
     setWindowTitle(tr("Config Dialog"));
+    windowSize.clear();
     slotReadConfigData();
 
 
@@ -139,31 +146,25 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const bool _firstTime)
         tabWidget->setCurrentIndex(logsPageTabN);
     }
     nolog = !(haveAtleastOneLog());
-      //qDebug() << "SetupDialog::SetupDialog 1 END" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 1 END" << endl;
 }
 
-
-SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime)
+*/
+SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime, QWidget *parent)
 {
-      //qDebug() << "SetupDialog::SetupDialog 2: " << _configFile << "/" << _softwareVersion << "/" << QString::number(_page) ;
-    if (_firstTime)
-    {
-          //qDebug() << "/True";
-    }
-    else {
-          //qDebug() << "/False";
-    }
-      //qDebug() << endl;
+    //qDebug() << "SetupDialog::SetupDialog 2: " << _configFile << "/" << _softwareVersion << "/" << QString::number(_page) << util->boolToQString(_firstTime) << endl ;
+
     logSeverity = 7;
     constrid = 2;
     util = new Utilities;
     firstTime = _firstTime;
+    latestBackup = QString();
     dataProxy = dp;
     configFileName = _configFile;
     version = _softwareVersion;
     pageRequested = _page;
     int logsPageTabN=-1;
-       //qDebug() << "SetupDialog::SetupDialog 01" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 01" << endl;
 
     locator = new Locator();
 
@@ -176,15 +177,20 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     miscPage = new SetupPageMisc(this);
     worldEditorPage = new SetupPageWorldEditor (dataProxy, this);
     logsPage = new SetupPageLogs(dataProxy, this);
-    clubLogPage = new SetupPageClubLog(this);
-    lotwPage = new SetupPageLoTW(this);
+    eLogPage = new SetupPageELog(this);
+    //clubLogPage = new SetupPageClubLog(this);
+    //lotwPage = new SetupPageLoTW(this);
+    //eQSLPage = new SetupPageEQSL(this);
     UDPPage = new SetupPageUDP(this);
     satsPage = new SetupPageSats(dataProxy, this);
     hamlibPage = new SetupPageHamLib(dataProxy, this);
-    interfacesWindowsPage = new SetupPageInterfacesWindows(this);
+    //subdivisionsPage = new SetupPageSubdivisions(dataProxy, this);
+    //regionalAwardsPage = new SetupPageRegionalAwards(dataProxy, this);
+    //interfacesWindowsPage = new SetupPageInterfacesWindows(this);
 
 
-      //qDebug() << "SetupDialog::SetupDialog 02" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 02" << endl;
+    //tabWidget->addTab(subdivisionsPage, tr("Subdivisions"));
     tabWidget->addTab(userDataPage, tr("User data"));
     tabWidget->addTab(bandModePage, tr("Bands/Modes"));
     tabWidget->addTab(dxClusterPage, tr("D&X-Cluster"));
@@ -192,14 +198,16 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     tabWidget->addTab(miscPage, tr("Misc"));
     tabWidget->addTab(worldEditorPage, tr("World Editor"));
     logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
-    tabWidget->addTab(clubLogPage, tr("ClubLog"));
-    tabWidget->addTab(lotwPage, tr("LoTW"));
+    tabWidget->addTab(eLogPage, tr("eLog"));
+    //tabWidget->addTab(clubLogPage, tr("ClubLog"));
+    //tabWidget->addTab(lotwPage, tr("LoTW"));
+
     tabWidget->addTab(UDPPage, tr("WSJT-X"));
     tabWidget->addTab(satsPage , tr("Satellites"));
     tabWidget->addTab(hamlibPage, tr ("HamLib"));
-    tabWidget->addTab(interfacesWindowsPage, tr ("Interfaces"));
+    //tabWidget->addTab(interfacesWindowsPage, tr ("Interfaces"));
 
-       //qDebug() << "SetupDialog::SetupDialog 03" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 03" << endl;
 
     QPushButton *closeButton = new QPushButton(tr("Cancel"));
     okButton = new QPushButton(tr("OK"));
@@ -216,16 +224,16 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     mainLayout->addLayout(horizontalLayout);
     mainLayout->addLayout(buttonsLayout);
 
-      //qDebug() << "SetupDialog::SetupDialog 04" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 04" << endl;
 
     setLayout(mainLayout);
 
-    setWindowTitle(tr("Config Dialog"));
+    setWindowTitle(tr("Settings"));
 
-      //qDebug() << "SetupDialog::SetupDialog 05" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 05" << endl;
 
     slotReadConfigData();
-      //qDebug() << "SetupDialog::SetupDialog 05.1" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 05.1" << endl;
 
     if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
     {
@@ -239,7 +247,7 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
     connectActions();
 
-      //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
 }
 
 
@@ -256,10 +264,20 @@ void SetupDialog::connectActions()
     connect (userDataPage, SIGNAL(stationCallSignal(QString)), this, SLOT(slotSetStationCallSign(QString)));
     connect (userDataPage, SIGNAL(operatorsSignal(QString)), this, SLOT(slotSetOperators(QString)));
     connect (userDataPage, SIGNAL(enterKey()), this, SLOT(slotOkButtonClicked()));
+    //connect (lotwPage, SIGNAL(enterKey()), this, SLOT(slotOkButtonClicked()));
+    connect (eLogPage, SIGNAL(enterKey()), this, SLOT(slotOkButtonClicked()));
+    //connect (clubLogPage, SIGNAL(enterKey()), this, SLOT(slotOkButtonClicked()));
+    connect (eLogPage, SIGNAL(qrzcomAuto(bool)), this, SLOT(slotQRZCOMAuto(bool)));
+
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
 
 }
 
+void SetupDialog::slotQRZCOMAuto(const bool _b)
+{
+    emit qrzcomAuto(_b);
+}
+
 void SetupDialog::setData(const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime)
 {
       //qDebug() << "SetupDialog::setData: " << "/" << _configFile << "/" << _softwareVersion << "/" << QString::number(_page) << endl;
@@ -273,7 +291,6 @@ void SetupDialog::setData(const QString &_configFile, const QString &_softwareVe
     else
     {
           //qDebug() << "SetupDialog::setData NOT FIRST TIME! " << endl;
-
         miscPage->setUseDefaultDBPath(miscPage->getDefaultDBPath());
     }
 
@@ -323,7 +340,6 @@ void SetupDialog::slotCancelButtonClicked()
     {
         if (nolog)
         {
-
             QMessageBox msgBox;
             msgBox.setIcon(QMessageBox::Information);
             msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
@@ -342,13 +358,8 @@ void SetupDialog::slotCancelButtonClicked()
                 emit debugLog (Q_FUNC_INFO, "END-2", logSeverity);
                 return;
             }
-
         }
-        //emit exitSignal(2);
     }
-
-    //
-
     close();
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
 }
@@ -421,7 +432,7 @@ void SetupDialog::changePage(QListWidgetItem *current, QListWidgetItem *previous
 
 void SetupDialog::slotOkButtonClicked()
 {
-   //qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
+    //qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
     emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
 
     if (!miscPage->areDBPathChangesApplied())
@@ -435,7 +446,7 @@ void SetupDialog::slotOkButtonClicked()
         return;
     }
 
-    if ((userDataPage->getStationQrz()).length() < 3){ // There are no valid calls with less than 3 Chars
+    if (!util->isValidCall(userDataPage->getStationQrz())){ //
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
         msgBox.setText(tr("You need to enter at least a valid QRZ."));
@@ -447,7 +458,7 @@ void SetupDialog::slotOkButtonClicked()
 
     if (!haveAtleastOneLog())
     {
-          //qDebug() << "SetupDialog::slotOkButtonClicked - NO LOG!" << endl;
+        //qDebug() << "SetupDialog::slotOkButtonClicked - NO LOG!" << endl;
 
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
@@ -462,7 +473,7 @@ void SetupDialog::slotOkButtonClicked()
         emit debugLog (Q_FUNC_INFO, "END-3", logSeverity);
         return;
     }
-
+    //qDebug() << "SetupDialog::slotOkButtonClicked - 10" << endl;
     QFile file (configFileName);
     QString tmp;
     tmp = "true";
@@ -473,15 +484,13 @@ void SetupDialog::slotOkButtonClicked()
     int contestCategory;
     int modes;*/
     //QRZ/CQ/ITU/CONTEST
-        stream << "version=" << version << ";" << endl;        
-        stream << "callsign="  << userDataPage->getStationQrz() << ";" << endl;
-        if ((userDataPage->getOperators()).length() >= 3){ // There are no valid calls with less than 3 Chars
-            stream << "operators="  << userDataPage->getOperators() << ";" << endl;
-        }
-        //stream << "contest="  << userDataPage->getContest()  <<   ";" << endl;
-        //stream << "contestcategory=" << userDataPage->getContestCategory() <<  ";" <<  endl;
-        stream << "cqz=" << QString::number(userDataPage->getCQz()) <<  ";" <<  endl;
-        stream << "ituz=" << QString::number(userDataPage->getITUz()) <<  ";" <<  endl;
+    stream << "Version=" << version << ";" << endl;
+    stream << "Callsign="  << userDataPage->getStationQrz() << ";" << endl;
+    if ((userDataPage->getOperators()).length() >= 3){ // There are no valid calls with less than 3 Chars
+        stream << "Operators="  << userDataPage->getOperators() << ";" << endl;
+    }
+    stream << "CQz=" << QString::number(userDataPage->getCQz()) <<  ";" <<  endl;
+    stream << "ITUz=" << QString::number(userDataPage->getITUz()) <<  ";" <<  endl;
 
         if ( locator->isValidLocator(userDataPage->getStationLocator()) )
         {
@@ -554,7 +563,7 @@ void SetupDialog::slotOkButtonClicked()
         {
             stream << "Power=" << userDataPage->getPower() << ";" << endl;
         }
-
+        //qDebug() << "SetupDialog::slotOkButtonClicked - 20" << endl;
         //stream << "locator=" << (MyLocatorkLineEdit->text ()).toUpper () <<  ";" << endl;
         //stream << "CallUsed=" << (UserDataPage.qrzLineEdit).text() <<  ";" << endl;
         //stream << "Operators=" <<  ";" << endl;
@@ -571,19 +580,20 @@ void SetupDialog::slotOkButtonClicked()
         stream << "ImperialSystem=" << miscPage->getImperial() << ";" <<  endl;
         stream << "SendQSLWhenRec=" << miscPage->getSendQSLWhenRec() << ";" <<  endl;
         stream << "ShowCallsignInSearch=" << miscPage->getShowStationCallSignInSearch() << ";" <<  endl;
-        stream << "KeepMyData=" << miscPage->getKeepMyData() << ";" <<  endl;
+        //stream << "KeepMyData=" << miscPage->getKeepMyData() << ";" <<  endl;
         stream << "CompleteWithPrevious=" << miscPage->getCompleteWithPrevious() << ";" <<  endl;
         stream << "CheckNewVersions=" << miscPage->getCheckNewVersions() << ";" <<  endl;
         stream << "ManageDXMarathon=" << miscPage->getDXMarathon() << ";" <<  endl;
         stream << "DebugLog=" << miscPage->getDebugLog() << ";" << endl;
         //stream << "LogSort=" << miscPage->getLogSort() << ";" << endl;
         stream << "SendEQSLByDefault=" << miscPage->getSendEQSLByDefault() << ";" << endl;
-        stream << "PSTRotatorActive=" << interfacesWindowsPage->getSendToPSTRotator() << ";" << endl;
-        stream << "PSTRotatorServer=" << interfacesWindowsPage->getPSTRotatorUDPServer() << ";" << endl;
-        stream << "PSTRotatorPort=" << interfacesWindowsPage->getPSTRotatorUDPServerPort() << ";" << endl;
+        //stream << "PSTRotatorActive=" << interfacesWindowsPage->getSendToPSTRotator() << ";" << endl;
+        //stream << "PSTRotatorServer=" << interfacesWindowsPage->getPSTRotatorUDPServer() << ";" << endl;
+        //stream << "PSTRotatorPort=" << interfacesWindowsPage->getPSTRotatorUDPServerPort() << ";" << endl;
 
+        //qDebug() << "SetupDialog::slotOkButtonClicked - 30" << endl;
 
-        if ((miscPage->getReportInfo()).toUpper() == "TRUE")
+        if ( miscPage->getReportInfo())
         {
             stream << "ProvideInfo=True;"  <<  endl;
         }
@@ -622,43 +632,112 @@ void SetupDialog::slotOkButtonClicked()
         stream << "ConfirmedColor=" << colorsPage->getConfirmedColor() << ";" <<  endl;
         stream << "DefaultColor=" << colorsPage->getDefaultColor() << ";" <<  endl;
         stream << "SelectedLog=" << QString::number(logsPage->getSelectedLog()) << ";" <<  endl;
-
+        //qDebug() << "SetupDialog::slotOkButtonClicked SelectedLog: " << logsPage->getSelectedLog() << endl;
         // CLUBLOG
+        //qDebug() << "SetupDialog::slotOkButtonClicked - 40" << endl;
 
-        if ((clubLogPage->getClubLog()).toUpper() == "TRUE" )
-        {
-            stream << "ClubLogActive=" << clubLogPage->getClubLog() << ";" <<  endl;
-            stream << "ClubLogRealTime=" << clubLogPage->getClubLogRealTime() << ";" <<  endl;
-            stream << "ClubLogCall=" << clubLogPage->getCallsign() << ";" <<  endl;
-            stream << "ClubLogPass=" << clubLogPage->getPassword() << ";" <<  endl;
-            stream << "ClubLogEmail=" << clubLogPage->getEmail() << ";" <<  endl;
-            stream << "ClubLogUseStationCallsign=" << clubLogPage->getUseQSOStationCallsign() << ";" << endl;
-        }
+            if (eLogPage->getClubLogActive())
+            {
+                stream << "ClubLogActive=True;"<<  endl;
+            }
 
-        // CLUBLOG
+            if (eLogPage->getClubLogRealTime())
+            {
+                stream << "ClubLogRealTime=True;" <<  endl;
+            }
+
+            tmp = eLogPage->getClubLogEmail() ;
+            if (tmp.length()>0)
+            {
+                 stream << "ClubLogEmail=" << tmp << ";" <<  endl;
+            }
+
+            tmp = eLogPage->getClubLogPassword() ;
+            if (tmp.length()>0)
+            {
+                stream << "ClubLogPass=" << tmp << ";" <<  endl;
+            }
+
+        //qDebug() << "SetupDialog::slotOkButtonClicked - 50" << endl;
+        // eQSL
+
+
+            if (eLogPage->getEQSLActive())
+            {
+                stream << "eQSLActive=True;" <<  endl;
+            }
+
+
+            tmp = eLogPage->getEQSLUser();
+            if (tmp.length()>0)
+            {
+                 stream << "eQSLCall=" << tmp << ";" <<  endl;
+            }
+
+            tmp = eLogPage->getEQSLPassword() ;
+            if (tmp.length()>0)
+            {
+                stream << "eQSLPass=" << tmp << ";" <<  endl;
+            }
+
+        // eQSL - END
+
+        // QRZ.com
+
+            //qDebug() << "SetupDialog::slotOkButtonClicked - Storing QRZ.com data" << endl;
+
+            if (eLogPage->getQRZCOMActive())
+            {
+                stream << "QRZcomActive=True;" <<  endl;
+            }
+            tmp = eLogPage->getQRZCOMUser();
+            if (tmp.length()>0)
+            {
+                 stream << "QRZcomUser=" << tmp << ";" <<  endl;
+            }
+            tmp = eLogPage->getQRZCOMPassword();
+            if (tmp.length()>0)
+            {
+                 stream << "QRZcomPass=" << tmp << ";" <<  endl;
+            }
+
+            if (eLogPage->getQRZCOMAutoCheck())
+            {
+                 stream << "QRZcomAuto=True;" << endl;
+            }
+            tmp = eLogPage->getQRZCOMLogBookKEY();
+            if (tmp.length()>0)
+            {
+                 stream << "QRZcomLogBookKey=" << tmp << ";" <<  endl;
+            }
+
+        // QRZ.com - END
+
+        //qDebug() << "SetupDialog::slotOkButtonClicked - 60" << endl;
 
         // LOTW
-        stream << "LoTWActive=" << lotwPage->getLoTW() << ";" <<  endl;
-        tmp = lotwPage->getPath();
+        stream << "LoTWActive=" << eLogPage->getLoTWActive() << ";" <<  endl;
+        tmp = eLogPage->getTQSLPath();
         if (tmp.length()>0)
         {
             stream << "LoTWPath=" << tmp << ";" <<  endl;
         }
-        tmp = lotwPage->getLoTWUser();
+        tmp = eLogPage->getLoTWUser();
         if (tmp.length()>0)
         {
             stream << "LoTWUSer=" << tmp << ";" <<  endl;
         }
-        tmp = lotwPage->getLoTWPass();
+        tmp = eLogPage->getLoTWPass();
         if (tmp.length()>0)
         {
             stream << "LoTWPass=" << tmp << ";" <<  endl;
         }
 
         // LOTW
-
+        //qDebug() << "SetupDialog::slotOkButtonClicked - 70" << endl;
         //WSJTX
         stream << "UDPServer=" << UDPPage->getUDPServer() << ";" <<  endl;
+        stream << "UDPNetworkInterface=" << UDPPage->getNetworkInterface() << ";" <<  endl;
         stream << "UDPServerPort=" << UDPPage->getUDPServerPort() << ";" <<  endl;
         stream << "LogFromWSJTX=" << UDPPage->getLogFromWSJTx() << ";" <<  endl;
         stream << "LogAutoFromWSJTX=" << UDPPage->getAutoLogFromWSJTx() << ";" <<  endl;
@@ -673,21 +752,31 @@ void SetupDialog::slotOkButtonClicked()
 
         //WSJTX
 
+        //Windows Size
+        if (windowSize.length()>0)
+        {
+            stream << "MainWindowSize=" << windowSize << ";" <<  endl;
+        }
+        if (latestBackup.length()>0)
+        {
+            stream << "LatestBackup=" << latestBackup << ";" << endl;
+        }
         file.close ();
     }
-       //qDebug() << "SetupDialog::slotOkButtonClicked - just before leaving" << endl;
+    //qDebug() << "SetupDialog::slotOkButtonClicked - just before leaving" << endl;
     QDialog::accept();
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
-       //qDebug() << "SetupDialog::slotOkButtonClicked - END" << endl;
+    //qDebug() << "SetupDialog::slotOkButtonClicked - END" << endl;
     //close();
 }
 
 void SetupDialog::slotReadConfigData()
 {
-      //qDebug() << "SetupDialog::slotReadConfigData" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData" << endl;
     emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
     if (firstTime)
     {
+        //qDebug() << "SetupDialog::slotReadConfigData - First time" << endl;
         setDefaults();
         bands.removeDuplicates();
         modes.removeDuplicates();
@@ -695,26 +784,24 @@ void SetupDialog::slotReadConfigData()
         bandModePage->setActiveBands(bands);
     }
 
-      //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
 
     QFile file(configFileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
-           //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
+        //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
         //firstTime = true;
         emit debugLog (Q_FUNC_INFO, "END-1", logSeverity);
         return;
     }
-      //qDebug() << "SetupDialog::slotReadConfigData - 2" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData - 2" << endl;
     //dxClusterServers.clear();
 
-
-
     while (!file.atEnd()) {
         QByteArray line = file.readLine();
         processConfigLine(line);        
-          //qDebug() << "SetupDialog::slotReadConfigData - in the while" << endl;
+        //qDebug() << "SetupDialog::slotReadConfigData - in the while" << endl;
     }
-      //qDebug() << "SetupDialog::slotReadConfigData - 3" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData - 3" << endl;
 
     dxClusterPage->setDxclusterServersComboBox(dxClusterServers);
     dxClusterPage->setSelectedDxClusterServer(dxClusterServerToUse);
@@ -733,15 +820,14 @@ void SetupDialog::slotReadConfigData()
     bandModePage->setActiveModes(modes);
     bands.removeDuplicates();
     bandModePage->setActiveBands(bands);
-      //qDebug() << "SetupDialog::slotReadConfigData - END" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData - END" << endl;
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
 
 }
 
 bool SetupDialog::processConfigLine(const QString &_line)
 {
-
-      //qDebug() << "SetupDialog::processConfigLine: " << _line << endl;
+    //qDebug() << "SetupDialog::processConfigLine: " << _line << endl;
     emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
 
     QString line = _line.simplified();
@@ -805,12 +891,10 @@ bool SetupDialog::processConfigLine(const QString &_line)
     }else if (tab=="DBPATH"){
         miscPage->setUseDefaultDBPath(value);
     }else if (tab=="DEFAULTADIFFILE"){
-        miscPage->setDefaultFileName(value.toUpper());
+        miscPage->setDefaultFileName(value);
            //qDebug() << "SetupDialog::processConfigLine: FILE: " << value << endl;
     }else if (tab=="IMPERIALSYSTEM"){
         miscPage->setImperial(value.toUpper());
-    }else if (tab=="KEEPMYDATA"){
-        miscPage->setKeepMyData(value.toUpper());
     }else if (tab=="COMPLETEWITHPREVIOUS"){
         miscPage->setCompleteWithPrevious(value.toUpper());
     }else if (tab=="SENDQSLWHENREC"){
@@ -818,7 +902,7 @@ bool SetupDialog::processConfigLine(const QString &_line)
     }else if (tab=="MANAGEDXMARATHON"){
         miscPage->setDXMarathon(value.toUpper());
     }else if (tab=="DEBUGLOG"){
-        miscPage->setDebugLog(value.toUpper());
+        miscPage->setDebugLog(value);
     }
     else if (tab=="SHOWCALLSIGNINSEARCH"){
         miscPage->setShowStationCallSignInSearch(value.toUpper());
@@ -837,6 +921,7 @@ bool SetupDialog::processConfigLine(const QString &_line)
     else if (tab=="SENDEQSLBYDEFAULT"){
         miscPage->setSetEQSLByDefault(value);
     }
+    /*
     else if (tab=="PSTROTATORACTIVE"){
         interfacesWindowsPage->setSendToPSTRotator(value);
     }
@@ -847,9 +932,13 @@ bool SetupDialog::processConfigLine(const QString &_line)
     {
         interfacesWindowsPage->setPSTRotatorUDPServer(value);
     }
+    */
     else if (tab=="UDPSERVER"){
         UDPPage->setUDPServer(value);
     }
+    else if (tab=="UDPNETWORKINTERFACE"){
+        UDPPage->setNetworkInterface(value);
+    }
     else if (tab=="UDPSERVERPORT"){
         UDPPage->setUDPServerPort(value);
     }
@@ -940,7 +1029,6 @@ bool SetupDialog::processConfigLine(const QString &_line)
         {
             userDataPage->setStationLocator(value);
         }
-
     }else if (tab =="DXCLUSTERSHOWHF"){
         dxClusterPage->setShowHFRadiobutton(value);
     }else if (tab =="DXCLUSTERSHOWVHF"){
@@ -960,7 +1048,6 @@ bool SetupDialog::processConfigLine(const QString &_line)
     }else if(tab =="DXCLUSTERSERVERPORT"){
         dxClusterServers << value;
            //qDebug() << "SetupDialog::processConfigLine: dxClusterServers: " << dxClusterServers.last() << endl;
-
     }else if (tab  =="DXCLUSTERSERVERTOUSE"){        
         dxClusterServerToUse=value;
     }
@@ -980,7 +1067,6 @@ bool SetupDialog::processConfigLine(const QString &_line)
           //qDebug() << "SetupDialog::processConfigLine: DEFAULTCOLOR: " << value << endl;
     }else if(tab =="HAMLIBRIGTYPE"){
           //qDebug() << "SetupDialog::processConfigLine: Before HAMLIBRIGTYPE: " << value << endl;
-
         hamlibPage->setRigType(value);
           //qDebug() << "SetupDialog::processConfigLine: After HAMLIBRIGTYPE: " << value << endl;
     }else if(tab =="HAMLIBSERIALPORT"){
@@ -1012,7 +1098,8 @@ bool SetupDialog::processConfigLine(const QString &_line)
     }else if(tab =="HAMLIBSERIALDTR"){
           //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALDTR: " << value << endl;
         //hamlibPage->setDTR(value);
-
+    }else if (tab == "HAMLIBRIGPOLLRATE"){
+        hamlibPage->setPollingInterval(value.toInt());
     }else if(tab =="SELECTEDLOG"){
            //qDebug() << "SetupDialog::processConfigLine: SELECTEDLOG: " << value << endl;
         i = value.toInt();
@@ -1034,36 +1121,86 @@ bool SetupDialog::processConfigLine(const QString &_line)
            //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist END" << endl;
 
     }else if(tab =="CLUBLOGACTIVE"){
-        clubLogPage->setClubLog(value);
+        eLogPage->setClubLogActive(util->trueOrFalse(value));
+        //clubLogPage->setClubLog(value);
     }
     else if(tab =="CLUBLOGREALTIME"){
-        clubLogPage->setClubLogRealTime(value);
-    }
-    else if(tab =="CLUBLOGCALL"){
-        clubLogPage->setCallsign(value);
+        //clubLogPage->setClubLogRealTime(value);
+        eLogPage->setClubLogRealTime(util->trueOrFalse(value));
     }
     else if(tab =="CLUBLOGPASS"){
-        clubLogPage->setPassword(value);
+        //clubLogPage->setPassword(value);
+        eLogPage->setClubLogPassword(value);
     }
     else if(tab =="CLUBLOGEMAIL"){
-        clubLogPage->setEmail(value);
+        //clubLogPage->setEmail(value);
+        eLogPage->setClubLogEmail(value);
     }
-    else if(tab =="CLUBLOGUSESTATIONCALLSIGN"){
-            clubLogPage->setUseStationCall(value);
+    else if(tab =="EQSLACTIVE"){
+        //eQSLPage->setActive(value);
+        eLogPage->setEQSLActive(util->trueOrFalse(value));
+    }
+    else if(tab =="EQSLCALL"){
+        //eQSLPage->setCallsign(value);
+        eLogPage->setEQSLEmail(value);
+    }
+    else if(tab =="EQSLPASS"){
+        //eQSLPage->setPassword(value);
+        eLogPage->setEQSLPassword(value);
+    }    
+    else if(tab =="QRZCOMACTIVE"){
+        //eQSLPage->setActive(value);
+        eLogPage->setQRZCOMActive(value);
+    }
+    else if(tab =="QRZCOMUSER"){
+        eLogPage->setQRZCOMUser(value);
+    }
+    else if(tab =="QRZCOMAUTO"){
+        eLogPage->setQRZCOMAutoCheck(value);
+    }
+    else if(tab =="QRZCOMPASS"){
+        eLogPage->setQRZCOMPassword(value);
+    }
+    else if(tab =="QRZCOMLOGBOOKKEY"){
+        eLogPage->setQRZCOMLogBookKEY(value);
     }
     else if(tab =="LOTWACTIVE"){
-        lotwPage->setLoTW(value);
+        eLogPage->setLoTWActive(util->trueOrFalse(value));
     }
     else if(tab =="LOTWPATH"){
-        lotwPage->setPath(value);
+        eLogPage->setTQSLPath(value);
     }
     else if(tab =="LOTWUSER"){
-            lotwPage->setLoTWUser(value);
+        eLogPage->setLoTWUser(value);
     }
     else if(tab =="LOTWPASS"){
-            lotwPage->setLoTWPass(value);
+        eLogPage->setLoTWPass(value);
+    }
+    else if(tab =="MAINWINDOWSIZE"){
+        QStringList values;
+        values.clear();
+        values << value.split("x");
+        if ((values.at(0).toInt()>0) && (values.at(1).toInt()>0))
+        {
+            windowSize = value;
+        }
 
-    }else{
+    }
+    else if (tab == "LATESTBACKUP")
+    {
+        if (value.length()>0)
+        {
+            latestBackup = value;
+        }
+        else
+        {
+            latestBackup = QString();
+        }
+    //s.append("LatestBackup=" + (QDateTime::currentDateTime()).toString("yyyyMMdd-hhmmss") + ";\n" );
+    }
+
+    else
+    {
            //qDebug() << "SetupDialog::processConfigLine: NONE: " << endl;
     }
 
@@ -1178,8 +1315,7 @@ void SetupDialog::setDefaults()
     miscPage->setImperial("FALSE"); //Metric system is the default
     miscPage->setAlwaysADIF("FALSE");
     miscPage->setSendQSLWhenRec("TRUE");
-    miscPage->setShowStationCallSignInSearch("TRUE");
-    miscPage->setKeepMyData("TRUE");
+    miscPage->setShowStationCallSignInSearch("TRUE");    
     miscPage->setCheckNewVersions("TRUE");
     miscPage->setReportInfo("FALSE");
     miscPage->setDXMarathon("FALSE");
@@ -1193,9 +1329,9 @@ void SetupDialog::setDefaults()
     UDPPage->setLogFromWSJTx("FALSE");
     UDPPage->setReaDataFromWSJTx("FALSE");
     UDPPage->setAutoLogFromWSJTx("FALSE");
-    interfacesWindowsPage->setSendToPSTRotator("FALSE");
-    interfacesWindowsPage->setPSTRotatorUDPServer("locahost");
-    interfacesWindowsPage->setPSTRotatorUDPServerPort("12040");
+    //interfacesWindowsPage->setSendToPSTRotator("FALSE");
+    //interfacesWindowsPage->setPSTRotatorUDPServer("locahost");
+    //interfacesWindowsPage->setPSTRotatorUDPServerPort("12040");
 
     dxClusterPage->setShowHFRadiobutton("TRUE");
     dxClusterPage->setShowVHFRadiobutton("TRUE");
@@ -1261,17 +1397,19 @@ bool SetupDialog::haveAtleastOneLog()
 void SetupDialog::setClubLogActive(const bool _b)
 {
     emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
-    if (_b == true)
-    {
-        clubLogPage->setClubLog("True");
-    }
-    else
-    {
-        clubLogPage->setClubLog("False");
-    }
+    eLogPage->setClubLogActive(_b);
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
 }
 
+void SetupDialog::setQRZCOMAutoCheckActive(const bool _b)
+{
+     eLogPage->setQRZCOMAutoCheck(util->boolToQString(_b));
+}
+
+void SetupDialog::setEQSLActive(const bool _b)
+{
+    eLogPage->setEQSLActive(_b);
+}
 
 void SetupDialog::checkIfNewBandOrMode()
 {
