@@ -35,12 +35,15 @@
 #include "setuppages/setuppagecolors.h"
 #include "setuppages/setuppagelogs.h"
 #include "setuppages/setuppageworldeditor.h"
-#include "setuppages/setuppageclublog.h"
-#include "setuppages/setuppagelotw.h"
+//#include "setuppages/setuppageclublog.h"
+#include "setuppages/setuppageelog.h"
+//#include "setuppages/setuppageeqsl.h"
+//#include "setuppages/setuppagelotw.h"
 #include "setuppages/setuppageudp.h"
 #include "setuppages/setuppagesats.h"
 #include "setuppages/setuppagehamlib.h"
-#include "setuppages/setuppageinterfaceswindows.h"
+#include "setuppages/setuppagesubdivisions.h"
+//#include "setuppages/setuppageinterfaceswindows.h"
 #include "utilities.h"
 #include "locator.h"
 
@@ -54,21 +57,22 @@ class SetupDialog : public QDialog
     Q_OBJECT
 
 public:
-    SetupDialog(DataProxy_SQLite *dp, const bool _firstTime=true);
-    SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const QString &_softwareVersion, const int _page=0, const bool _firstTime = true);
+    //SetupDialog(DataProxy_SQLite *dp, const bool _firstTime=true, QWidget *parent = nullptr);
+    SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const QString &_softwareVersion, const int _page=0, const bool _firstTime = true, QWidget *parent = nullptr);
     ~SetupDialog();
 
     void setData(const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime=true);
     void setClubLogActive(const bool _b);
+    void setEQSLActive(const bool _b);
+    void setQRZCOMAutoCheckActive(const bool _b);
     void checkIfNewBandOrMode();
     void setSeverity(const int _sev);
 
-public slots:
-
 signals:
     void exitSignal(const int status); // 1 = OK, -1 = NOK, 2 = Cancel clicked
     void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
     void debugLog (QString _func, QString _msg, int _level);
+    void qrzcomAuto(bool);
     //void newLogRequested(const bool _s); // true show new log
 
 private slots:
@@ -81,6 +85,7 @@ private slots:
     void slotSetOperators(const QString &_p);            // We receive te station operators from the userData tab to fill the new log
     void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
     void slotFocusOK();
+    void slotQRZCOMAuto(const bool _b);
 
 private:
     void showEvent(QShowEvent *event);
@@ -122,13 +127,16 @@ private:
     SetupPageColors *colorsPage;
     SetupPageLogs *logsPage;
     SetupPageWorldEditor *worldEditorPage;
-    SetupPageClubLog *clubLogPage;
-    SetupPageLoTW *lotwPage;
+    SetupPageELog *eLogPage;
+    //SetupPageClubLog *clubLogPage;
+    //SetupPageEQSL *eQSLPage;
+    //SetupPageLoTW *lotwPage;
     SetupPageUDP *UDPPage;
     SetupPageSats *satsPage;
     SetupPageHamLib *hamlibPage;
-    SetupPageInterfacesWindows *interfacesWindowsPage;
-
+    //SetupPageInterfacesWindows *interfacesWindowsPage;
+    SetupPageSubdivisions *subdivisionsPage;
+    //SetupPageRegionalAwards *regionalAwardsPage;
     int pageRequested; // The page on the Dialog that is requested to be shown when you call it
     //QString klogDir;
     QString configFileName, version;
@@ -138,6 +146,8 @@ private:
     DataProxy_SQLite *dataProxy;
 
     Utilities *util;
+    QString windowSize;
+    QString latestBackup;
 
     int constrid; // Just an id for the constructor to check who is being executed at one specific time
     int logSeverity;    // Manages as syslog, the severity of the application debug log
