@@ -7,7 +7,7 @@ SetupPageHamLib::SetupPageHamLib(DataProxy_SQLite *dp, QWidget *parent) : QWidge
     activateHamlibCheckBox = new QCheckBox();
     readOnlyModeCheckBox = new QCheckBox();
     rigTypeComboBox = new QComboBox();
-    poolIntervalQSpinBox = new QSpinBox();
+    pollIntervalQSpinBox = new QSpinBox();
     serialBaudsComboBox = new QComboBox();
     serialPortComboBox = new QComboBox();
 
@@ -27,6 +27,8 @@ SetupPageHamLib::SetupPageHamLib(DataProxy_SQLite *dp, QWidget *parent) : QWidge
 
    strings.clear();
    //strings << "1200" << "2400" << "4800" << "9600" << "19200" << "38400" << "57600" << "115200";
+    pollMax = 5000;
+    pollMin = 10;
 
 
     createUI();
@@ -76,21 +78,21 @@ void SetupPageHamLib::createUI()
     rigTypeLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
     rigTypeLabel->setEnabled(true);
       //qDebug() << "SetupPageHamLib::createUI-30" << endl;
-    QString poolTip = QString(tr("Defines the interval to pool the radio in msecs."));
+    QString pollTip = QString(tr("Defines the interval to poll the radio in msecs."));
 
-    poolIntervalQSpinBox->setToolTip(poolTip);
-    poolIntervalQSpinBox->setMinimum(10);
-    poolIntervalQSpinBox->setMaximum(5000);
+    pollIntervalQSpinBox->setToolTip(pollTip);
+    pollIntervalQSpinBox->setMinimum(pollMin);
+    pollIntervalQSpinBox->setMaximum(pollMax);
 
-    QLabel *poolIntervalLabel = new QLabel(tr("Pool interval"));
-    poolIntervalLabel->setBuddy(rigTypeComboBox);
-    poolIntervalLabel->setToolTip(poolTip);
-    poolIntervalLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
-    poolIntervalLabel->setEnabled(true);
+    QLabel *pollIntervalLabel = new QLabel(tr("Poll interval"));
+    pollIntervalLabel->setBuddy(rigTypeComboBox);
+    pollIntervalLabel->setToolTip(pollTip);
+    pollIntervalLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
+    pollIntervalLabel->setEnabled(true);
 
-    QHBoxLayout *poolIntervalLayout = new QHBoxLayout;
-    poolIntervalLayout->addWidget(poolIntervalLabel);
-    poolIntervalLayout->addWidget(poolIntervalQSpinBox);
+    QHBoxLayout *pollIntervalLayout = new QHBoxLayout;
+    pollIntervalLayout->addWidget(pollIntervalLabel);
+    pollIntervalLayout->addWidget(pollIntervalQSpinBox);
 
 
     serialPortComboBox->addItems(serialPorts);
@@ -162,7 +164,7 @@ void SetupPageHamLib::createUI()
     QGridLayout *topData = new QGridLayout;
     topData->addWidget(rigTypeLabel, 0, 0);
     topData->addWidget(rigTypeComboBox, 0, 1);
-    topData->addLayout(poolIntervalLayout, 0, 2);
+    topData->addLayout(pollIntervalLayout, 0, 2);
     topData->addWidget(serialPortLabel, 1, 0);
     topData->addWidget(serialPortComboBox, 1, 1);
     topData->addWidget(scanSerialPortButton, 1, 2);
@@ -204,11 +206,17 @@ void SetupPageHamLib::createUI()
 
 void SetupPageHamLib::setRig()
 {
-      //qDebug() << "SetupPageHamLib::SetRig" << endl;
+   //qDebug()() << "SetupPageHamLib::SetRig" << endl;
   // Rutine to fill the rig combo boxes
   // Do not display debug codes when load the rig's
-
-    rigTypeComboBox->insertItems(0, hamlib->getRigList());
+    QStringList rigs;
+    rigs.clear();
+    rigs << hamlib->getRigList();
+   //qDebug()() << "SetupPageHamLib::SetRig - rigs: " << QString::number(rigs.length()) << endl;
+    rigTypeComboBox->clear();
+    rigTypeComboBox->addItems(rigs);
+    //qDebug() << "SetupPageHamLib::SetRig - rigs: " << QString::number(rigs.length()) << endl;
+    //rigTypeComboBox->insertItems(0, rigs);
 /*
     rig_set_debug (RIG_DEBUG_NONE);
 
@@ -219,7 +227,7 @@ void SetupPageHamLib::setRig()
   rigTypeComboBox->insertItems (0, strings);
   strings.clear ();
   */
-      //qDebug() << "SetupPageHamLib::SetRig - END" << endl;
+   //qDebug()() << "SetupPageHamLib::SetRig - END" << endl;
 }
 /*
 int SetupPageHamLib::addRigToList (const struct rig_caps *caps, void *data)
@@ -262,6 +270,7 @@ void SetupPageHamLib::setDefaults()
     flowControlComboBox->setCurrentIndex(0);
     parityComboBox->setCurrentIndex(0);
     stopBitsComboBox->setCurrentIndex(0);
+    pollIntervalQSpinBox->setValue(300);
 
     //RTSCheckBox->setChecked(false);
     //DTRCheckBox->setChecked(false);
@@ -321,6 +330,7 @@ QString SetupPageHamLib::getData()
     //_output = _output + "HamLibRigType=" + _rigType + "\n";
     _output = _output + "HamlibSerialPort=" + _serialPort + ";\n";
     _output = _output + "HamlibSerialBauds=" + _baudsSpeed + ";\n";
+    _output = _output + "HamlibRigPollRate=" + QString::number(pollIntervalQSpinBox->value()) + ";\n";
 
 
       //qDebug() << "SetupPageHamLib::getData: " << _output << endl;
@@ -378,6 +388,7 @@ bool SetupPageHamLib::setSerialSpeed(const QString &_speed )
 void SetupPageHamLib::setActive(const QString &_active)
 {
       //qDebug() << "SetupPageHamLib::setActive: " << _active << endl;
+
     if (_active.toUpper() == "TRUE")
     {
         activateHamlibCheckBox->setChecked(true);
@@ -596,6 +607,14 @@ void SetupPageHamLib::setStopBits(const QString &_st)
         stopBitsComboBox->setCurrentIndex(0);
     }
 }
+void SetupPageHamLib::setPollingInterval(const int _msecs)
+{
+    if ((_msecs>=pollMin) && (_msecs<=pollMax))
+    {
+        pollIntervalQSpinBox->setValue(_msecs);
+    }
+}
+
 /*
 void SetupPageHamLib::setRTS(const QString &_state)
 {
