@@ -43,6 +43,7 @@ public:
     explicit SetupPageHamLib(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     QString getData();
     bool setRigType(const QString &_radio);
+    void setPollingInterval(const int _msecs);
     bool setSerialPort(const QString &_port);
     bool setSerialSpeed(const QString &_speed );
     void setActive(const QString &_active);
@@ -52,7 +53,7 @@ public:
     void setFlowControl(const QString &_st);
     void setParity(const QString &_st);
     void setStopBits(const QString &_st);
-    void setPoolInterval(const QString &_st);
+    //void setPollInterval(const QString &_st);
     void setReadOnly(const QString &_m);
 
 
@@ -74,7 +75,7 @@ private:
     QString getFlowControl();
     QString getParity();
     QString getStopBits();
-    QString getPoolInterval();
+    QString getPollInterval();
 
 /*
 
@@ -90,7 +91,8 @@ StopBits { OneStop, OneAndHalfStop, TwoStop, UnknownStopBits }
                 *flowControlComboBox, *parityComboBox, *stopBitsComboBox;
     //QSpinBox *serialBaudsSpinBox;
     QLineEdit *serialPort;
-    QSpinBox *poolIntervalQSpinBox;
+    QSpinBox *pollIntervalQSpinBox;
+    int pollMin, pollMax;
 
     HamLibClass *hamlib;
 
