@@ -129,7 +129,7 @@ void SetupPageLogs::createNewLog()
     {
         newLog->setOperators(defaultOperators);
     }
-    newLog->setDateString(QDate::currentDate().toString("yyyy/MM/dd"));
+    newLog->setDateString(QDate::currentDate().toString("yyyy-MM-dd"));
     newLog->setComment("");
 
     int result = newLog->exec();
@@ -491,7 +491,7 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
     contestBands  = (_qs.at(10)).toInt();
     typeContestN = (_qs.at(12)).toInt();
 */
-
+    /*
     bool editing;
     if ( (_qs.at(4)).toInt() == 1)
     {
@@ -501,7 +501,7 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
     {
         editing = false;
     }
-
+    */
     //OVERLAY = 11
 /*
     QString _dateString = _qs.at(0);
@@ -527,6 +527,10 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
         logsModel->select();
         updateSelectedLogs();
     }
+    else
+    {
+        showError(tr("The new log could not be created."));
+    }
 
     // We send the data to the main tab
     QStringList logData;
@@ -608,7 +612,7 @@ int SetupPageLogs::getSelectedLog()
     qs.clear();
     qs << selectedLog.split("-");
     i = (qs.at(0)).toInt();
-      //qDebug() << "SetupPageLogs::getSelectedLog: " << QString::number(i) << endl;
+    //qDebug() << "SetupPageLogs::getSelectedLog: " << QString::number(i) << endl;
     if (i>=1)
     {
         return i;
