@@ -163,7 +163,7 @@ void SetupPageLogsNew::createWidget()
     operatorsLineEdit->setToolTip(tr("Comma separated list of operators: callsign1, callsign2."));
 
     dateEdit->setToolTip(tr("Start date of this log."));
-    commentLineEdit->setToolTip(tr("Add a comment about this log."));
+    commentLineEdit->setToolTip(tr("Add a comment about this log. If filled, it will be shown in the main KLog title to identify the log."));
 
     //typeLabel->setText(tr("&Type of Operation"));
     //typeLabel->setWordWrap(true);
@@ -587,7 +587,7 @@ void SetupPageLogsNew::slotOKButtonClicked()
     operators = operatorsLineEdit->text();
     //TODO: Check if operators is really including a comma separated list of QRZ
     comment = commentLineEdit->text();    
-    dateString = dateEdit->date().toString("yyyy/MM/dd");
+    dateString = dateEdit->date().toString("yyyy-MM-dd");
 
     logData.clear();
     logData << stationCallsign << operators << comment << dateString;
@@ -813,13 +813,13 @@ void SetupPageLogsNew::setOperators(const QString &_st)
 void SetupPageLogsNew::setComment(const QString &_st)
 {
     comment = _st;
-    commentLineEdit->setText(comment.toUpper());
+    commentLineEdit->setText(comment);
 }
 
 void SetupPageLogsNew::setDateString(const QString &_st)
 {
     dateString = _st;
-    dateEdit->setDate(QDate::fromString(dateString, "yyyy/MM/dd"));
+    dateEdit->setDate(QDate::fromString(dateString, "yyyy-MM-dd"));
 
 }
 
