@@ -43,7 +43,7 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     sendQSLWhenRecCheckBox = new QCheckBox(tr("Mark &QSO to send QSL when QSL is received"), this);
     completeWithPreviousCheckBox = new QCheckBox(tr("Complete QSO with previous data"));
     showStationCallWhenSearchCheckBox = new QCheckBox(tr("Show the Station &Callsign used in the search box"), this);  
-    keepMyDataCheckBox = new QCheckBox(tr("&Keep My Data for all QSOs"), this);
+    //keepMyDataCheckBox = new QCheckBox(tr("&Reset to My Data for all QSOs"), this);
     checkNewVersionCheckBox = new QCheckBox(tr("&Check for new versions automatically"), this);
     provideCallCheckBox = new QCheckBox(tr("&Provide Info for statistics"), this);
     useDxMarathonCheckBox = new QCheckBox(tr("Manage DX-Marathon"), this);
@@ -114,7 +114,7 @@ void SetupPageMisc::createUI()
     useDefaultName->setChecked(true);
     alwaysADIFCheckBox->setChecked(true);
     showStationCallWhenSearchCheckBox->setChecked(true);
-    keepMyDataCheckBox->setChecked(true);
+    //keepMyDataCheckBox->setChecked(true);
     completeWithPreviousCheckBox->setChecked(false);
     debugLogCheckBox->setChecked(false);
     UTCCheckbox->setChecked(true);
@@ -125,7 +125,7 @@ void SetupPageMisc::createUI()
 
     sendQSLWhenRecCheckBox->setToolTip(tr("QSOs will be marked as pending to send a QSL if you receive the DX QSL and have not sent yours."));
     showStationCallWhenSearchCheckBox->setToolTip(tr("The search box will also show the callsign on the air to do the QSO."));
-    keepMyDataCheckBox->setToolTip(tr("All the data from the My Data tab will be used or data from the previous QSO will be maintained."));
+    //keepMyDataCheckBox->setToolTip(tr("All the data from the My Data tab will be used or data from the previous QSO will be maintained."));
     checkNewVersionCheckBox->setToolTip(tr("Check if there is a new release of KLog available every time you start KLog."));
     provideCallCheckBox->setToolTip(tr("If new version checking is selected, KLog will send the developer your callsign, KLog version and Operating system to help in improving KLog."));
     imperialCheckBox ->setToolTip(tr("Check it for Imperial system (Miles instead of Kilometers)."));
@@ -164,7 +164,7 @@ void SetupPageMisc::createUI()
     mainLayou1->addWidget(realTimeCheckbox, 3, 1, 1, 1);
     mainLayou1->addWidget(imperialCheckBox, 4, 0, 1, 1);
     mainLayou1->addWidget(useDxMarathonCheckBox, 4, 1, 1, 1);
-    mainLayou1->addWidget(keepMyDataCheckBox, 5, 0, 1, 1);
+    //mainLayou1->addWidget(keepMyDataCheckBox, 5, 0, 1, 1);
     mainLayou1->addWidget(completeWithPreviousCheckBox, 5, 1, 1, 1);
     mainLayou1->addWidget(sendQSLWhenRecCheckBox,6, 0, 1, 1);
     mainLayou1->addWidget(sendEQSLByDefaultSearchCheckBox, 6, 1, 1, 1);
@@ -190,130 +190,46 @@ void SetupPageMisc::createActions(){
     //connect(UDPServerCheckBox, SIGNAL(clicked () ), this, SLOT(slotUDPServerCheckBoxClicked() ) );
 
 }
-/*
-
-QString SetupPageMisc::getLogSort(){
-
-    if (logSortCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
-}
-
-
-void SetupPageMisc::setLogSort(const QString &_t){
-
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        logSortCheckBox->setChecked(false);
-    }
-    else
-    {
-        logSortCheckBox->setChecked(true);
-    }
-}
-*/
 
 QString SetupPageMisc::getSendEQSLByDefault(){
 
-    if (sendEQSLByDefaultSearchCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
+    return util->boolToQString(sendEQSLByDefaultSearchCheckBox->isChecked());
 }
 
 void SetupPageMisc::setSetEQSLByDefault(const QString &_t){
 
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        sendEQSLByDefaultSearchCheckBox->setChecked(false);
-    }
-    else
-    {
-        sendEQSLByDefaultSearchCheckBox->setChecked(true);
-    }
+    sendEQSLByDefaultSearchCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
 QString SetupPageMisc::getRealTime(){
 
-    if (realTimeCheckbox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
+    return util->boolToQString(realTimeCheckbox->isChecked());
 }
 
 void SetupPageMisc::setRealTime(const QString &_t)
 {
-    //QString st = t;
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        realTimeCheckbox->setChecked(false);
-    }
-    else
-    {
-        realTimeCheckbox->setChecked(true);
-    }
+    realTimeCheckbox->setChecked(util->trueOrFalse(_t));
 }
 
 QString SetupPageMisc::getUTCTime(){
 
-    if (UTCCheckbox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
+    return util->boolToQString(UTCCheckbox->isChecked());
 }
 
 
-void SetupPageMisc::setUTCTime(const QString &_t){
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        UTCCheckbox->setChecked(false);
-    }
-    else
-    {
-        UTCCheckbox->setChecked(true);
-    }
+void SetupPageMisc::setUTCTime(const QString &_t)
+{
+    UTCCheckbox->setChecked(util->trueOrFalse(_t));
 }
 
 
 QString SetupPageMisc::getAlwaysADIF()
 {
-    if (alwaysADIFCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
+    return util->boolToQString(alwaysADIFCheckBox->isChecked());
 }
 void SetupPageMisc::setAlwaysADIF(const QString &_t)
 { // Defaul value is false
-    if ( (_t.toUpper()) == "TRUE")
-    {
-        alwaysADIFCheckBox->setChecked(true);
-    }
-    else
-    {
-        alwaysADIFCheckBox->setChecked(false);
-    }
-
+    alwaysADIFCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
 QString SetupPageMisc::getDefaultFileName()
@@ -342,54 +258,22 @@ void SetupPageMisc::slotOpenFileButtonClicked()
 
 QString SetupPageMisc::getUseDefaultName()
 {
-    if (useDefaultName->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
-
+    return util->boolToQString(useDefaultName->isChecked());
 }
 
 void SetupPageMisc::setUseDefaultName(const QString &_t)
 {
-
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        useDefaultName->setChecked(false);
-    }
-    else
-    {
-        useDefaultName->setChecked(true);
-    }
+    useDefaultName->setChecked(util->trueOrFalse(_t));
 }
 
 QString SetupPageMisc::getImperial()
 {
-    if (imperialCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
-
+    return util->boolToQString(imperialCheckBox->isChecked());
 }
 
 void SetupPageMisc::setImperial(const QString &_t)
 {
-
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        imperialCheckBox->setChecked(false);
-    }
-    else
-    {
-        imperialCheckBox->setChecked(true);
-    }
+    imperialCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
 
@@ -410,109 +294,47 @@ void SetupPageMisc::slotUseDefaultButtonStateChanged(int state)
     }
 }
 
-QString SetupPageMisc::getSendQSLWhenRec(){
-
-    if (sendQSLWhenRecCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
-
+QString SetupPageMisc::getSendQSLWhenRec()
+{
+    return util->boolToQString(sendQSLWhenRecCheckBox->isChecked());
 }
 
 
-void SetupPageMisc::setSendQSLWhenRec(const QString &_t){
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        sendQSLWhenRecCheckBox->setChecked(false);
-    }
-    else
-    {
-        sendQSLWhenRecCheckBox->setChecked(true);
-    }
+void SetupPageMisc::setSendQSLWhenRec(const QString &_t)
+{
+    sendQSLWhenRecCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
 QString SetupPageMisc::getShowStationCallSignInSearch()
 {
-
-    if (showStationCallWhenSearchCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
-
+    return util->boolToQString(showStationCallWhenSearchCheckBox->isChecked());
 }
 
 void SetupPageMisc::setShowStationCallSignInSearch(const QString &_t)
 {
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        showStationCallWhenSearchCheckBox->setChecked(false);
-    }
-    else
-    {
-        showStationCallWhenSearchCheckBox->setChecked(true);
-    }
-
+    showStationCallWhenSearchCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
-
+/*
 QString SetupPageMisc::getKeepMyData()
 {
-
-    if (keepMyDataCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
-
+    return util->boolToQString(keepMyDataCheckBox->isChecked());
 }
 
 void SetupPageMisc::setKeepMyData(const QString &_t)
 {
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        keepMyDataCheckBox->setChecked(false);
-    }
-    else
-    {
-        keepMyDataCheckBox->setChecked(true);
-    }
-
+    keepMyDataCheckBox->setChecked(util->trueOrFalse(_t));
 }
+*/
 
 QString SetupPageMisc::getCompleteWithPrevious()
 {
-    if (completeWithPreviousCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
-
+    return util->boolToQString(completeWithPreviousCheckBox->isChecked());
 }
 
 void SetupPageMisc::setCompleteWithPrevious(const QString &_t)
 {
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        completeWithPreviousCheckBox->setChecked(false);
-    }
-    else
-    {
-        completeWithPreviousCheckBox->setChecked(true);
-    }
+    completeWithPreviousCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
 
@@ -532,57 +354,22 @@ void SetupPageMisc::slotcheckNewVersionCheckBoxClicked()
 
 QString SetupPageMisc::getCheckNewVersions()
 {
-    if (checkNewVersionCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
+    return util->boolToQString(checkNewVersionCheckBox->isChecked());
 }
 
 void SetupPageMisc::setCheckNewVersions(const QString &_t)
 {
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        checkNewVersionCheckBox->setChecked(false);
-    }
-    else
-    {
-        checkNewVersionCheckBox->setChecked(true);
-    }
+    checkNewVersionCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
-QString SetupPageMisc::getReportInfo()
+bool SetupPageMisc::getReportInfo()
 {
-    if (checkNewVersionCheckBox->isChecked())
-    {
-        if (provideCallCheckBox->isChecked())
-        {
-            return "True";
-        }
-        else
-        {
-            return "False";
-        }
-    }
-    else
-    {
-        return "False";
-    }
+    return checkNewVersionCheckBox->isChecked();
 }
 
 void SetupPageMisc::setReportInfo(const QString &_t)
 {
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        provideCallCheckBox->setChecked(false);
-    }
-    else
-    {
-        provideCallCheckBox->setChecked(true);
-    }
+    provideCallCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
 QString SetupPageMisc::getDefaultDBPath()
@@ -600,52 +387,22 @@ void SetupPageMisc::setUseDefaultDBPath(const QString &_t)
 
 
 QString SetupPageMisc::getDXMarathon(){
-
-    if (useDxMarathonCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
+    return util->boolToQString(useDxMarathonCheckBox->isChecked());
 }
 
 void SetupPageMisc::setDXMarathon(const QString &_t){
     //QString st = t;
-    if ( (_t.toUpper()) == "FALSE")
-    {
-        useDxMarathonCheckBox->setChecked(false);
-    }
-    else
-    {
-        useDxMarathonCheckBox->setChecked(true);
-    }
+    useDxMarathonCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
 QString SetupPageMisc::getDebugLog()
 {
-    if (debugLogCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
+    return util->boolToQString(debugLogCheckBox->isChecked());
 }
 
 void SetupPageMisc::setDebugLog(const QString &_t)
 {
-    if ( (_t.toUpper()) == "TRUE")
-    {
-
-        debugLogCheckBox->setChecked(true);
-    }
-    else
-    {
-        debugLogCheckBox->setChecked(false);
-    }
+    debugLogCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
 
@@ -751,6 +508,7 @@ void SetupPageMisc::slotMoveDBButtonClicked()
         else
         {
             msgBox.setIcon(QMessageBox::Warning);
+
             msgBox.setStandardButtons(QMessageBox::Ok);
             msgBox.setDefaultButton(QMessageBox::Ok);
 
@@ -772,6 +530,8 @@ void SetupPageMisc::slotMoveDBButtonClicked()
             dbPathApplied = false;
             moveDBPushButton->setEnabled(true);
         }
+
+
     }
     else
     {
