@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 #include <QCoreApplication>
@@ -31,6 +31,8 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QNetworkAccessManager>
+#include <QOperatingSystemVersion>
+
 //#include <QFile>
 //#include <QDirIterator>
 //#include <QList>
@@ -46,12 +48,12 @@ class SoftwareUpdate: public QObject {
     Q_OBJECT
 
 public:
-    SoftwareUpdate(const QString _klogVersion);
+    SoftwareUpdate(const QString &_klogVersion);
     ~SoftwareUpdate();
 
-    void addCall(const QString _call);
+    void addCall(const QString &_call);
     void needToUpdate(bool _showWithoutVersion=false);
-    void setVersion(const QString _klogVersion);
+    void setVersion(const QString &_klogVersion);
 
 private slots:
     void slotReadyRead();
@@ -65,16 +67,19 @@ signals:
     void updateNeededSignal(const bool _q); // Will be TRUE if updated if needed and FALSE if we already have the latest version
 
 private:
-    void connectToURL(const QString _url);
+    void connectToURL(const QString &_url);
     bool checkUpdates(QIODevice *data);
-    void updateNeeded(QString _newVer);
-    void setTheURL(QString _url);
+    void updateNeeded(QString &_newVer);
+    //void setTheURL(QString _url);
     void setHeader();
+    void findOS(const int _os);
 
     Utilities *util;
 
     QString klogVersion, latestVersion, callsign;
     QString urld;
+    QString OSString;
+    int OSVersion;
     QUrl *url;
     
     //QNetworkAccessManager *manager;
