@@ -1,6 +1,6 @@
 #include "updatesatsdata.h"
 
-UpdateSatsData::UpdateSatsData(DataProxy *dp, QObject *parent) : QObject(parent)
+UpdateSatsData::UpdateSatsData(DataProxy_SQLite *dp, QObject *parent) : QObject(parent)
 {
     util = new Utilities;
      dataProxy = dp;
@@ -8,37 +8,37 @@ UpdateSatsData::UpdateSatsData(DataProxy *dp, QObject *parent) : QObject(parent)
 
 bool UpdateSatsData::satDataFileRead(const QString& tfileName)
 {
-     //qDebug() << "UpdateSatsData::satDataFileRead: " << tfileName << endl;
+       //qDebug() << "UpdateSatsData::satDataFileRead: " << tfileName << endl;
     QString fileName = tfileName;
     bool errorFound = true;
 
     QFile file( fileName );
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     {
-         //qDebug() << "UpdateSatsData::satDataFileRead File not found" << fileName << endl;
+           //qDebug() << "UpdateSatsData::satDataFileRead File not found" << fileName << endl;
         return false;
     }
     if (dataProxy->clearSatList())
     {
-         //qDebug() << "UpdateSatsData::satDataFileRead Sats YES deleted"  << endl;
+           //qDebug() << "UpdateSatsData::satDataFileRead Sats YES deleted"  << endl;
     }
     else
     {
-         //qDebug() << "UpdateSatsData::satDataFileRead Sats NOT deleted"  << endl;
+           //qDebug() << "UpdateSatsData::satDataFileRead Sats NOT deleted"  << endl;
          return false;
     }
 
     int numberOfSats = 0;
     bool hasEOH = false;
-    bool inHeader = true;
+    //bool inHeader = true;
     QString line = QString();
     bool noMoreRegisters = false;
     qint64 pos; //Position in the file
     bool haveId = false;
     bool haveName = false;
-    bool haveUpLink = false;
-    bool haveDownLink = false;
-    bool haveMode = false;
+    //bool haveUpLink = false;
+    //bool haveDownLink = false;
+    //bool haveMode = false;
 
     pos = file.pos();
     while ( !file.atEnd() && !hasEOH)
@@ -56,7 +56,7 @@ bool UpdateSatsData::satDataFileRead(const QString& tfileName)
 
     file.seek(pos);
 
-    QProgressDialog progress(tr("Reading Satellites data file..."), tr("Abort reading"), 0, numberOfSats, 0);
+    QProgressDialog progress(tr("Reading Satellites data file..."), tr("Abort reading"), 0, numberOfSats, nullptr);
 
     progress.setWindowModality(Qt::ApplicationModal);
     progress.setVisible(true);
@@ -64,20 +64,20 @@ bool UpdateSatsData::satDataFileRead(const QString& tfileName)
     progress.setMaximum(numberOfSats);
 
 
-     //qDebug() << "UpdateSatsData::satDataFileRead: END OF HEADER"  << endl;
+       //qDebug() << "UpdateSatsData::satDataFileRead: END OF HEADER"  << endl;
 
 
     //file.seek(pos);
     //START reading SAT data...
-     //qDebug() << "UpdateSatsData::satDataFileRead: Start reading data"  << endl;
+       //qDebug() << "UpdateSatsData::satDataFileRead: Start reading data"  << endl;
 
     QStringList fields, fieldToAnalyze;//, qsToPass;
     fields.clear();
     fieldToAnalyze.clear();
     QString aux = QString();
     QString field, data;
-    int tagLength = 0;
-    int dataLength = 0;
+    //int tagLength = 0;
+    //int dataLength = 0;
     QString satID = QString();
     QString satName = QString();
     QString satUpLink = QString();
@@ -87,43 +87,43 @@ bool UpdateSatsData::satDataFileRead(const QString& tfileName)
 
     while (!noMoreRegisters)
     {
-         //qDebug() << "UpdateSatsData::satDataFileRead: While Start"  << endl;
+           //qDebug() << "UpdateSatsData::satDataFileRead: While Start"  << endl;
         if (!file.atEnd())
         {
             line.clear();
             line.append(file.readLine().trimmed().toUpper());
             fields.clear();
-             //qDebug() << "UpdateSatsData::satDataFileRead-line:" << line << endl;
+               //qDebug() << "UpdateSatsData::satDataFileRead-line:" << line << endl;
             fields << line.split("<", QString::SkipEmptyParts);
 
             foreach (aux, fields)
             {
                 aux = aux.simplified();
-                //QDebug() << "UpdateSatsData::satDataFileRead-aux:" << aux << endl;
+                  //qDebug() << "UpdateSatsData::satDataFileRead-aux:" << aux << endl;
                 fieldToAnalyze = util->getValidADIFFieldAndData("<" + aux);
                 if (fieldToAnalyze.size() == 2)
                 {
                     field = fieldToAnalyze.at(0);
                     data = fieldToAnalyze.at(1);
-                    //QDebug() << "UpdateSatsData::satDataFileRead-Field:" << field << endl;
-                    //QDebug() << "UpdateSatsData::satDataFileRead-Data:" << data << endl;
+                      //qDebug() << "UpdateSatsData::satDataFileRead-Field:" << field << endl;
+                      //qDebug() << "UpdateSatsData::satDataFileRead-Data:" << data << endl;
                     if (field == "EOR")
                     {
-                        //QDebug() << "UpdateSatsData::satDataFileRead - EOR DETECTED!" << endl;
+                          //qDebug() << "UpdateSatsData::satDataFileRead - EOR DETECTED!" << endl;
                         if (haveId && haveName)
                         {
-                            //QDebug() << "UpdateSatsData::satDataFileRead - EOR DETECTED and have it all!" << endl;
+                              //qDebug() << "UpdateSatsData::satDataFileRead - EOR DETECTED and have it all!" << endl;
                             haveId = false;
                             haveName = false;
-                            haveUpLink = false;
-                            haveDownLink = false;
-                            haveMode = false;
+                            //haveUpLink = false;
+                            //haveDownLink = false;
+                            //haveMode = false;
                             if (!dataProxy->addSatellite(satID, satName, satDownLink,satUpLink, satMode))
                             {
                                 errorFound = true;
                                 return false;
                             }
-                            //QDebug() << "UpdateSatsData::satDataFileRead - Satellite added: " << satID << endl;
+                              //qDebug() << "UpdateSatsData::satDataFileRead - Satellite added: " << satID << endl;
                             satID = QString();
                             satName = QString();
                             satUpLink = QString();
@@ -134,9 +134,9 @@ bool UpdateSatsData::satDataFileRead(const QString& tfileName)
                         {
                             haveId = false;
                             haveName = false;
-                            haveUpLink = false;
-                            haveDownLink = false;
-                            haveMode = false;
+                            //haveUpLink = false;
+                            //haveDownLink = false;
+                            //haveMode = false;
                             satID = QString();
                             satName = QString();
                             satUpLink = QString();
@@ -150,35 +150,35 @@ bool UpdateSatsData::satDataFileRead(const QString& tfileName)
                         {
                             satID = data;
                             haveId = true;
-                                 //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_ARRLID" << endl;
+                                   //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_ARRLID" << endl;
                         }
                         else if (field == "APP_KLOG_SATS_NAME")
                         {
                             satName = data;
                             haveName = true;
-                                 //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_NAME" << endl;
+                                   //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_NAME" << endl;
                         }
                         else if (field == "APP_KLOG_SATS_UPLINK")
                         {
                             satUpLink = data;
-                            haveUpLink = true;
-                             //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_UPLINK" << endl;
+                            //haveUpLink = true;
+                               //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_UPLINK" << endl;
                         }
                         else if (field == "APP_KLOG_SATS_DOWNLINK")
                         {
                             satDownLink = data;
-                            haveDownLink = true;
-                             //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_DOWNLINK" << endl;
+                            //haveDownLink = true;
+                               //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_DOWNLINK" << endl;
                         }
                         else if (field == "APP_KLOG_SATS_MODE")
                         {
                             satMode = data;
-                            haveMode = true;
-                                 //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_MODE" << endl;
+                            //haveMode = true;
+                                   //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_SATS_MODE" << endl;
                         }
                         else if (field == "APP_KLOG_DATA")
                         {
-                             //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_DATA" << endl;
+                               //qDebug() << "UpdateSatsData::satDataFileRead - Detected: " << "APP_KLOG_DATA" << endl;
                             if (data != "SATS")
                             {
                                 return false;
@@ -186,27 +186,27 @@ bool UpdateSatsData::satDataFileRead(const QString& tfileName)
                         }
                     }
                 }
-                 //qDebug() << "UpdateSatsData::satDataFileRead: foreach end"  << endl;
+                   //qDebug() << "UpdateSatsData::satDataFileRead: foreach end"  << endl;
             }
-             //qDebug() << "UpdateSatsData::satDataFileRead: out of foreach"  << endl;
+               //qDebug() << "UpdateSatsData::satDataFileRead: out of foreach"  << endl;
         }
         else
         {
             noMoreRegisters = true;
         }
 
-         //qDebug() << "UpdateSatsData::satDataFileRead: While END"  << endl;
+           //qDebug() << "UpdateSatsData::satDataFileRead: While END"  << endl;
     }
 
 
     if (errorFound)
     {
-        //qDebug() << "UpdateSatsData::satDataFileRead: errorFound = true"  << endl;
+          //qDebug() << "UpdateSatsData::satDataFileRead: errorFound = true"  << endl;
         return false;
     }
     else
     {
-       //qDebug() << "UpdateSatsData::satDataFileRead: END"  << endl;
+         //qDebug() << "UpdateSatsData::satDataFileRead: END"  << endl;
        emit satsUpdatedSignal(true);
        QMessageBox msgBox;
        msgBox.setIcon(QMessageBox::Information);
@@ -215,7 +215,7 @@ bool UpdateSatsData::satDataFileRead(const QString& tfileName)
     }
 
 
-    //qDebug() << "UpdateSatsData::satDataFileRead: END "  << endl;
+      //qDebug() << "UpdateSatsData::satDataFileRead: END "  << endl;
     return true;
 }
 
@@ -224,11 +224,11 @@ bool UpdateSatsData::satDataFileRead(const QString& tfileName)
 
 bool UpdateSatsData::readSatDataFile()
 {
-     //qDebug() << "UpdateSatsData::readSatDataFile: " << endl;
+       //qDebug() << "UpdateSatsData::readSatDataFile: " << endl;
     //QString fileName = QFileDialog::getOpenFileName(0, tr("Open File"), "/home", "Sat data (*.dat)");
 
 
-    QString fileName = QFileDialog::getOpenFileName(0, tr("Open File"),
+    QString fileName = QFileDialog::getOpenFileName(nullptr, tr("Open File"),
                                                      util->getHomeDir(),
                                                      tr("Sat Data") + "(*.dat)");
     if (fileName.isNull())
@@ -237,9 +237,9 @@ bool UpdateSatsData::readSatDataFile()
     }
     else
     {
-         //qDebug() << "MainWindow::slotADIFImport -1" << endl;
+           //qDebug() << "MainWindow::slotADIFImport -1" << endl;
         return satDataFileRead(fileName);
         //filemanager->adifReadLog(fileName, currentLog);
     }
-     //qDebug() << "UpdateSatsData::readSatDataFile: END" << endl;
+       //qDebug() << "UpdateSatsData::readSatDataFile: END" << endl;
 }
