@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 #include <QObject>
@@ -30,7 +30,7 @@
 #include <QProgressDialog>
 #include <QFileDialog>
 #include "utilities.h"
-#include "dataproxy.h"
+#include "dataproxy_sqlite.h"
 #include "dataproxy_sqlite.h"
 
 class UpdateSatsData : public QObject
@@ -38,7 +38,7 @@ class UpdateSatsData : public QObject
     Q_OBJECT
 
 public:
-    explicit UpdateSatsData(DataProxy *dp, QObject *parent = nullptr);
+    explicit UpdateSatsData(DataProxy_SQLite *dp, QObject *parent = nullptr);
     bool readSatDataFile();
     bool satDataFileRead(const QString& tfileName);
 
@@ -46,7 +46,7 @@ private:
 
 
     Utilities *util;
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
 
 signals:
     void satsUpdatedSignal(const bool _p);
