@@ -3,8 +3,11 @@
 Utilities::Utilities()
 {
        //qDebug() << "Utilities::Utilities"  << endl;
-    //dbPath = getKLogDBFile();
+
     softwareVersion = "0.0";
+
+    //palRed.setColor(QPalette::Text, Qt::red);
+    //palBlack.setColor(QPalette::Text, Qt::black);
        //qDebug() << "Utilities::Utilities - END"  << endl;
 }
 
@@ -80,6 +83,31 @@ bool Utilities::trueOrFalse(const QString &_s)
     //return false;
 }
 
+QChar Utilities::boolToCharToSQLite(const bool _b)
+{
+    if (_b)
+    {
+        return 'Y';
+    }
+    else
+    {
+        return 'N';
+    }
+
+}
+
+QString Utilities::boolToQString(const bool _b)
+{
+    if (_b)
+    {
+        return "True";
+    }
+    else
+    {
+        return "False";
+    }
+}
+
 QString Utilities::checkAndFixASCIIinADIF(const QString &_data)
 {
          //qDebug() << "SetupDialog::checkAndFixASCIIinADIF " << _data << endl;
@@ -120,79 +148,86 @@ void Utilities::printQString(const QStringList &_qs)
         //qDebug() << _qs.at(_qs.length()-1) << endl;
 }
 
+QString Utilities::getGlobalAgent(const QString &_klogversion)
+{
+    return QString("KLog-%1").arg(_klogversion);
+}
 QString Utilities::getAgent(const QString &_klogversion)
 {
     QString version;
+    QString ops;
     version = _klogversion;
     
 #if defined(Q_OS_WIN32)
-    return "KLog-Win32-" + version;
+    ops = "KLog-Win32-";
 #elif defined(Q_OS_WIN64)
-    return "KLog-Win64-" + version;
+    ops = "KLog-Win64-";
 #elif defined(Q_OS_LINUX)
-    return "KLog-Linux-" + version;
+    ops = "KLog-Linux-";
 #elif defined(Q_OS_WIN)
-    return "KLog-Win-"+ version;
+    ops = "KLog-Win-"+ version;
 #elif defined(Q_OS_MACOS)
-    return "KLog-macOS-" + version;
+    ops = "KLog-macOS-";
 #elif defined(Q_OS_OSX)
-    return "KLog-OSX-" + version;
+    ops = "KLog-OSX-";
 #elif defined(Q_OS_MAC)
-    return "KLog-MAC-" + version;
+    ops = "KLog-MAC-";
 #elif defined(Q_OS_DARWIN)
-    return "KLog-DARWIN-" + version;
+    ops = "KLog-DARWIN-";
 #elif defined(Q_OS_AIX)
-    return "KLog-aix-" + version;    
+    ops = "KLog-aix-";
 #elif defined(Q_OS_ANDROID)
-    return "KLog-android-" + version;    
+    ops = "KLog-android-";
 //#elif defined(Q_OS_BSD4)
-//    return "KLog-bsd4-" + version;
+//    ops = "KLog-bsd4-";
 #elif defined(Q_OS_BSDI)
-    return "KLog-bsdi-" + version;    
+    ops = "KLog-bsdi-";
 #elif defined(Q_OS_CYGWIN)
-    return "KLog-cygwin-" + version;    
+    ops = "KLog-cygwin-";
 #elif defined(Q_OS_DARWIN)
-    return "KLog-darwin-" + version;    
+    ops = "KLog-darwin-";
 #elif defined(Q_OS_DGUX)
-    return "KLog-dgux-" + version;    
+    ops = "KLog-dgux-";
 #elif defined(Q_OS_DYNIX)
-    return "KLog-dynix-" + version;
+    ops = "KLog-dynix-";
 #elif defined(Q_OS_FREEBSD)
-    return "KLog-freebsd-" + version;    
+    ops = "KLog-freebsd-";
 #elif defined(Q_OS_HPUX)
-    return "KLog-hpux-" + version;    
+    ops = "KLog-hpux-";
 #elif defined(Q_OS_IOS)
-    return "KLog-ios-" + version;    
+    ops = "KLog-ios-";
 #elif defined(Q_OS_IRIX)
-    return "KLog-irix-" + version;    
+    ops = "KLog-irix-";
 #elif defined(Q_OS_LYNX)
-    return "KLog-lynx-" + version;    
+    ops = "KLog-lynx-";
 #elif defined(Q_OS_NETBSD)
-    return "KLog-netbsd-" + version;    
+    ops = "KLog-netbsd-";
 #elif defined(Q_OS_OPENBSD)
-    return "KLog-openbsd-" + version;    
+    ops = "KLog-openbsd-";
 #elif defined(Q_OS_OSF)
-    return "KLog-osf-" + version;
+    ops = "KLog-osf-";
 #elif defined(Q_OS_QNX)
-    return "KLog-qnx-" + version;    
+    ops = "KLog-qnx-";
 #elif defined(Q_OS_SCO)
-    return "KLog-sco-" + version;    
+    ops = "KLog-sco-";
 #elif defined(Q_OS_SOLARIS)
-    return "KLog-solaris-" + version;    
+    ops = "KLog-solaris-";
 #elif defined(Q_OS_TVOS)
-    return "KLog-tvos-" + version;    
+    ops = "KLog-tvos-";
 #elif defined(Q_OS_UNIX)
-    return "KLog-unix-" + version;    
+    ops = "KLog-unix-";
 #elif defined(Q_OS_UNIXWARE)
-    return "KLog-unixware-" + version;    
+    ops = "KLog-unixware-";
 #elif defined(Q_OS_WHATCHOS)
-    return "KLog-whatchos-" + version;    
+    ops = "KLog-whatchos-";
 #elif defined(Q_OS_WINRT)
-    return "KLog-winrt-" + version;    
+    ops = "KLog-winrt-";
 #else
-    return "KLog-Other-" + version;
+    ops = "KLog-Other-";
 #endif
 
+    return ops+version;
+
     //return "KLog-Unknown-" + version;
 }
 
@@ -209,6 +244,35 @@ QString Utilities::getHomeDir()
 #endif
 }
 
+QString Utilities::getDefaultRST(const QString &_m)
+{
+   //qDebug() << "Utilities::getDefaultRST: " << _m << endl;
+
+   if ((_m == "SSB") || (_m== "LSB") || (_m=="USB") )
+   {
+        //qDebug() << "MainWindow::setRSTToMode: Detected SSB/LSB/USB"  << endl;
+       return "59";
+   }
+   else if ((_m == "CW") || (_m == "RTTY"))
+   {
+       return "599";
+   }
+   else if (_m == "PSK31")
+   {
+       return "599";
+   }
+   else if ( (_m.contains("FT", Qt::CaseInsensitive)) || (_m.contains("JT", Qt::CaseInsensitive)) || (_m.contains("QRA64", Qt::CaseInsensitive)) || (_m.contains("JS", Qt::CaseInsensitive)))
+   {
+        return "0";
+   }
+   else
+   { // By default SSB RST is configured but anything could be added
+        return "59";
+   }
+
+
+}
+
 QString Utilities::getKLogDefaultDatabaseFile()
 {
 //TODO: To be removed when the defaultDir is saved in the config file
@@ -238,14 +302,39 @@ QString Utilities::getKLogDBFile()
         {
             dbPath = getKLogDefaultDatabaseFile();
         }
-
     }
-
        //qDebug() << "Utilities::getKLogDBFile: path to use: " << dbPath << endl;
-
     return dbPath + "/logbook.dat";
 }
 
+QString Utilities::getKLogDBBackupFile()
+{
+        //qDebug() << "Utilities::getKLogDBFile: start " << endl;
+
+    dbPath = getKLogDefaultDatabaseFile();
+    QFile file(getCfgFile());
+
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+
+        //return dbPath;
+        //return getKLogDatabaseFile(dbPath);
+    }
+    else
+    {
+        while (!file.atEnd()) {
+            QByteArray line = file.readLine();
+            processConfigLine(line);
+        }
+
+        if (dbPath.length()<1)
+        {
+            dbPath = getKLogDefaultDatabaseFile();
+        }
+    }
+       //qDebug() << "Utilities::getKLogDBFile: path to use: " << dbPath << endl;
+    return dbPath + "/" + QDateTime::currentDateTime().toString("yyyyMMdd-hhmmss") + "-backup-logbook.dat" ;
+}
+
 bool Utilities::processConfigLine(const QString &_line)
 {
              //qDebug() << "Utilities::processConfigLine: " << _line << endl;
@@ -331,7 +420,26 @@ QString Utilities::getSaveSpotsLogFile()
     QString filename = "/" + (QDateTime::currentDateTime()).toString("yyyyMMdd") + "-klogdxcluster.txt";
 
     return getHomeDir() + filename;
+}
 
+QString Utilities::getBackupADIFile()
+{
+   return getHomeDir() + "/" + (QDateTime::currentDateTime()).toString("yyyyMMdd-hhmm") + "-klogbackup.adi";
+}
+
+QString Utilities::getClubLogFile()
+{
+    return getHomeDir() + "/klog-clublog-upload.adi";
+}
+
+QString Utilities::getEQSLFile()
+{
+    return getHomeDir() + "/klog-eqsl-upload.adi";
+}
+
+QString Utilities::getLoTWAdifFile()
+{
+    return getHomeDir() + "/klog-lotw-upload.adi";
 }
 
 QString Utilities::getTQSLsFileName()
@@ -652,27 +760,6 @@ bool Utilities::isValidCall(const QString &_c)
     return true;
 }
 
-bool Utilities::isValidTime(const QString &_t)
-{
-    QTime time = QTime::fromString(_t, "hhmmss");
-    if (time.isValid())
-    {
-        return true;
-    }
-    time = QTime::fromString(_t, "hhmm");
-    if (time.isValid())
-    {
-        return true;
-    }
-    time = QTime::fromString(_t, "hhmm");
-    if (time.isValid())
-    {
-        return true;
-    }
-
-    return false;
-}
-
 bool Utilities::isValidBandId(const int _b)
 {
     if (_b>0)
@@ -857,7 +944,7 @@ bool Utilities::isValidADIFField(const QString &_b)
 
     if (separatorPosition <= 0)
     {
-           //qDebug() << "Utilities::isValidADIFField: Length problem <= 0" << endl;
+        //qDebug() << "Utilities::isValidADIFField: Length problem <= 0" << endl;
         return false;
     }
 
@@ -866,9 +953,31 @@ bool Utilities::isValidADIFField(const QString &_b)
     return true;
 }
 
+bool Utilities::isValidQSL_Rcvd(const QString &c)
+{
+    if ((c == "Y") | (c == "N") | (c == "R") | (c == "I") | (c == "V"))
+    {
+        return true;
+    }
+    else {
+        return false;
+    }
+}
+
+bool Utilities::isValidQSL_Sent(const QString &c)
+{
+    if ((c == "Y") | (c == "N") | (c == "R") | (c == "Q") | (c == "I"))
+    {
+        return true;
+    }
+    else {
+        return false;
+    }
+}
+
 QStringList Utilities::getValidADIFFieldAndData(const QString &_b)
 {
-      //qDebug() << "Utilities::getValidADIFFieldAndData: " << _b << endl;
+   //qDebug() << "Utilities::getValidADIFFieldAndData: " << _b << endl;
     /*
         This functions checks if the ADIF field has the proper format.
         <Field:length:Data type>Data
@@ -878,35 +987,45 @@ QStringList Utilities::getValidADIFFieldAndData(const QString &_b)
 
     if (!(_b.startsWith('<')))
     {
-          //qDebug() << "Utilities::getValidADIFFieldAndData: BAD FORMAT: No < or > delimiters: " << _b << endl;
+        //qDebug() << "Utilities::getValidADIFFieldAndData: BAD FORMAT: No < or > delimiters: " << _b << endl;
         return QStringList();
     }
     if (_b.simplified() == "<EOR>")
     {
-          //qDebug() << "Utilities::getValidADIFFieldAndData: EOR" << endl;
+        //qDebug() << "Utilities::getValidADIFFieldAndData: EOR" << endl;
         result << "EOR" << "EOR";
         return result;
     }
-      //qDebug() << "Utilities::getValidADIFFieldAndData: -20" << endl;
-    QStringList validDataTypes = {"B", "N", "D", "T", "S", "I", "M", "G", "E", "L"};
+    QString aux = _b;
     QStringList qs;
     qs.clear();
-    qs.append(_b.split('>'));
+
+    if ((aux.contains("APP_LOTW_")) && aux.contains("//"))
+    { // Trying to fix a LoTW ADIF bug
+        qs.append(aux.split("//"));
+        aux = qs.at(0);
+    }
+
+    //qDebug() << "Utilities::getValidADIFFieldAndData: -20" << endl;
+    QStringList validDataTypes = {"B", "N", "D", "T", "S", "I", "M", "G", "E", "L"};
+
+    qs.clear();
+    qs.append(aux.split('>'));
 
     if (qs.size()!= 2)
     {
-          //qDebug() << "Utilities::getValidADIFFieldAndData-0 (not two): " << QString::number(qs.size()) << endl;
+        //qDebug() << "Utilities::getValidADIFFieldAndData-0 (not two): " << QString::number(qs.size()) << endl;
         return result;
     }
-      //qDebug() << "Utilities::getValidADIFFieldAndData: -30" << endl;
+    //qDebug() << "Utilities::getValidADIFFieldAndData: -30" << endl;
     //QString field = (qs.at(0)).right((qs.at(0)).length() - 1);
     QString field = (qs.at(0)).right((qs.at(0)).length() - 1);
     QString data = (qs.at(1)).simplified();
     //data = data.simplified();
     QString dataType = QString();
 
-      //qDebug() << "Utilities::getValidADIFFieldAndData-Field: " << field << endl;
-      //qDebug() << "Utilities::getValidADIFFieldAndData_Data: " << data << endl;
+    //qDebug() << "Utilities::getValidADIFFieldAndData-Field: " << field << endl;
+    //qDebug() << "Utilities::getValidADIFFieldAndData_Data: " << data << endl;
 
     int length = data.length();
     int separatorPosition = 0;
@@ -930,27 +1049,27 @@ QStringList Utilities::getValidADIFFieldAndData(const QString &_b)
     }
     else
     {
-          //qDebug() << "Utilities::getValidADIFFieldAndData - FORMAT ERROR, more than 2 \":\" - " << field << endl;
+        //qDebug() << "Utilities::getValidADIFFieldAndData - FORMAT ERROR, more than 2 \":\" - " << field << endl;
         return result;
     }
-      //qDebug() << "Utilities::getValidADIFFieldAndData: -60" << endl;
+    //qDebug() << "Utilities::getValidADIFFieldAndData: -60" << endl;
     if ( length != separatorPosition)
     {
-          //qDebug() << "Utilities::getValidADIFFieldAndData: Data Length problem: " << (field) << "/" << data << " - " << QString::number(length) << "/" << QString::number(separatorPosition) << endl;
+        //qDebug() << "Utilities::getValidADIFFieldAndData: Data Length problem: " << (field) << "/" << data << " - " << QString::number(length) << "/" << QString::number(separatorPosition) << endl;
         return result;
     }
 
     if (separatorPosition <= 0)
     {
-          //qDebug() << "Utilities::getValidADIFFieldAndData: Length problem <= 0" << endl;
+        //qDebug() << "Utilities::getValidADIFFieldAndData: Length problem <= 0" << endl;
         return result;
     }
-      //qDebug() << "Utilities::getValidADIFFieldAndData: -90: f: " << field << endl;
+     //qDebug() << "Utilities::getValidADIFFieldAndData: -90: f: " << field << endl;
       //qDebug() << "Utilities::getValidADIFFieldAndData: -90: d: " << data<< endl;
     //field = field.section(':', 0, 0);
     result.clear();
     result << field.section(':', 0, 0) << data;
-      //qDebug() << "Utilities::checkADIFValidFormat: Return true: " << result.at(0) << "/" << result.at(1) << endl;
+     //qDebug() << "Utilities::checkADIFValidFormat: Return true: " << result.at(0) << "/" << result.at(1) << endl;
     return result;
 }
 
@@ -989,3 +1108,198 @@ QString Utilities::getAValidCall (const QString &_wrongCall)
     //qDebug() << "Utilities::getAValidCall: " << _confirmedCall << endl;
     return _confirmedCall;
 }
+
+
+QString Utilities::getDateTimeSQLiteStringFromDateTime(const QDateTime &_d)
+{
+    return QString(_d.toString("yyyy-MM-dd hh:mm:ss"));
+}
+
+QString Utilities::getDateSQLiteStringFromDate(const QDate &_d)
+{
+    return QString(_d.toString("yyyy-MM-dd"));
+}
+
+bool Utilities::isValidDateFromString(const QString &_s)
+{
+    return getDateFromSQliteString(_s).isValid();
+}
+
+bool Utilities::isValidTimeFromString(const QString &_s)
+{
+    return getDateTimeFromSQLiteString(_s).time().isValid();
+}
+
+bool Utilities::isValidDateTimeFromString(const QString &_s)
+{
+    return getDateTimeFromSQLiteString(_s).isValid();
+}
+
+QDateTime Utilities::getDateTimeFromSQLiteString(const QString &_s)
+{
+    return QDateTime::fromString(_s, "yyyy-MM-dd hh:mm:ss");
+}
+
+QTime Utilities::getTimeFromSQLiteString(const QString &_s)
+{
+    if (_s.length()==5)
+    {
+        return QTime::fromString(_s, "hh:mm");
+    }
+    else
+    {
+        return QTime::fromString(_s, "hh:mm:ss");
+    }
+
+}
+
+QDate Utilities::getDateFromSQliteString(const QString &_s)
+{
+    //It may receive "just" a date or a "date time".
+
+    if (getDateTimeFromSQLiteString(_s).isValid()) // if we have received a full date time
+    {
+        return (getDateTimeFromSQLiteString(_s)).date();
+
+    }
+    else // If we have received "just a date" or an error
+    {
+        return  QDate::fromString(_s, "yyyy-MM-dd");
+    }
+
+
+}
+
+QDate Utilities::getDateFromADIFDateString(const QString &_s)
+{// Expects an ADIF DATE format string: "YYYYMMDD"
+   //qDebug() << "Utilities::getDateFromADIFDateString: " << _s << endl;
+    return QDate::fromString(_s, "yyyyMMdd");
+
+}
+
+QTime Utilities::getTimeFromADIFTimeString(const QString &_s)
+{// Expects and ADIF TIME format String "HHMMSS" or "HHMM"
+    //qDebug() << "Utilities::getTimeFromADIFTimeString: " << _s << endl;
+    if (_s.length()==4)
+    {
+
+        return QTime::fromString(_s, "hhmm");
+    }
+    else
+    {
+        return QTime::fromString(_s, "hhmmss");
+    }
+}
+
+QDate Utilities::getDateFromLoTWQSLDateString(const QString &_s)
+{
+    //qDebug() << "Utilities::getDateFromLoTWQSLDateString: " << _s << endl;
+    QStringList datet;
+    datet.clear();
+    datet << _s.split(" ");
+    //qDebug() << "Utilities::getDateFromLoTWQSLDateString: date:" << datet.at(0) << endl;
+    return QDate::fromString(datet.at(0), "yyyy-MM-dd");
+}
+
+
+QString Utilities::getADIFDateFromQDateTime(const QDateTime &_d)
+{
+    if (!_d.isValid())
+    {
+        return QString();
+    }
+    else
+    {
+        return _d.date().toString("yyyyMMdd");
+    }
+}
+
+QString Utilities::getADIFDateFromQDate(const QDate &_d)
+{
+    if (!_d.isValid())
+    {
+        return QString();
+    }
+    else
+    {
+        return _d.toString("yyyyMMdd");
+    }
+}
+
+QString Utilities::getADIFTimeFromQDateTime(const QDateTime &_d)
+{
+    if (!_d.isValid())
+    {
+        return QString();
+    }
+    else
+    {
+        return _d.time().toString("hhmmss");
+    }
+}
+
+
+QString Utilities::getCabrilloDateFromQDate(const QDate &_d)
+{// Will produce the Cabrillo DATE format: "YYYY-MM-DD"
+    if (!_d.isValid())
+    {
+        return QString("0000-00-00");
+    }
+    else
+    {
+        return _d.toString("yyyy-MM-dd");
+    }
+}
+
+QString Utilities::getCabrilloTimeFromQDateTime(const QDateTime &_d)
+{// Will produce the Cabrillo TIME format: "HHMM"
+    if (!_d.isValid())
+    {
+        return QString("0000");
+    }
+    else
+    {
+        return _d.time().toString("hhmm");
+    }
+}
+
+QString Utilities::getOnlineServiceName(OnLineProvider _service)
+{//enum OnLineProvider {ClubLog, LoTW, eQSL, QRZ}; //, HamQTH, HRDLog
+    switch (_service)
+    {
+        case LoTW:
+        {
+            return "LoTW";
+        }
+    case ClubLog:
+    {
+        return "ClubLog";
+    }
+    case QRZ:
+    {
+        return "QRZ.com";
+    }
+    case eQSL:
+    {
+        return "eQSL.cc";
+    }
+    }
+    return QString();
+}
+/*
+QPalette Utilities::getPalete(bool _ok)
+{
+   //qDebug() << "Utilities::getPalete"  << endl;
+    if (_ok)
+    {
+       //qDebug() << "Utilities::getPalete - true"  << endl;
+        return palRed;
+        //return QPalette::setColor(QPalette::Text, Qt::red);
+    }
+    else
+    {
+       //qDebug() << "Utilities::getPalete - false"  << endl;
+        return palBlack;
+    }
+}
+*/
