@@ -34,10 +34,14 @@
 #include <QtGlobal>
 #include <QString>
 #include <QtWidgets>
+#include <QPalette>
 #include "locator.h"
 #include <QtDebug>
 
-enum ExportMode {ModeLotW, ModeADIF};
+enum ExportMode {ModeLotW, ModeADIF, ModeClubLog, ModeEQSL, ModeQRZ};
+enum OnLineProvider {ClubLog, LoTW, eQSL, QRZ}; //, HamQTH, HRDLog
+enum OnlineErrorCode {Ok, Fail};
+enum OnlineErrorReason {Other, Auth, DupeQSO, WrongLogBook};
 
 class Utilities
 {
@@ -46,12 +50,16 @@ public:
     ~Utilities();
     int getProgresStepForDialog(int totalSteps);
     bool trueOrFalse(const QString &_s); // reads a String and return true if s.upper()== TRUE :-)
+    QChar boolToCharToSQLite(const bool _b);
+    QString boolToQString(const bool _b);
     QString checkAndFixASCIIinADIF(const QString &_data);
     QString getAgent(const QString &_klogversion);
+    QString getGlobalAgent(const QString &_klogversion);
     //QOperatingSystemVersion getOS();
     //Devel or debug functions - Not adding any feature to the user
     void printQString(const QStringList &_qs);
     QString getKLogDBFile();
+    QString getKLogDBBackupFile();
 
     //QString getKLogDatabaseFile(const QString &_file);
     bool isDBFileExisting();
@@ -63,19 +71,24 @@ public:
     QString getCTYFile();
     QString getDebugLogFile();
     QString getSaveSpotsLogFile();
+    QString getBackupADIFile();
+    QString getClubLogFile();
+    QString getEQSLFile();
+    QString getLoTWAdifFile();
 
     void setVersion(const QString &_v);
     QString getVersion();
     double getVersionDouble();
 
-    QDate getDefaultDate();    
+    QDate getDefaultDate();
+    QString getDefaultRST(const QString &_m);
     int getNormalizedDXCCValue(const int _dxcc);
 
     // Validations
     bool isValidDate(const QDate _d);
     bool isValidDateTime(const QString &_d);
     bool isValidCall(const QString &_c);
-    bool isValidTime(const QString &_t);
+
     bool isValidBandId(const int _b);
     bool isValidModeId(const int _m);
     bool isValidFreq(const QString &_b);
@@ -85,19 +98,53 @@ public:
     bool isValidComment(const QString &_b);
     bool isValidName(const QString &_b);
     bool isValidADIFField(const QString &_b);
+    bool isValidQSL_Rcvd(const QString &c);
+    bool isValidQSL_Sent(const QString &c);
 
+    bool isValidTimeFromString(const QString &_s);
+    bool isValidDateFromString(const QString &_s);
+    bool isValidDateTimeFromString(const QString &_s);
 
     QStringList getValidADIFFieldAndData(const QString &_b);
     QString getAValidCall (const QString &_wrongCall);
 
+    // Write DATE/TIME to DB
+    QString getDateTimeSQLiteStringFromDateTime(const QDateTime &_d);
+    QString getDateSQLiteStringFromDate(const QDate &_d);
 
+    // Read from DB
+    QDateTime getDateTimeFromSQLiteString(const QString &_s);
+    QTime getTimeFromSQLiteString(const QString &_s);
+    QDate getDateFromSQliteString(const QString &_s);
+
+
+    // Creates the ADIF DATE & TIME formats
+    QString getADIFDateFromQDateTime(const QDateTime &_d);  // Will produce the ADIF DATE format: "YYYYMMDD"
+    QString getADIFDateFromQDate(const QDate &_d);          // Will produce the ADIF DATE format: "YYYYMMDD"
+    QString getADIFTimeFromQDateTime(const QDateTime &_d);  // Will produce the ADIF TIME format: "HHMMSS"
+
+    // Parse Date & Time from ADIF
+    QDate getDateFromADIFDateString(const QString &_s);     // Expects an ADIF DATE format string: "YYYYMMDD"
+    QTime getTimeFromADIFTimeString(const QString &_s);     // Expects and ADIF TIME format String "HHMMSS" or "HHMM"
+
+    // Parse date fromLoTW
+    QDate getDateFromLoTWQSLDateString(const QString &_s);
+
+    // Creates the Cabrillo DATE & TIME (http://wwrof.org/cabrillo/)
+    QString getCabrilloDateFromQDate(const QDate &_d);          // Will produce the Cabrillo DATE format: "YYYY-MM-DD"
+    QString getCabrilloTimeFromQDateTime(const QDateTime &_d);  // Will produce the Cabrillo TIME format: "HHMM"
+
+    QString getOnlineServiceName(OnLineProvider _service);
+    //QPalette getPalete(bool _ok);
 private:
     bool processConfigLine(const QString &_line);
     QString getKLogDefaultDatabaseFile();
     QString dbPath;
     QString softwareVersion;
+    //QPalette palRed, palBlack;
 
 };
 
 #endif // UTILITIES_H
 
+
